@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Jun Shih 1995
+// uC++ Version 5.5.0, Copyright (C) Jun Shih 1995
 // 
 // uBConditionEval.cc -- 
 // 
 // Author           : Jun Shih
 // Created On       : Sat Nov 11 14:44:08 EST 1995
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Sep 14 13:06:53 2006
-// Update Count     : 41
+// Last Modified On : Fri Jun 22 17:27:15 2007
+// Update Count     : 42
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -243,8 +243,8 @@ int uBConditionEval::evaluate() {
 	return 0;					// can not find address of one of them
     } // if
 
-    assert(bp_cond.var[0].vtype == BreakpointCondition::INT &&	bp_cond.var[1].vtype == BreakpointCondition::INT ||
-	    bp_cond.var[0].vtype == BreakpointCondition::PTR &&	bp_cond.var[1].vtype == BreakpointCondition::PTR );
+    assert( ( bp_cond.var[0].vtype == BreakpointCondition::INT && bp_cond.var[1].vtype == BreakpointCondition::INT ) ||
+	    ( bp_cond.var[0].vtype == BreakpointCondition::PTR && bp_cond.var[1].vtype == BreakpointCondition::PTR ) );
 
     switch (bp_cond.Operator) {
       case BreakpointCondition::EQUAL:
