@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Martin Karsten 1995
+// uC++ Version 5.5.0, Copyright (C) Martin Karsten 1995
 // 
 // uLocalDebugger.cc -- 
 // 
 // Author           : Martin Karsten
 // Created On       : Thu Apr 20 21:34:48 1995
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Sep 12 08:10:26 2006
-// Update Count     : 700
+// Last Modified On : Thu Sep  6 09:09:39 2007
+// Update Count     : 702
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -251,30 +251,30 @@ void uLocalDebugger::main() {
 #endif // __U_DEBUG_H__
 		_Accept( ~uLocalDebugger ) {
 			break;
-		} else _Accept( breakpointHandler ) {
-		} else _Accept( unblockTask ) {
-		} else _Accept( checkPointMX ) {
-		} else _Accept( performAtomicOperation ) {
-		} else _Accept( attachULThread ) {
+		} or _Accept( breakpointHandler ) {
+		} or _Accept( unblockTask ) {
+		} or _Accept( checkPointMX ) {
+		} or _Accept( performAtomicOperation ) {
+		} or _Accept( attachULThread ) {
 			send( pdu );
-		} else _Accept( createULThreadMX ) {
+		} or _Accept( createULThreadMX ) {
 			send( pdu );
-		} else _Accept( destroyULThreadMX ) {
+		} or _Accept( destroyULThreadMX ) {
 			send( pdu );
-		} else _Accept( createCluster ) {
+		} or _Accept( createCluster ) {
 			send( pdu );
-		} else _Accept( destroyCluster ) {
+		} or _Accept( destroyCluster ) {
 			send( pdu );
-		} else _Accept( createKernelThread ) {
+		} or _Accept( createKernelThread ) {
 			send( pdu );
-		} else _Accept( destroyKernelThread ) {
+		} or _Accept( destroyKernelThread ) {
 			send( pdu );
-		} else _Accept( migrateKernelThread ) {
+		} or _Accept( migrateKernelThread ) {
 			send( pdu );
-		} else _Accept( migrateULThreadMX ) {
+		} or _Accept( migrateULThreadMX ) {
 			send( pdu );
-		} else _Accept( abortApplication ) {
-		} else _Accept( finish ) {
+		} or _Accept( abortApplication ) {
+		} or _Accept( finish ) {
 			send( pdu );
 			uLocalDebuggerActive = false;
 		} // _Accept
@@ -975,7 +975,7 @@ void uLocalDebugger::abortApplication() {
   if ( ! uLocalDebuggerActive ) return;
   if ( U_THIS_TASK == uLocalDebuggerInstance ) return;	// prevent recursion
 
-	uSigHandlerModule::signal( SIGCONT, cont_handler );	// install SIGCONT handler
+	UPP::uSigHandlerModule::signal( SIGCONT, cont_handler ); // install SIGCONT handler
 	pdu.createNabortApplication( uThisProcessor().getPid() );
 	send( pdu );
 	while ( ! abort_confirmed ) {						// busy wait for a response
