@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 2003
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 2003
 // 
 // Allocation.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Fri Oct  3 22:58:11 2003
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sun Jul 31 13:54:58 2005
-// Update Count     : 15
+// Last Modified On : Tue Jul 24 18:00:50 2007
+// Update Count     : 16
 // 
 
 #include <uC++.h>
@@ -61,7 +61,7 @@ void uMain::main() {
 	  if ( area == NULL ) uAbort( "out of memory" );
 	    //cout << setw(6) << i << " " << area << endl;
 	    if ( (size_t)area % alignments[a] != 0 ) {	// must always be correctly aligned
-		uAbort( "bad alignment 0x%p", area );
+		uAbort( "bad alignment memalign 0x%p", area );
 	    } // if
 	    free( area );
 	} // for
@@ -84,7 +84,7 @@ void uMain::main() {
 	  if ( area == NULL ) uAbort( "out of memory" );
 	    //cout << setw(6) << i << " " << area << endl;
 	    if ( (size_t)area % alignments[a] != 0 ) {	// must always be correctly aligned
-		uAbort( "bad alignment 0x%p", area );
+		uAbort( "bad alignment realloc 0x%p", area );
 	    } // if
 	} // for
 	free( area );
