@@ -1,15 +1,15 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 2006
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 2006
 // 
 // CRAII.cc -- Test that deletion of a non-terminated coroutine results in all
 //             objects on its stack to be deallocated.
 // 
 // Author           : Peter A. Buhr
 // Created On       : Thu Feb 23 21:42:16 2006
-// Last Modified By : Roy Krischer
-// Last Modified On : Wed Sep 20 15:40:39 2006
-// Update Count     : 39
+// Last Modified By : Peter A. Buhr
+// Last Modified On : Tue Jun 26 09:12:44 2007
+// Update Count     : 41
 // 
 
 #include <uC++.h>
@@ -17,8 +17,8 @@
 using std::cout;
 using std::endl;
 
-#define NoInTest 4
-#define MaxStackDepth 4
+const unsigned int NoInTest = 4;
+const unsigned int MaxStackDepth = 4;
 
 int check = 0;
 
@@ -38,7 +38,7 @@ _Coroutine CRAII {
     RAII ol[NoInTest];					// object level
 
     void main() {
-	RAII sl[NoInTest];				// stack level
+	RAII sl[NoInTest] __attribute__(( unused ));	// stack level
 
 	cout << " coroutine(" << this << ") starts:" << check << endl;
 
@@ -63,10 +63,10 @@ _Coroutine C {
     void main() {
 	CRAII sl[NoInTest];				// stack level
 
-	for ( int i = 0; i < NoInTest; i += 1 ) {
+	for ( unsigned int i = 0; i < NoInTest; i += 1 ) {
 	    ol[i].mem();				// start coroutines
 	} // for
-	for ( int i = 0; i < NoInTest; i += 1 ) {
+	for ( unsigned int i = 0; i < NoInTest; i += 1 ) {
 	    sl[i].mem();				// start coroutines
 	} // for
 
@@ -83,9 +83,9 @@ bool flags[NoInTest] = { false };
 int idno = 0;
 
 class SRAII {						// silent RAII
-    int id;
+    unsigned int id;
   public:
-    SRAII( int i ) : id( i ) {
+    SRAII( unsigned int i ) : id( i ) {
 	checkarray[i] += 1;
     } // SRAII::SRAII
 
@@ -100,12 +100,12 @@ class SRAII {						// silent RAII
 
 _Task Cancelee {
     SRAII ol;    
-    int id;
+    unsigned int id;
   public:
     Cancelee() : ol( idno ), id( idno ) { idno += 1; }
     
     void main() {
-	for ( int i = 0; i < 100000; i+= 1 ) {
+	for ( unsigned int i = 0; i < 100000; i+= 1 ) {
 	    rec();
 	    assert( checkarray[id] > 0 );
 	} // for
@@ -130,7 +130,7 @@ _Task Cancelee {
 
 
 void uMain::main() {
-    uProcessor p[3];
+    uProcessor processors[3] __attribute__(( unused ));
     { 
 	C c;
 	c.mem();
@@ -139,13 +139,13 @@ void uMain::main() {
     if ( check != 0 ) uAbort( "not all destructors called" );
 
     // Task cancellation test
-    int r;
+
     srand( time(NULL) );
     {
 	Cancelee ca[NoInTest];
 	yield();
 	ca[0].cancel();					// special check for _Disable
-        for ( int i = 1; i < NoInTest; i += 1 ) {
+        for ( unsigned int i = 1; i < NoInTest; i += 1 ) {
 	    if ( rand() %  2 ) {
 		flags[i] = true;
 		ca[i].cancel();
@@ -153,7 +153,7 @@ void uMain::main() {
 	} // for
     }
    
-    for ( int i = 0; i < NoInTest; i += 1 ) {
+    for ( unsigned int i = 0; i < NoInTest; i += 1 ) {
 	if ( checkarray[i] != 0 || ! flags[i] ) uAbort( "unsuccessful task cancellation" );
     } // for
 
