@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.5.0, Copyright (C) Ashif S. Harji 2000
 // 
 // Disinherit.cc -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Mon Feb 14 14:22:08 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jan 12 14:54:51 2006
-// Update Count     : 18
+// Last Modified On : Tue Jun 26 09:15:06 2007
+// Update Count     : 19
 // 
 
 
@@ -117,17 +117,17 @@ _Mutex<uPriorityQ, uPriorityQ> _PeriodicTask<uPIHeap> task2 {
 
 void uMain::main() {
     uDeadlineMonotonic1 rq ;				// create real-time scheduler
-    uRealTimeCluster RTClust( rq );			// create real-time cluster with scheduler
-    uProcessor *p;
+    uRealTimeCluster rtCluster( rq );			// create real-time cluster with scheduler
+    uProcessor *processor;
     {
-	task1 t1( 1, 500, 0, 6, RTClust );
-	task1 t2( 2, 400, 5, 0, RTClust );
-	task1 t3( 3, 300, 15, 0, RTClust );
-	task2 t4( 4, 200, 10, RTClust );
+	task1 t1( 1, 500, 0, 6, rtCluster );
+	task1 t2( 2, 400, 5, 0, rtCluster );
+	task1 t3( 3, 300, 15, 0, rtCluster );
+	task2 t4( 4, 200, 10, rtCluster );
 
-	p = new uProcessor( RTClust );			// now create the processor to do the work
+	processor = new uProcessor( rtCluster );	// now create the processor to do the work
     }
-    delete p;
+    delete processor;
     osacquire( cout ) << "successful completion" << endl;
 } // uMain::main
 
