@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Ashif Harji 2000
+// uC++ Version 5.5.0, Copyright (C) Ashif Harji 2000
 // 
 // Disinherit1.cc -- 
 // 
 // Author           : Ashif Harji
 // Created On       : Sat Mar 11 09:56:27 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jan 12 16:23:18 2006
-// Update Count     : 22
+// Last Modified On : Tue Jun 26 09:15:43 2007
+// Update Count     : 23
 // 
 
 
@@ -117,16 +117,16 @@ _Mutex<uPriorityQ, uPriorityQ> _PeriodicTask<uPIHeap> task2 {
 
 void uMain::main() {
     uDeadlineMonotonic1 rq ;				// create real-time scheduler
-    uRealTimeCluster RTClust( rq );			// create real-time cluster with scheduler
-    uProcessor *p;
+    uRealTimeCluster rtCluster( rq );			// create real-time cluster with scheduler
+    uProcessor *processor;
     {
-	task2 t1( 1, uDuration( 500 ), uDuration( 3 ), RTClust );
-	task1 t2( 2, uDuration( 400 ), uDuration( 3 ), uDuration( 0 ), RTClust );
-	task1 t3( 3, uDuration( 300 ), uDuration( 7 ), uDuration( 0 ), RTClust );
+	task2 t1( 1, uDuration( 500 ), uDuration( 3 ), rtCluster );
+	task1 t2( 2, uDuration( 400 ), uDuration( 3 ), uDuration( 0 ), rtCluster );
+	task1 t3( 3, uDuration( 300 ), uDuration( 7 ), uDuration( 0 ), rtCluster );
 
-	p = new uProcessor( RTClust );			// now create the processor to do the work
+	processor = new uProcessor( rtCluster );	// now create the processor to do the work
     }
-    delete p;
+    delete processor;
     osacquire( cout ) << "successful completion" << endl;
 } // uMain::main
 
