@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Ashif Harji 2000
+// uC++ Version 5.5.0, Copyright (C) Ashif Harji 2000
 // 
 // Disinherit1Static.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Tue Apr 18 17:56:52 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jan 12 16:09:10 2006
-// Update Count     : 18
+// Last Modified On : Tue Jun 26 09:16:24 2007
+// Update Count     : 19
 // 
 
 
@@ -118,17 +118,17 @@ _Mutex<uStaticPriorityQ, uStaticPriorityQ> _PeriodicTask<uStaticPIQ> task2 {
 }; // task2
 
 void uMain::main() {
-    uDeadlineMonotonicStatic rq ;				// create real-time scheduler
-    uRealTimeCluster RTClust( rq );			// create real-time cluster with scheduler
-    uProcessor *p;
+    uDeadlineMonotonicStatic rq ;			// create real-time scheduler
+    uRealTimeCluster rtCluster( rq );			// create real-time cluster with scheduler
+    uProcessor *processor;
     {
-	task2 t1( 1, uDuration( 500 ), uDuration( 3 ), RTClust );
-	task1 t2( 2, uDuration( 400 ), uDuration( 3 ), uDuration( 0 ), RTClust );
-	task1 t3( 3, uDuration( 300 ), uDuration( 7 ), uDuration( 0 ), RTClust );
+	task2 t1( 1, uDuration( 500 ), uDuration( 3 ), rtCluster );
+	task1 t2( 2, uDuration( 400 ), uDuration( 3 ), uDuration( 0 ), rtCluster );
+	task1 t3( 3, uDuration( 300 ), uDuration( 7 ), uDuration( 0 ), rtCluster );
 
-	p = new uProcessor( RTClust );			// now create the processor to do the work
+	processor = new uProcessor( rtCluster );	// now create the processor to do the work
     }
-    delete p;
+    delete processor;
     osacquire( cout ) << "successful completion" << endl;
 } // uMain::main
 
