@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.5.0, Copyright (C) Ashif S. Harji 2000
 // 
 // Disinherit.cc -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Mon Feb 14 14:22:08 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jan 12 16:11:30 2006
-// Update Count     : 33
+// Last Modified On : Tue Jun 26 09:17:18 2007
+// Update Count     : 34
 // 
 
 
@@ -119,20 +119,18 @@ _Mutex<uStaticPriorityQ, uStaticPriorityQ> _PeriodicTask<uStaticPIQ> task2 {
 }; // task2
 
 void uMain::main() {
-    uDeadlineMonotonicStatic rq ;				// create real-time scheduler
-    uRealTimeCluster RTClust( rq );			// create real-time cluster with scheduler
-    uProcessor *p;
+    uDeadlineMonotonicStatic rq ;			// create real-time scheduler
+    uRealTimeCluster rtCluster( rq );			// create real-time cluster with scheduler
+    uProcessor *processor;
     {
-	task1 t1( 1, 500, 0, 6, RTClust );
-	task1 t2( 2, 400, 5, 0, RTClust );
-	task1 t3( 3, 300, 15, 0, RTClust );
-	task2 t4( 4, 200, 10, RTClust );
+	task1 t1( 1, 500, 0, 6, rtCluster );
+	task1 t2( 2, 400, 5, 0, rtCluster );
+	task1 t3( 3, 300, 15, 0, rtCluster );
+	task2 t4( 4, 200, 10, rtCluster );
 
-	//osacquire( cout ) << "Time  \t\tPhilosopher" << endl;
-
-	p = new uProcessor( RTClust );			// now create the processor to do the work
+	processor = new uProcessor( rtCluster );	// now create the processor to do the work
     }
-    delete p;
+    delete processor;
     osacquire( cout ) << "successful completion" << endl;
 } // uMain::main
 
