@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1997
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1997
 // 
 // EHM1.cc -- testing exception handling mechanism
 // 
 // Author           : Peter A. Buhr
 // Created On       : Wed Nov 26 23:06:25 1997
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Aug  6 17:47:33 2005
-// Update Count     : 238
+// Last Modified On : Fri Feb  2 15:28:44 2007
+// Update Count     : 249
 // 
 
 
@@ -22,23 +22,33 @@ using std::endl;
 //######################### uBaseCoroutine::uFailure #########################
 
 
-_ThrowEvent xxx {
+_Event xxx {
   public:
-    xxx( const char *const msg ) : uEHM::uThrowClass( msg ) {}
+    xxx( const char *const msg ) : uBaseEvent( msg ) {}
 };
 
+_Event yyy {
+  public:
+    yyy( const char *msg ) { setMsg( msg ); }
+};
 
 _Coroutine CoroutineDummy1 {
+    bool res;
     void main() {
-	_Throw xxx( "test" );
+	if ( res ) {
+	    _Resume yyy( "resume test" );
+	} else {
+	    _Throw xxx( "throw test" );
+	} // if
     } // CoroutineDummy1::main
   public:
+    CoroutineDummy1( bool r ) : res( r ) {}
     void mem() { resume(); }
 }; // CoroutineDummy1
 
 _Coroutine CoroutineDummy2 {
     void main() {
-	CoroutineDummy1 dummy1;
+	CoroutineDummy1 dummy1( false );
 	dummy1.mem();
     } // CoroutineDummy1::main
   public:
@@ -70,8 +80,8 @@ _Task TaskDummy2 {
 #endif
 	try {
 	    t1.mem();
-	} catch( uCondition::WaitingFailure &evt ) {
-	    osacquire( cout ) << "handled exception uCondition::WaitingFailure : task " << evt.source().getName() << " (" << &(evt.source()) << ") found blocked task" << " " << uThisTask().getName() << " (" << &uThisTask() << ") on condition variable " << &evt.conditionId() << endl << endl;
+	} catch( uCondition::WaitingFailure &ex ) {
+	    osacquire( cout ) << "handled exception uCondition::WaitingFailure : task " << ex.source().getName() << " (" << &(ex.source()) << ") found blocked task" << " " << uThisTask().getName() << " (" << &uThisTask() << ") on condition variable " << &ex.conditionId() << endl << endl;
 	} // try
     } // TaskDummy2::main
   public:
@@ -96,8 +106,8 @@ _Task TaskDummy3 {
 #endif
 	try {
 	    _Accept( mem );
-	} catch ( uSerial::RendezvousFailure &evt ) {
-	    osacquire( cout ) << "handled exception uSerial::RendezvousFailure : accepted call fails from task " << evt.sourceName() << " (" << &(evt.source()) << ") to mutex member of task " << uThisTask().getName() << " (" << &uThisTask() << ")" << endl << endl;
+	} catch ( uSerial::RendezvousFailure &ex ) {
+	    osacquire( cout ) << "handled exception uSerial::RendezvousFailure : accepted call fails from task " << ex.sourceName() << " (" << &(ex.source()) << ") to mutex member of task " << uThisTask().getName() << " (" << &uThisTask() << ")" << endl << endl;
 	} // try
     } // TaskDummy3::main
 }; // TaskDummy3
@@ -131,10 +141,10 @@ _Task TaskDummy5 {
 #endif
 	try {
 	    t4.mem();
-	} catch( uSerial::EntryFailure &evt ) {
-	    osacquire( cout ) << "handled exception uSerial::EntryFailure : while executing mutex destructor, task " << evt.source().getName() << " (" << &(evt.source()) << ") found task " << uThisTask().getName() << " (" << &uThisTask() << ") " << evt.message() << endl << endl;
+	} catch( uSerial::EntryFailure &ex ) {
+	    osacquire( cout ) << "handled exception uSerial::EntryFailure : while executing mutex destructor, task " << ex.source().getName() << " (" << &(ex.source()) << ") found task " << uThisTask().getName() << " (" << &uThisTask() << ") " << ex.message() << endl << endl;
 	} catch( ... ) {
-	    uAbort( "error" );
+	    uAbort( "EHM1 error" );
 	} // try
     } // TaskDummy5::main
 }; // TaskDummy5
@@ -164,26 +174,35 @@ _Task TaskDummy7 {
 #endif
 	try {
 	    t6.mem();
-	} catch( uSerial::EntryFailure &evt ) {
-	    osacquire( cout ) << "handled exception uSerial::EntryFailure : while executing mutex destructor, task " << evt.source().getName() << " (" << &(evt.source()) << ") found task " << uThisTask().getName() << " (" << &uThisTask() << ") " << evt.message() << endl << endl;
+	} catch( uSerial::EntryFailure &ex ) {
+	    osacquire( cout ) << "handled exception uSerial::EntryFailure : while executing mutex destructor, task " << ex.source().getName() << " (" << &(ex.source()) << ") found task " << uThisTask().getName() << " (" << &uThisTask() << ") " << ex.message() << endl << endl;
 	} catch( ... ) {
-	    uAbort( "error" );
+	    uAbort( "EHM1 error" );
 	} // try
     } // TaskDummy7::main
 }; // TaskDummy7
 
+void unHandledHandler( uBaseCoroutine::UnhandledException & e ) {
+    osacquire( cout ) << "Now triggering embedded UnhandledException" << endl;    
+    e.triggerCause();
+}
+
 
 void uMain::main() {
-    //######################### uBaseCoroutine::UnHandledException #########################
+    //######################### uBaseCoroutine::UnhandledException #########################
     {
-	CoroutineDummy1 dummy1;
+	CoroutineDummy1 dummy1( true );
 
 	try {
 	    dummy1.mem();
-	} catch( uBaseCoroutine::UnHandledException &evt ) {
-	    osacquire( cout ) << "handled exception uBaseCoroutine::UnHandledException : in coroutine " << uThisCoroutine().getName() << " (" << &uThisCoroutine() << ") raised non-locally from resumed coroutine " << evt.sourceName() << " (" << &(evt.source()) << "), which was terminated due to an " << evt.message() << endl << endl;
+	} catch( uBaseCoroutine::UnhandledException &ex ) {
+	    osacquire( cout ) << "handled exception uBaseCoroutine::UnhandledException : in coroutine " << uThisCoroutine().getName() << " (" << &uThisCoroutine() << ") raised non-locally from resumed coroutine " << ex.sourceName() << " (" << &(ex.source()) << "), which was terminated due to an " << ex.message() << endl << endl;
+	    try <yyy> {
+		ex.triggerCause();
+		osacquire( cout ) << "after trigger" << endl;
+	    } // try
 	} catch( ... ) {
-	    uAbort( "error" );
+	    uAbort( "EHM1 error" );
 	} // try
     }
     {
@@ -191,10 +210,19 @@ void uMain::main() {
 
 	try {
 	    dummy2.mem();
-	} catch( uBaseCoroutine::UnHandledException &evt ) {
-	    osacquire( cout ) << "handled exception uBaseCoroutine::UnHandledException : in coroutine " << uThisCoroutine().getName() << " (" << &uThisCoroutine() << ") raised non-locally from resumed coroutine " << evt.sourceName() << " (" << &(evt.source()) << "), which was terminated due to a series of unhandled exceptions -- originally " << evt.message() << " inside coroutine " << evt.origName() << " (" << &(evt.origSource()) << ")." << endl << endl;
+	} catch( uBaseCoroutine::UnhandledException &ex ) {
+	    osacquire( cout ) << "handled exception uBaseCoroutine::UnhandledException : in coroutine " << uThisCoroutine().getName() << " (" << &uThisCoroutine() << ") raised non-locally from resumed coroutine " << ex.sourceName() << " (" << &(ex.source()) << "), which was terminated due to a series of unhandled exceptions -- originally " << ex.message() << " inside coroutine " << ex.origName() << " (" << &(ex.origSource()) << ")." << endl << endl;
+
+	    osacquire( cout ) << "Now triggering exception" << endl;
+	    try <uBaseCoroutine::UnhandledException, unHandledHandler> {
+		ex.triggerCause();
+	    } catch ( xxx &ex ) {
+		osacquire( cout ) << "caught xxx : " << ex.message() << endl;
+	    } catch ( ... ) {
+		uAbort("EHM1 error");
+	    } // try
 	} catch( ... ) {
-	    uAbort( "error" );
+	    uAbort( "EHM1 error" );
 	} // try
     }
     //######################### uCondition::uWaitingFailure #########################
@@ -211,9 +239,9 @@ void uMain::main() {
 	    _Enable {
 		t3.mem();
 	    } // _Enable
-	} catch( xxx &evt ) {
+	} catch( xxx &ex ) {
 	} catch( ... ) {
-	    uAbort( "error" );
+	    uAbort( "EHM1 error" );
 	} // try
     }
     //######################### uSerial::uEntryFailure (acceptor/signalled stack) #########################
