@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 2004
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 2004
 // 
 // EHM10.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Mar 22 21:17:24 2004
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Nov 21 15:25:53 2005
-// Update Count     : 11
+// Last Modified On : Fri Feb  2 08:12:49 2007
+// Update Count     : 12
 // 
 
 #include <uC++.h>
@@ -16,13 +16,13 @@
 using std::cout;
 using std::endl;
 
-_ResumeEvent R1 {
+_Event R1 {
   public:
 	int &i;
 	R1( int &i ) : i(i) {}
 };
 
-_ResumeEvent R2 {
+_Event R2 {
   public:
 	int &i;
 	R2( int &i ) : i(i) {}
