@@ -1,25 +1,25 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1998
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1998
 // 
 // EHM2.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Tue Oct 27 21:24:48 1998
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Sep 12 08:08:53 2006
-// Update Count     : 29
+// Last Modified On : Tue Jun 26 09:10:12 2007
+// Update Count     : 32
 // 
 
 #include <uC++.h>
 
-_ThrowEvent xxx {
+_Event xxx {
   public:
     uBaseTask *tid;
     xxx( uBaseTask *tid ) : tid(tid) {}
 };
 
-_ThrowEvent yyy {
+_Event yyy {
   public:
     uBaseTask *tid;
     yyy( uBaseTask *tid ) : tid(tid) {}
@@ -62,8 +62,8 @@ _Task fred {
     } // fred::t
     
     void main() {
-//	for ( int i = 0; i < 5000; i += 1 ) {
-	for ( int i = 0; i < 5; i += 1 ) {
+	for ( int i = 0; i < 5000; i += 1 ) {
+//	for ( int i = 0; i < 5; i += 1 ) {
 	    try {
 		t( 5 );
 	    } catch( yyy e ) {
@@ -74,6 +74,6 @@ _Task fred {
 }; // fred
 
 void uMain::main() {
-    uProcessor p[3];
+    uProcessor processors[3] __attribute__(( unused ));	// more than one processor
     fred f[4] __attribute__(( unused ));
 } // uMain::main
