@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1998
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1998
 // 
 // EHM3.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Tue Oct 27 21:24:48 1998
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Nov 21 15:25:35 2005
-// Update Count     : 41
+// Last Modified On : Fri Feb  2 08:13:51 2007
+// Update Count     : 43
 // 
 
 #include <uC++.h>
@@ -17,23 +17,23 @@ using std::cout;
 using std::osacquire;
 using std::endl;
 
-_ResumeEvent R1 {
+_Event R1 {
   public:
-	int &i; char &c;
-	R1( int &i, char &c ) : i( i ), c( c ) {}
+	double &i; char &c;
+	R1( double &i, char &c ) : i( i ), c( c ) {}
 };
 
-_ResumeEvent R2 {};
+_Event R2 {};
 
-_DualEvent R3 {};
+_Event R3 {};
 
 
-void f( int x, char y ) {
+void f( double x, char y ) {
 	osacquire( cout ) << "enter f, x:" << x << " y:" << y << endl;
 	_Resume R2();
 	osacquire( cout ) << "exit f, x:" << x << " y:" << y << endl;
 }
-void g( int &x, char &y ) {
+void g( double &x, char &y ) {
 	osacquire( cout ) << "enter g, x:" << x << " y:" << y << endl;
 	_Resume R1( x, y );
 	osacquire( cout ) << "exit g, x:" << x << " y:" << y << endl;
@@ -41,15 +41,15 @@ void g( int &x, char &y ) {
 
 void rtn1( R1 &r ) {
 	osacquire( cout ) << "rtn1" << endl;
-	r.i = 1; r.c = 'b';
+	r.i = 1.5; r.c = 'b';
 }
 
 struct Rtn2 {
-	int &i; char &c;
-	Rtn2( int &i, char &c ) : i( i ), c( c ) {}
+	double &i; char &c;
+	Rtn2( double &i, char &c ) : i( i ), c( c ) {}
 	void operator()( R2 &r ) {
 		osacquire( cout ) << "rtn2, i:" << i << " c:" << c << endl;
-		i = 2; c = 'c';									// change x, y
+		i = 2.5; c = 'c';								// change x, y
 	}
 };
 
@@ -61,7 +61,7 @@ struct Any{
 }; // Any
 
 
-_DualEvent D {};
+_Event D {};
 
 class R {
     uBaseTask &p;
@@ -141,7 +141,7 @@ _Task T2 {
 
 
 void uMain::main() {
-	int x = 0;
+	double x = 0.5;
 	char y = 'a';
 	try <R1,rtn1> {
 		Rtn2 rtn2( x, y );								// closure for locals
