@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Roy Krischer 2002
+// uC++ Version 5.5.0, Copyright (C) Roy Krischer 2002
 // 
 // EHM4.cc -- 
 // 
 // Author           : Roy Krischer
 // Created On       : Tue Mar 26 23:01:30 2002
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Sep 12 08:08:45 2006
-// Update Count     : 139
+// Last Modified On : Tue Jun 26 09:17:56 2007
+// Update Count     : 142
 // 
 
 #include <uC++.h>
@@ -56,10 +56,10 @@ uBarrier b( NTASK + 1 );								// control start and finish of main/worker tasks
 worker *f[NTASK];										// shared resource controlled by barrier
 
 
-_ResumeEvent rev {
+_Event rev {
   public:
     int ticket;
-    rev( const char *msg, int ticket ) : uResumeClass(msg), ticket(ticket) {};
+    rev( const char *msg, int ticket ) : ticket( ticket ) { setMsg( msg ); }
 };
 
 class Arg {
@@ -113,7 +113,7 @@ void worker::main() {
 
 
 void uMain::main () {
-    uProcessor p[4];
+    uProcessor processors[4] __attribute__(( unused ));	// more than one processor
 
     for ( int i = 0; i < NTASK; i += 1 ) {
 		f[i] = new worker( i );
