@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 2002
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 2002
 // 
 // EHM5.cc -- 
 // 
 // Author           : Roy Krischer
 // Created On       : Sun Nov 24 12:34:43 2002
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sun Jul 31 17:09:01 2005
-// Update Count     : 14
+// Last Modified On : Fri Feb  2 08:15:42 2007
+// Update Count     : 15
 // 
 
 #include <uC++.h>
@@ -16,7 +16,7 @@
 using std::cout;
 using std::endl;
 
-_ThrowEvent fred {
+_Event fred {
   public:
     int k;
     fred ( int k ) : k(k) {}
