@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1998
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1998
 // 
 // EHM6.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Tue Oct 27 21:24:48 1998
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Nov 21 15:25:45 2005
-// Update Count     : 25
+// Last Modified On : Fri Feb  2 08:16:09 2007
+// Update Count     : 26
 // 
 
 #include <uC++.h>
@@ -17,13 +17,13 @@ using std::cout;
 using std::osacquire;
 using std::endl;
 
-_ResumeEvent R1 {
+_Event R1 {
   public:
 	int &i; char &c;
 	R1( int &i, char &c ) : i( i ), c( c ) {}
 };
 
-_ResumeEvent R2 {};
+_Event R2 {};
 
 
 class fred {
