@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 2002
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 2002
 // 
 // EHM7.cc -- 
 // 
 // Author           : Roy Krischer
 // Created On       : Sun Nov 24 12:42:34 2002
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Sep 12 08:09:20 2006
-// Update Count     : 25
+// Last Modified On : Fri Feb  2 08:16:32 2007
+// Update Count     : 26
 // 
 
 #include <uC++.h>
@@ -17,7 +17,7 @@ using std::cout;
 using std::osacquire;
 using std::endl;
 
-_ThrowEvent fred {
+_Event fred {
   public:
     int k;
     fred ( int k ) : k(k) {}
