@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 2003
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 2003
 // 
 // EHM8.cc -- 
 // 
 // Author           : Roy Krischer
 // Created On       : Wed Oct  8 22:02:29 2003
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Sep 12 08:09:27 2006
-// Update Count     : 55
+// Last Modified On : Tue Jun 26 09:18:29 2007
+// Update Count     : 57
 // 
 
 #include <uC++.h>
@@ -20,8 +20,8 @@ using std::endl;
 #define ROUNDS  10000
 #define NP 9 
 
-_ThrowEvent E1 {};
-_ThrowEvent E2 {};
+_Event E1 {};
+_Event E2 {};
 
 
 void one() {
@@ -109,7 +109,7 @@ _Task mary {
 };
 
 void uMain::main() {
-    uProcessor p[NP];
+    uProcessor processors[NP] __attribute__(( unused )); // more than one processor
     fred *f[NP];
     int i;
 
