@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 2003
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 2003
 // 
 // EHM9.cc -- recursive resumption
 // 
 // Author           : Peter A. Buhr
 // Created On       : Sun Dec  7 12:15:30 2003
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Nov 21 15:26:01 2005
-// Update Count     : 33
+// Last Modified On : Fri Feb  2 08:17:23 2007
+// Update Count     : 34
 // 
 
 #include <uC++.h>
@@ -17,8 +17,8 @@ using std::cout;
 using std::osacquire;
 using std::endl;
 
-_ResumeEvent R1 {};
-_ResumeEvent R2 {};
+_Event R1 {};
+_Event R2 {};
 
 
 void H1( R2 ) {
