@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1994
 // 
 // ServerUNIX.cc -- Server for UNIX/stream socket test. Server accepts multiple
 // connections from clients. Each client then communicates with an acceptor.
@@ -9,8 +9,8 @@
 // Author           : Peter A. Buhr
 // Created On       : Tue Jan  7 08:40:22 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Sep  2 09:21:56 2006
-// Update Count     : 138
+// Last Modified On : Tue Sep 11 08:33:20 2007
+// Update Count     : 140
 // 
 
 #include <uC++.h>
@@ -31,7 +31,7 @@ _Task acceptor {
 
 	void main();
   public:
-	acceptor( uSocketServer &socks, server &s ) : uBaseTask( 64000 ), sockserver( socks ), s( s ) {
+	acceptor( uSocketServer &socks, server &s ) : sockserver( socks ), s( s ) {
 	} // acceptor::acceptor
 }; // acceptor
 
@@ -58,7 +58,7 @@ _Task server {
 			_Accept( connection ) {
 				new acceptor( sockserver, *this );		// create new acceptor after a connection
 				acceptorCnt += 1;
-			} else _Accept( complete ) {				// acceptor has completed with client
+			} or _Accept( complete ) {					// acceptor has completed with client
 				delete terminate;						// delete must appear here or deadlock
 				acceptorCnt -= 1;
 		  if ( acceptorCnt == 0 ) break;				// if no outstanding connections, stop
