@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1994
 // 
 // Inheritance.cc -- test inheritance of tasks
 // 
@@ -47,8 +47,8 @@ void super::main() {
     for ( ;; ) {
 	_Accept( ~super ) {
 	    break;
-	} else _Accept( fred ) {
-	} else _Accept( mary ) {
+	} or _Accept( fred ) {
+	} or _Accept( mary ) {
 	} // accept
     } // for
     osacquire( cout ) << "super::main terminating" << endl;
@@ -82,9 +82,9 @@ void sub::main() {
     for ( ;; ) {
 	_Accept( ~sub ) {
 	    break;
-	} else _Accept( fred ) {
-	} else _Accept( mary ) {
-	} else _Accept( jane ) {
+	} or _Accept( fred ) {
+	} or _Accept( mary ) {
+	} or _Accept( jane ) {
 	} // accept
     } // for
     osacquire( cout ) << "sub::main terminating" << endl;
