@@ -1,24 +1,23 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 2001
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 2001
 // 
 // Locks.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Dec 10 15:08:22 2001
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Aug  5 14:46:01 2005
-// Update Count     : 27
+// Last Modified On : Tue Jun 26 09:18:59 2007
+// Update Count     : 30
 // 
 
 #include <uC++.h>
 #include <uSemaphore.h>
-#include <pthread.h>
 #include <iostream>
 using std::cout;
 using std::endl;
 
-const int NoOfTimes = 50000;
+const unsigned int NoOfTimes = 50000;
 
 uOwnerLock sharedLock;
 volatile uBaseTask *checkID;
@@ -26,7 +25,7 @@ uSemaphore start(0);
 
 _Task testerOL_AR {
     void main() {
-	for ( int i = 0; i < NoOfTimes; i += 1 ) {
+	for ( unsigned int i = 0; i < NoOfTimes; i += 1 ) {
 	    sharedLock.acquire();
 	    checkID = &uThisTask();
 	    yield();
@@ -47,12 +46,12 @@ _Task testerOL_AR {
 
 _Task testerOL_TAR {
     void main() {
-	for ( int i = 0; i < 100; i += 1 ) {
+	for ( unsigned int i = 0; i < 100; i += 1 ) {
 	    while ( ! sharedLock.tryacquire() ) yield();
 	    checkID = &uThisTask();
 	    yield();
 	    if ( checkID != &uThisTask() ) uAbort( "interference" );
-	    if ( ! sharedLock.tryacquire() )  uAbort( "interference" );
+	    if ( ! sharedLock.tryacquire() ) uAbort( "interference" );
 	    if ( checkID != &uThisTask() ) uAbort( "interference" );
 	    yield();
 	    if ( checkID != &uThisTask() ) uAbort( "interference" );
@@ -69,7 +68,7 @@ _Task testerOL_TAR {
 class monitor {
     uCondLock cond1, cond2;
     uOwnerLock lock;
-    int cnt;
+    unsigned int cnt;
   public:
     monitor() { cnt = 0; }
     void mS2W1() {
@@ -77,10 +76,8 @@ class monitor {
 	lock.acquire();
 	lock.acquire();
 	if ( ! cond2.empty() ) {
-//	    cerr << "signal2" << endl;
 	    cond2.signal();
 	} else {
-//	    cerr << "wait1" << endl;
 	    cond1.wait( lock );
 	}
 	lock.release();
@@ -90,10 +87,8 @@ class monitor {
     void mLS1W2() {
 	lock.acquire();
 	if ( ! cond1.empty() ) {
-//	    cerr << "signal1" << endl;
 	    cond1.signal();
 	} else {
-//	    cerr << "wait2" << endl;
 	    cond2.wait( lock );
 	}
 	lock.release();
@@ -135,7 +130,7 @@ class monitor {
 _Task testerCL_S2W1 {
     monitor &m;
     void main() {
-	for ( int i = 0; i < NoOfTimes; i += 1 ) {
+	for ( unsigned int i = 0; i < NoOfTimes; i += 1 ) {
 	    m.mS2W1();
 	    yield(2);
 	} // for
@@ -147,7 +142,7 @@ _Task testerCL_S2W1 {
 _Task testerCL_S1W2 {
     monitor &m;
     void main() {
-	for ( int i = 0; i < NoOfTimes; i += 1 ) {
+	for ( unsigned int i = 0; i < NoOfTimes; i += 1 ) {
 	    m.mLS1W2();
 	    yield(2);
 	} // for
@@ -159,7 +154,7 @@ _Task testerCL_S1W2 {
 _Task testerCL_LB {
     monitor &m;
     void main() {
-	for ( int i = 0; i < NoOfTimes; i += 1 ) {
+	for ( unsigned int i = 0; i < NoOfTimes; i += 1 ) {
 	    start.P();
 	    m.mLB();
 	    yield(2);
@@ -172,7 +167,7 @@ _Task testerCL_LB {
 _Task testerCL_LWSem {
     monitor &m;
     void main() {
-	for ( int i = 0; i < NoOfTimes; i += 1 ) {
+	for ( unsigned int i = 0; i < NoOfTimes; i += 1 ) {
 	    m.mLWSem();
 	    yield(2);
 	} // for
@@ -184,7 +179,7 @@ _Task testerCL_LWSem {
 _Task testerCL_LW {
     monitor &m;
     void main() {
-	for ( int i = 0; i < NoOfTimes; i += 1 ) {
+	for ( unsigned int i = 0; i < NoOfTimes; i += 1 ) {
 	    m.mLW();
 	    yield(2);
 	} // for
@@ -224,13 +219,13 @@ _Task testerCL_B {
 };
 
 void uMain::main() {
-    uProcessor p;
+    uProcessor processor[1] __attribute__(( unused ));	// more than one processor
 #if 1
     {							// test uOwnerLock
 	testerOL_AR t1[2] __attribute__(( unused ));
 	testerOL_TAR t2[2] __attribute__(( unused ));
 
-	for ( int i = 0; i < NoOfTimes; i += 1 ) {
+	for ( unsigned int i = 0; i < NoOfTimes; i += 1 ) {
 	    sharedLock.acquire();
 	    yield();
 	    sharedLock.release();
@@ -250,13 +245,13 @@ void uMain::main() {
 #endif
 #if 1
 	{						// signal/wait
-	    const int N = 5;
+	    const unsigned int N = 5;
 	    testerCL_S t1( m );
 	    testerCL_LW *ti[N];
-	    for ( int i = 0; i < N; i += 1 ) {
+	    for ( unsigned int i = 0; i < N; i += 1 ) {
 		ti[i] = new testerCL_LW(m);
 	    } // for
-	    for ( int i = 0; i < N; i += 1 ) {
+	    for ( unsigned int i = 0; i < N; i += 1 ) {
 		delete ti[i];
 	    } // for
 	}
@@ -264,13 +259,13 @@ void uMain::main() {
 #endif
 #if 1
 	{						// broadcast/wait
-	    const int N = 3;
+	    const unsigned int N = 3;
 	    testerCL_LB t1( m );
 	    testerCL_LWSem *ti[N];
-	    for ( int i = 0; i < N; i += 1 ) {
+	    for ( unsigned int i = 0; i < N; i += 1 ) {
 		ti[i] = new testerCL_LWSem(m);
 	    } // for
-	    for ( int i = 0; i < N; i += 1 ) {
+	    for ( unsigned int i = 0; i < N; i += 1 ) {
 		delete ti[i];
 	    } // for
 	}
@@ -278,13 +273,13 @@ void uMain::main() {
 #endif
 #if 1
 	{						// broadcast/wait
-	    const int N = 5;
+	    const unsigned int N = 5;
 	    testerCL_B t1( m );
 	    testerCL_LW *ti[N];
-	    for ( int i = 0; i < N; i += 1 ) {
+	    for ( unsigned int i = 0; i < N; i += 1 ) {
 		ti[i] = new testerCL_LW(m);
 	    } // for
-	    for ( int i = 0; i < N; i += 1 ) {
+	    for ( unsigned int i = 0; i < N; i += 1 ) {
 		delete ti[i];
 	    } // for
 	}
