@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Philipp E. Lim and Ashif S. Harji 1996
+// uC++ Version 5.5.0, Copyright (C) Philipp E. Lim and Ashif S. Harji 1996
 // 
 // PeriodicTaskTest.cc -- 
 // 
 // Author           : Philipp E. Lim and Ashif S. Harji
 // Created On       : Tue Jul 23 14:48:37 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Dec  3 09:43:23 2005
-// Update Count     : 137
+// Last Modified On : Tue Jun 26 10:50:44 2007
+// Update Count     : 138
 // 
 
 // When run multiprocessor, migration to the system cluster to perform I/O
@@ -98,19 +98,19 @@ _Mutex<uPriorityQ, uPriorityQ> _PeriodicTask<uPIHeap> TestTask {
 
 void uMain::main() {
     uDeadlineMonotonic1 rq;				// create real-time scheduler
-    uRealTimeCluster RTClust( rq );			// create real-time cluster with scheduler
-    uProcessor *p;
+    uRealTimeCluster rtCluster( rq );			// create real-time cluster with scheduler
+    uProcessor *processor;
     {
-	TestTask t1( 1, 15, 5, RTClust );
-	TestTask t2( 2, 30, 9, RTClust );
-	TestTask t3( 3, 60, 19, RTClust );
+	TestTask t1( 1, 15, 5, rtCluster );
+	TestTask t2( 2, 30, 9, rtCluster );
+	TestTask t3( 3, 60, 19, rtCluster );
 
 	osacquire( cout ) << "Time  \t\tTaskID" << endl;
 
 	::Start = uThisProcessor().getClock().getTime();
-	p = new uProcessor( RTClust );			// now create the processor to do the work
+	processor = new uProcessor( rtCluster );	// now create the processor to do the work
     } // wait for t1, t2, t3 to finish
-    delete p;
+    delete processor;
     cout << "successful completion" << endl;
 } // uMain::main
 
