@@ -5,7 +5,7 @@ using std::endl;
 
 volatile bool stop = false;
 
-_Task T {
+_Task Worker {
     void main() {
 	while ( ! stop ) {
 	    yield();
@@ -14,25 +14,25 @@ _Task T {
 };
 
 void uMain::main() {
-    uProcessor *p2 = NULL;
+    uProcessor *processor2 = NULL;
     {
-	T t[2];
+	Worker tasks[2];
 
-	uProcessor *p1 = new uProcessor();
+	uProcessor *processor1 = new uProcessor();
 
-	while ( &uThisProcessor() != p1 ) {
+	while ( &uThisProcessor() != processor1 ) {
 	    yield();
 	} // while
 
-	p2 = new uProcessor();
+	processor2 = new uProcessor();
 
-//	delete p2;
-	delete p1;
+//	delete processor2;
+	delete processor1;
 
 	stop = true;
     }
     cout << "here" << endl;
-    delete p2;
+    delete processor2;
 } // uMain::main
 
 // Local Variables: //
