@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Philipp E. Lim and Ashif S. Harji 1996
+// uC++ Version 5.5.0, Copyright (C) Philipp E. Lim and Ashif S. Harji 1996
 // 
 // RealTimePhilosophers.cc -- 
 // 
 // Author           : Philipp E. Lim and Ashif S. Harji
 // Created On       : Tue Jul 23 14:58:56 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Dec  3 09:45:08 2005
-// Update Count     : 105
+// Last Modified On : Tue Jun 26 10:55:22 2007
+// Update Count     : 106
 // 
 
 // When run multiprocessor, migration to the system cluster to perform I/O
@@ -136,20 +136,20 @@ _Mutex<uStaticPriorityQ, uStaticPriorityQ> _PeriodicTask<uStaticPIQ> Philosopher
 
 void uMain::main() {
     uDeadlineMonotonicStatic rq ;			 // create real-time scheduler
-    uRealTimeCluster RTClust( rq );			// create real-time cluster with scheduler
-    uProcessor *p;
+    uRealTimeCluster rtCluster( rq );			// create real-time cluster with scheduler
+    uProcessor *processor;
     {
-	Philosopher t1( 1, 20, 2, 2, RTClust );
-	Philosopher t2( 2, 30, 4, 3, RTClust );
-	Philosopher t3( 3, 40, 6, 4, RTClust );
-	Philosopher t4( 4, 50, 8, 5, RTClust );
+	Philosopher t1( 1, 20, 2, 2, rtCluster );
+	Philosopher t2( 2, 30, 4, 3, rtCluster );
+	Philosopher t3( 3, 40, 6, 4, rtCluster );
+	Philosopher t4( 4, 50, 8, 5, rtCluster );
 
 	osacquire( cout ) << "Time  \t\tPhilosopher" << endl;
 
 	::Start = uThisProcessor().getClock().getTime();
-	p = new uProcessor( RTClust );			// now create the processor to do the work
+	processor = new uProcessor( rtCluster );	// now create the processor to do the work
     }
-    delete p;
+    delete processor;
     osacquire( cout ) << "successful completion" << endl;
 } // uMain::main
 
