@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.5.0, Copyright (C) Ashif S. Harji 2000
 // 
 // SRC3.cc -- 
 // 
@@ -56,8 +56,8 @@ void SRC::Hold() {
 void SRC::Resume() {
 	while ( ! Locked ) {								// assume Resume never accepted if outstanding allocate
 		_Accept( Hold ) {
-		} else _When( Free > 0 ) _Accept( Allocate ) {
-		} else _Accept( Deallocate ) {
+		} or _When( Free > 0 ) _Accept( Allocate ) {
+		} or _Accept( Deallocate ) {
 		} // _Accept
 	} // while
 	osacquire( cout ) << &uThisTask() << " Resume,     Free:" << Free << " Taken:" << Taken << endl;
@@ -77,8 +77,8 @@ void SRC::Allocate( unsigned int N = 1 ) {
 	osacquire( cout ) << &uThisTask() << " Allocate(" << N << "), enter, Free:" << Free << " Taken:" << Taken << endl;
 	while ( Locked || ! Free > 0 ) {
 		_When ( ! Locked ) _Accept( Hold ) {
-		} else _When ( Locked ) _Accept( Resume ) {
-		} else _Accept( Deallocate ) {
+		} or _When ( Locked ) _Accept( Resume ) {
+		} or _Accept( Deallocate ) {
 		} // _Accept
 	} // while	
 	Free -= N;
