@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.5.0, Copyright (C) Ashif S. Harji 2000
 // 
 // SRC4.cc -- 
 // 
@@ -82,8 +82,8 @@ void SRC::Hold() {
 void SRC::Resume() {
 	while ( ! Locked ) {    // assume resume never accepted if outstanding allocate
 		_Accept( Hold ) {
-		} else _When( Free > 0 ) _Accept( Allocate ) {
-		} else _Accept( Deallocate ) {
+		} or _When( Free > 0 ) _Accept( Allocate ) {
+		} or _Accept( Deallocate ) {
 		} // _Accept
 	} // while
 	osacquire( cout ) << &uThisTask() << " Resume,     Free:" << Free << " Taken:" << Taken << " Waiting:" << list.empty() << endl;
