@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1994
 // 
 // TaskAcceptBB.cc -- Generic bounded buffer using a task
 // 
@@ -44,10 +44,10 @@ template<typename ELEMTYPE> _Task BoundedBuffer {
 		for ( ;; ) {
 			_Accept( ~BoundedBuffer )
 				break;
-			else _When ( count != size ) _Accept( insert ) {
+			or _When ( count != size ) _Accept( insert ) {
 				back = ( back + 1 ) % size;
 				count += 1;
-			} else _When ( count != 0 ) _Accept( remove ) {
+			} or _When ( count != 0 ) _Accept( remove ) {
 				front = ( front + 1 ) % size;
 				count -= 1;
 			} // _Accept
