@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1999
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1999
 // 
 // TaskConditionBB.cc -- Generic bounded buffer using a task
 // 
@@ -54,7 +54,7 @@ template<typename ELEMTYPE> _Task BoundedBuffer {
 		for ( ;; ) {
 			_Accept( ~BoundedBuffer ) {
 				break;
-			} else _Accept( insert, remove ) {
+			} or _Accept( insert, remove ) {
 			} // _Accept
 		} // for
 	} // BoundedBuffer::main
