@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Philipp E. Lim and Ashif S. Harji 1995, 1997
+// uC++ Version 5.5.0, Copyright (C) Philipp E. Lim and Ashif S. Harji 1995, 1997
 // 
 // uAlarm.h -- 
 // 
 // Author           : Philipp E. Lim
 // Created On       : Thu Dec 21 14:01:24 1995
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jan 24 13:14:38 2006
-// Update Count     : 170
+// Last Modified On : Thu Jul 12 16:22:19 2007
+// Update Count     : 178
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -29,8 +29,12 @@
 #define __U_ALARM_H__
 
 
-class uSignalHandler;					// forward declaration
-
+class uSignalHandler;					// forward declarations
+namespace UPP {
+    _Coroutine uProcessorKernel;
+    class uSemaphore;
+    class uNBIO;
+} // UPP
 
 //######################### uEventNode #########################
 
@@ -39,13 +43,14 @@ class uEventNode : public uSeqable {
     friend class uEventList;				// access: everything
     friend class uProcEventList;			// access: constructor
     friend class uEventListPop;				// access: everything
-    friend _Coroutine uProcessorKernel;			// access: timerT, private constructor
+    friend _Coroutine UPP::uProcessorKernel;		// access: timerT, private constructor
     friend class uBaseTask;				// access: everything
     friend class uSerial;				// access: everything
-    friend class uNBIO;					// access: everything
+    friend class UPP::uNBIO;				// access: everything
     friend class uKernelBoot;                           // access: new
     friend class uProcessor;                            // access: new
     friend class uCondLock;				// access: everything
+    friend class UPP::uSemaphore;			// access: everything
 
     uTime timerT;					// time when alarm goes off (in internal clock time)
     uDuration timerD;					// if periodic, timerD contains period of alarm (after timerT)
@@ -69,10 +74,10 @@ class uEventNode : public uSeqable {
 
 
 class uEventList {
-    friend _Coroutine uProcessorKernel;			// access: new
+    friend _Coroutine UPP::uProcessorKernel;		// access: new
     friend class uSerial;				// access: addEvent, removeEvent
     friend class uCondLock;				// access: addEvent, removeEvent
-    friend class uNBIO;					// access: addEvent, removeEvent, uNextAlarm
+    friend class UPP::uNBIO;				// access: addEvent, removeEvent, uNextAlarm
     friend class uBaseTask;				// access: addEvent
     friend class uCluster;				// access: uNextAlarm
     friend class uKernelBoot;				// access: new
