@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1996
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1996
 // 
 // uBaseTask.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Jan  8 16:14:20 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Sep 21 18:15:32 2006
-// Update Count     : 263
+// Last Modified On : Thu Jul 12 16:32:24 2007
+// Update Count     : 268
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -34,6 +34,9 @@
 //#include <uDebug.h>
 
 
+using namespace UPP;
+
+
 //######################### uBaseTask #########################
 
 
@@ -165,10 +168,16 @@ void uBaseTask::uYieldNoPoll() {
     } // if
 #endif // __U_DEBUG__
 
-    uSCHEDULE( this );					// find someone else to execute; wake on kernel stack
+    uProcessorKernel::schedule( this );			// find someone else to execute; wake on kernel stack
 } // uBaseTask::uYieldNoPoll
 
 
+void uBaseTask::yield() {
+    uYieldNoPoll();
+    uEHM::poll();
+} // uBaseTask::yield
+
+
 void uBaseTask::yield( unsigned int times ) {
     for ( ; times > 0 ; times -= 1 ) {
 	yield();
@@ -209,7 +218,7 @@ void uBaseTask::uYieldInvoluntary() {
 
 	THREAD_GETMEM( This )->disableInterrupts();
 	(*uProfiler::uProfiler_setMetricMemoryPointers)( uProfiler::profilerInstance, ptrs, *this ); // force task to use local memory array
-	activeProcessorKernel->schedule( this );	// find someone else to execute; wake on kernel stack
+	activeProcessorKernel->scheduleInternal( this ); // find someone else to execute; wake on kernel stack
 	(*uProfiler::uProfiler_resetMetricMemoryPointers)( uProfiler::profilerInstance, *this );     // reset task to use its native memory array
 	THREAD_GETMEM( This )->enableInterrupts();
 
@@ -219,7 +228,7 @@ void uBaseTask::uYieldInvoluntary() {
 	} // for
     } else {
 	THREAD_GETMEM( This )->disableInterrupts();
-	activeProcessorKernel->schedule( this );	// find someone else to execute; wake on kernel stack
+	activeProcessorKernel->scheduleInternal( this ); // find someone else to execute; wake on kernel stack
 	THREAD_GETMEM( This )->enableInterrupts();
     } // if
 } // uBaseTask::uYieldInvoluntary
@@ -264,6 +273,9 @@ void uBaseTask::profileActivate() {
 
 
 void uBaseTask::profileInactivate() {
+    if ( profileActive && uProfiler::uProfiler_profileInactivate ) {
+	(*uProfiler::uProfiler_profileInactivate)( uProfiler::profilerInstance, *this );
+    } // if
     profileActive = false;
 } // uBaseTask::profileInactivate
 
