@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uDebug.h -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Sat Dec 18 12:56:10 1993
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Aug  5 14:44:43 2005
-// Update Count     : 43
+// Last Modified On : Fri Jul 13 17:31:12 2007
+// Update Count     : 44
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -29,6 +29,7 @@
 #define __U_DEBUG_H__
 
 
+extern void uDebugWrite( char *buffer, int len );
 extern void uDebugAcquire();
 extern void uDebugRelease();
 extern "C" void uDebugPrt( const char fmt[], ... ) __attribute__(( format (printf, 1, 2) ));
