@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Russell Mok 1997
+// uC++ Version 5.5.0, Copyright (C) Russell Mok 1997
 // 
 // uEHM.cc -- 
 // 
 // Author           : Russell Mok
 // Created On       : Sun Jun 29 00:15:09 1997
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sun Sep 24 19:00:42 2006
-// Update Count     : 524
+// Last Modified On : Tue Sep 18 12:16:34 2007
+// Update Count     : 579
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -30,7 +30,6 @@
 //#include <uDebug.h>
 
 #include <cxxabi.h>
-#include "unwind-cxx.h"					// include file copied from gcc 3.4, needed for reraise from a catch-any
 #include <cstring>					// strlen, strncpy, strcpy
 
 #if __GNUC__ == 3 && __GNUC_MINOR__ < 4 && !defined( __INTEL_COMPILER ) // TEMPORARY: bug in uncaught_exception, correction copied from gcc 3.4
@@ -86,30 +85,55 @@ namespace __cxxabiv1 {
 } // namespace __cxxabiv1
 #endif // __GNUC__ == 3 && __GNUC_MINOR__ < 4 && ! __INTEL_COMPILER
 
+#if 0							// future use
+namespace __cxxabiv1 {
+    // Interrupts must be disabled on linux during exception propagation, since
+    // libc does not use our locks.
+
+    typedef void (*cxa_throw_t)(void *, std::type_info *, void (*) (void *)) __attribute__((noreturn));
+    extern "C" void __cxa_throw (void *thrown_exception, std::type_info *tinfo, void (*dest) (void *)) {
+	static cxa_throw_t realThrow = NULL;
+	if ( realThrow == NULL ) {
+	    realThrow = (cxa_throw_t)uKernelModule::interposeSymbol( "__cxa_throw" );
+	}
+	realThrow( thrown_exception, tinfo, dest );
+    } // __cxa_throw
+
+    typedef void (*cxa_rethrow_t)() __attribute__((noreturn));
+    extern "C" void __cxa_rethrow () {
+	static cxa_rethrow_t realReThrow = NULL;
+	if ( realReThrow == NULL ) {
+	    realReThrow = (cxa_rethrow_t)uKernelModule::interposeSymbol( "__cxa_rethrow" );
+	}
+	realReThrow();
+    } // __cxa_rethrow
+} // namespace __cxxabiv1
+#endif
+
 
 //######################### std::{C++ exception routines} ########################
 
 
 void uEHM::terminate() {
-    char ExName[uEHMMaxName + sizeof("...")];		// room for "...\0"
-    char ResName[uEHMMaxName + sizeof("...")];
+    char ExName[uEHMMaxName];
+    char ResName[uEHMMaxName];
 
-    getCurrentEventName( uThrowF, ExName, uEHMMaxName );
-    getCurrentEventName( uResumeF, ResName, uEHMMaxName );
+    getCurrentEventName( ThrowRaise, ExName, uEHMMaxName );
+    getCurrentEventName( ResumeRaise, ResName, uEHMMaxName );
 
     bool exception = ExName[0] != '\0';			// optimization
     bool resumption = ResName[0] != '\0';
     
     if ( ! exception && ! resumption ) {
-	uAbort( "Attempt to rethrow/reraise but no active exception.\n"
-		"Possible cause is a rethrow/reraise not directly or indirectly performed from a catch clause." );
+	uAbort( "Attempt to rethrow/reresume but no active exception.\n"
+		"Possible cause is a rethrow/reresume not directly or indirectly performed from a catch clause." );
     } // if
     
     uAbort( "%s%s%s%s%s%s",
 	    ( uThisCoroutine().unexpected ?
 	      "Exception propagated through a function whose exception-specification does not permit exceptions of that type.\n" :
 	      "Propagation failed to find a matching handler.\n"
-	      "Possible cause is a missing try block with appropriate catch clause for specified or derived exception type\n"
+	      "Possible cause is a missing try block with appropriate catch clause for specified or derived exception type,\n"
 	      "or throwing an exception from within a destructor while propagating an exception.\n" ),
 	    (exception  ? "Type of last active exception: "  : ""), (exception  ? ExName  : ""), (exception && resumption ? "\n" : ""),
 	    (resumption ? "Type of last active resumption: " : ""), (resumption ? ResName : "") ); // uAbort puts a "\n"
@@ -152,7 +176,7 @@ std::unexpected_handler std::set_unexpected( std::unexpected_handler func ) thro
 //######################### uEHM::AsyncEMsg ########################
 
 
-uEHM::AsyncEMsg::AsyncEMsg( const uDualClass &ex, const raiseKind f ) : flag( f ), hidden( false ) {
+uEHM::AsyncEMsg::AsyncEMsg( const uBaseEvent &ex ) : hidden( false ) {
     asyncEvent = ex.duplicate();
 } // uEHM::AsyncEMsg::AsyncEMsg
 
@@ -208,93 +232,50 @@ uEHM::AsyncEMsg *uEHM::AsyncEMsgBuffer::nextVisible( AsyncEMsg *msg ) {
 } // uEHM::AsyncEMsgBuffer::nextVisible
 
 
-//######################### uDualClass ########################
+//######################### uBaseEvent ########################
 
 
-uEHM::uDualClass::uDualClass( const char *const msg ) : src( NULL ) {
-    strncpy( uEHM::uDualClass::msg, msg, uEHMMaxMsg );	// copy message
-}; // uEHM::uDualClass::uDualClass
+void uBaseEvent::setMsg( const char *const msg ) {
+    uEHM::strncpy( uBaseEvent::msg, msg, uEHMMaxMsg );	// copy message
+}; // uBaseEvent::setMsg
 
-uEHM::uDualClass::~uDualClass() {}
+uBaseEvent::~uBaseEvent() {}
 
-const char *uEHM::uDualClass::message() const { return msg; }
-const uBaseCoroutine &uEHM::uDualClass::source() const { return *src; }
-const char *uEHM::uDualClass::sourceName() const { return src != NULL ? srcName : "*unnamed*"; }
+void uBaseEvent::setSrc( uBaseCoroutine &coroutine ) {
+    src = &coroutine;
+    uEHM::strncpy( srcName, coroutine.getName(), uEHMMaxName ); // copy source name
+} // uBaseEvent::setSrc
 
-void uEHM::uDualClass::setSrc( uBaseCoroutine &cor ) {
-    src = &cor;
-    strncpy( srcName, cor.getName(), uEHMMaxName );	// copy source name
-} // uEHM::uDualClass::setSrc
+void uBaseEvent::reraise() const {
+    if ( getRaiseKind() == uEHM::ThrowRaise ) {
+	Throw();
+	// CONTROL NEVER REACHES HERE!
+	assert( false );
+    } // if
+    Resume();
+} // uBaseEvent::reraise
 
-const uEHM::uDualClass &uEHM::uDualClass::setOriginalThrower( const void * p ) const {
+const uBaseEvent &uBaseEvent::setOriginalThrower( const void * p ) const {
     staticallyBoundObject = p;
     return *this;
-} // uEHM::uDualClass::setOriginalThrower
+} // uBaseEvent::setOriginalThrower
 
-void uEHM::uDualClass::defaultTerminate() const {
-} // uEHM::uDualClass::defaultTerminate
+void uBaseEvent::defaultTerminate() const {
+} // uBaseEvent::defaultTerminate
 
-void uEHM::uDualClass::defaultTerminate() {
-    const_cast<const uDualClass *>(this)->defaultTerminate();
-} // uEHM::uDualClass::defaultTerminate
+void uBaseEvent::defaultTerminate() {
+    const_cast<const uBaseEvent *>(this)->defaultTerminate();
+} // uBaseEvent::defaultTerminate
 
-void uEHM::uDualClass::defaultResume() const {
+void uBaseEvent::defaultResume() const {
     stackThrow();
     // CONTROL NEVER REACHES HERE!
-#ifdef __U_DEBUG__
     assert( false );
-#endif // __U_DEBUG__
-} // uEHM::uDualClass::defaultResume
+} // uBaseEvent::defaultResume
 
-void uEHM::uDualClass::defaultResume() {
-    const_cast<const uDualClass *>(this)->defaultResume();
-} // uEHM::uDualClass::defaultResume
-
-
-//######################### uEHM::uThrowClass ########################
-
-
-uEHM::uThrowClass::uThrowClass( const char *const msg ) : uDualClass( msg ) {}
-uEHM::uThrowClass::~uThrowClass() {}
-
-#ifdef __DEBUG__
-void uEHM::uThrowClass::defaultResume() const {
-    uAbort( "uThrowClass object cannot be casted to a raise-able object." );
-} // uEHM::uThrowClass::defaultResume
-
-void uEHM::uThrowClass::defaultResume() {
-    const_cast<const uThrowClass *>(this)->defaultResume();
-} // uEHM::uThrowClass::defaultResume
-#endif // __DEBUG__
-
-
-//######################### uEHM::uResumeClass ########################
-
-
-void uEHM::uResumeClass::stackThrow() const {
-    uAbort( "uResumeClass object cannot be thrown." );
-} // uEHM::uResumeClass::stackThrow
-
-uEHM::uResumeClass::uResumeClass( const char *const msg ) : uDualClass( msg ) {}
-uEHM::uResumeClass::~uResumeClass() {}
-
-#ifdef __DEBUG__
-void uEHM::uResumeClass::defaultTerminate() const {
-    uAbort( "uResumeClass object cannot be casted to a throw-able object." );
-} // uEHM::uResumeClass::defaultTerminate
-
-void uEHM::uResumeClass::defaultTerminate() {
-    const_cast<const uResumeClass *>(this)->defaultTerminate();
-} // uEHM::uResumeClass::defaultTerminate
-#endif // __DEBUG__
-
-void uEHM::uResumeClass::defaultResume() const {
-    terminate();
-} // uEHM::uResumeClass::defaultResume
-
-void uEHM::uResumeClass::defaultResume() {
-    const_cast<const uResumeClass *>(this)->defaultResume();
-} // uEHM::uResumeClass::defaultResume
+void uBaseEvent::defaultResume() {
+    const_cast<const uBaseEvent *>(this)->defaultResume();
+} // uBaseEvent::defaultResume
 
 
 //######################### uEHM::uResumptionHandlers ########################
@@ -340,9 +321,9 @@ uEHM::uDeliverEStack::~uDeliverEStack() {
 
 class uEHM::ResumeWorkHorseInit {
     uResumptionHandlers *prevVisualTop;
-    uDualClass *prevResumption;
+    uBaseEvent *prevResumption;
   public:
-    ResumeWorkHorseInit( uResumptionHandlers *h, uDualClass & newResumption ) {
+    ResumeWorkHorseInit( uResumptionHandlers *h, uBaseEvent & newResumption ) {
 	uBaseCoroutine &coroutine = uThisCoroutine();	// optimization
 	prevResumption = coroutine.resumedObj;
 	coroutine.resumedObj = &newResumption;
@@ -397,30 +378,31 @@ static void Check( uBaseCoroutine &target, const char *kind ) {
 #endif // __U_DEBUG__
 
 
-void uEHM::asyncToss( const uDualClass &ex, uBaseCoroutine &target, raiseKind f, bool rethrow ) {
+void uEHM::asyncToss( const uBaseEvent &ex, uBaseCoroutine &target, RaiseKind raiseKind, bool rethrow ) {
 #ifdef __U_DEBUG__
-    Check( target, f == uResumeF ? "resume" : "throw" );
+    Check( target, raiseKind == ThrowRaise ? "throw" : "resume" );
 #endif // __U_DEBUG__
 
     if ( target.getState() != uBaseCoroutine::Halt ) {
-	AsyncEMsg *temp = new AsyncEMsg( ex, f );
-	uBaseCoroutine &cor = uThisCoroutine();
+	ex.raiseKind = raiseKind;
+	AsyncEMsg *temp = new AsyncEMsg( ex );
+	uBaseCoroutine &coroutine = uThisCoroutine();
 	if ( ! rethrow ) {				// reset current raiser ?
-	    temp->asyncEvent->setOriginalThrower( (void *)&cor );
-	    temp->asyncEvent->setSrc( cor );
+	    temp->asyncEvent->setOriginalThrower( (void *)&coroutine );
+	    temp->asyncEvent->setSrc( coroutine );
 	} // if
 	target.asyncEBuf.uAddMsg( temp );
     } // if
 } // uEHM::asyncToss
 
-void uEHM::asyncReToss( uBaseCoroutine &target, raiseKind f ) {
-    uDualClass *r;
+void uEHM::asyncReToss( uBaseCoroutine &target, RaiseKind raiseKind ) {
+    uBaseEvent *r;
 
-    if (f == uResumeF) {
+    if ( raiseKind == ResumeRaise ) {
 	r = getCurrentResumption();
 	if ( r == NULL ) {
 	    r = getCurrentException();
-	}//if
+	} // if
     } else {
 	r = getCurrentException();
 	if ( r == NULL ) {
@@ -431,24 +413,23 @@ void uEHM::asyncReToss( uBaseCoroutine &target, raiseKind f ) {
     if ( r == NULL ) {					// => there is nothing to resume => terminate
 	terminateHandler();
     } else {
-	asyncToss( *r, target, f, true );
+	asyncToss( *r, target, raiseKind, true );
     } // if
 } // uEHM::asyncReToss
 
 
-void uEHM::Throw( const uDualClass &ex ) {
+void uEHM::Throw( const uBaseEvent &ex ) {
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "uEHM::Throw( uDualClass::ex:0x%p ) from task %.256s (0x%p)\n", &ex, uThisTask().getName(), &uThisTask() );
+    uDebugPrt( "uEHM::Throw( uBaseEvent::ex:0x%p ) from task %.256s (0x%p)\n", &ex, uThisTask().getName(), &uThisTask() );
 #endif // __U_DEBUG_H__
+    ex.raiseKind = ThrowRaise;
     ex.stackThrow();
     // CONTROL NEVER REACHES HERE!
-#ifdef __U_DEBUG__
     assert( false );
-#endif // __U_DEBUG__
 } // uEHM::Throw
 
 void uEHM::ReThrow() {
-    uDualClass *e = getCurrentException();		// optimization
+    uBaseEvent *e = getCurrentException();		// optimization
     if ( e == NULL ) {
 	e = getCurrentResumption();
     } // if
@@ -460,12 +441,13 @@ void uEHM::ReThrow() {
 } // uEHM::ReThrow
 
 
-void uEHM::Resume( const uDualClass &ex ) {
+void uEHM::Resume( const uBaseEvent &ex ) {
+    ex.raiseKind = ResumeRaise;
     resumeWorkHorse( ex, true );
 } // uEHM::Resume
 
 void uEHM::ReResume() {
-    uDualClass *r = getCurrentResumption();		// optimization
+    uBaseEvent *r = getCurrentResumption();		// optimization
 
     if ( r == NULL ) {
 	r = getCurrentException();
@@ -482,17 +464,15 @@ void uEHM::ReResume() {
 // Check for and handle pending nonlocal exceptions.
 
 bool uEHM::poll() {
-    uBaseCoroutine &cor = uThisCoroutine();
-  if ( cor.cancelInProgress() ) return false;		// skip async handling if cancelling
-    if ( cor.getCancelState() != uBaseCoroutine::CancelDisabled && cor.cancelled() ) { // check for cancellation first, but only if it is enabled	
-	cor.unwindStack();				// not cancelling, so unwind stack
+    uBaseCoroutine &coroutine = uThisCoroutine();
+  if ( coroutine.cancelInProgress() ) return false;	// skip async handling if cancelling
+    if ( coroutine.getCancelState() != uBaseCoroutine::CancelDisabled && coroutine.cancelled() ) { // check for cancellation first, but only if it is enabled	
+	coroutine.unwindStack();			// not cancelling, so unwind stack
 	// CONTROL NEVER REACHES HERE!
-#ifdef __U_DEBUG__
 	assert( false );
-#endif // __U_DEBUG__
     } // if
 
-    AsyncEMsgBuffer &msgbuf = cor.asyncEBuf;
+    AsyncEMsgBuffer &msgbuf = coroutine.asyncEBuf;
     AsyncEMsg *asyncMsg = msgbuf.head();		// find first node in queue
 
   if ( asyncMsg == NULL ) return false;
@@ -511,7 +491,7 @@ bool uEHM::poll() {
 	    // poll can only be called from resumeWorkHorse again, which is a
 	    // safe recursion.
 	    asyncMsg->hidden = true;			// hide node from recursive children of poll
-	    uDualClass *asyncEvent = asyncMsg->asyncEvent;
+	    uBaseEvent *asyncEvent = asyncMsg->asyncEvent;
 	    
 	    // Recover memory allocated for async event message. Resuming
 	    // handler should not destroyed raised exception regardless of
@@ -520,12 +500,10 @@ bool uEHM::poll() {
 	    AutoResourceCleanup dummy_var( asyncMsg, msgbuf ); // This ensures removal and deletion of the node at end of block.
 	                                                       // Necessary because of return or throw.
 
-	    if ( asyncMsg->flag == uThrowF ) {		// throw the event
+	    if ( asyncEvent->raiseKind == ThrowRaise ) { // throw the event
 		asyncEvent->stackThrow();
 		// CONTROL NEVER REACHES HERE!
-#ifdef __U_DEBUG__
 		assert( false );
-#endif // __U_DEBUG__
 	    } // if
 	    resumeWorkHorse( *asyncEvent, false );	// handle event, potential recursion! also potential exception
 	    
@@ -545,18 +523,18 @@ bool uEHM::poll() {
 } // uEHM::poll
 
 
-uEHM::uDualClass *uEHM::getCurrentException() {
+uBaseEvent *uEHM::getCurrentException() {
     __cxxabiv1::__cxa_eh_globals *globals = __cxxabiv1::__cxa_get_globals();
     if ( globals != NULL ) {
 	__cxxabiv1::__cxa_exception *header = globals->caughtExceptions;	
 	if ( header != NULL ) {			// handling an exception and want to turn it into resumption
-	    return (uEHM::uDualClass*)((char *)header + sizeof(__cxxabiv1::__cxa_exception)); 
+	    return (uBaseEvent*)((char *)header + sizeof(__cxxabiv1::__cxa_exception)); 
 	} // if
     } // if
     return NULL;
 } // uEHM::getCurrentException
 
-uEHM::uDualClass *uEHM::getCurrentResumption() {
+uBaseEvent *uEHM::getCurrentResumption() {
     return uThisCoroutine().resumedObj;			// optimization
 } // uEHM::getCurrentResumption
 
@@ -565,10 +543,10 @@ const std::type_info * uEHM::getTopResumptionType() {
 } // uEHM::getCurrentResumptionType()
 
 
-char *uEHM::getCurrentEventName( raiseKind f, char *s1, size_t n ) {
+char *uEHM::getCurrentEventName( RaiseKind raiseKind, char *s1, size_t n ) {
     const std::type_info *t;
 
-    if ( f == uResumeF ) {
+    if ( raiseKind == ResumeRaise ) {
 	t = uEHM::getTopResumptionType();
     } else {
 	t = __cxxabiv1::__cxa_current_exception_type();
@@ -589,7 +567,7 @@ char *uEHM::getCurrentEventName( raiseKind f, char *s1, size_t n ) {
 char *uEHM::strncpy( char *s1, const char *s2, size_t n ) {
     ::strncpy( s1, s2, n );
     if ( strlen( s2 ) > n ) {				// name too long ?
-	strcpy( &s1[n], "..." );			// add 4 character ...
+	strcpy( &s1[n - 4], "..." );			// add 4 character ...
     } // if
     return s1;
 } // uEHM::strncpy
@@ -629,7 +607,7 @@ bool uEHM::deliverable_exception( const std::type_info *event_type ) {
 // earlier resumption handlers. In this case, the virtual top
 // (handlerStackVisualTop) of the handler stack is used.
 
-void uEHM::resumeWorkHorse( const uDualClass &ex, const bool conseq ) {
+void uEHM::resumeWorkHorse( const uBaseEvent &ex, const bool conseq ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "uEHM::resumeWorkHorse( ex:0x%p, conseq:%d ) from task %.256s (0x%p)\n",
 	       &ex, conseq, uThisTask().getName(), &uThisTask() );
@@ -659,8 +637,8 @@ void uEHM::resumeWorkHorse( const uDualClass &ex, const bool conseq ) {
 #ifdef __U_DEBUG_H__
 		uDebugPrt( "uEHM::resumeWorkHorse match\n" );
 #endif // __U_DEBUG_H__
-		ResumeWorkHorseInit newStackVisualTop( next, (uDualClass &)ex );
-		elem->uHandler( (uDualClass &)ex );
+		ResumeWorkHorseInit newStackVisualTop( next, (uBaseEvent &)ex );
+		elem->uHandler( (uBaseEvent &)ex );
 		return;					// return after handling the exception
 	    } // if
 	} // for
@@ -668,7 +646,7 @@ void uEHM::resumeWorkHorse( const uDualClass &ex, const bool conseq ) {
     } // while
 
     // cannot find a handler, use the default handler
-    ResumeWorkHorseInit newStackVisualTop( NULL, (uDualClass &)ex ); // record the current resumption
+    ResumeWorkHorseInit newStackVisualTop( NULL, (uBaseEvent &)ex ); // record the current resumption
     ex.defaultResume();					// default handler can change the exception
 } // uEHM::resumeWorkHorse
 
