@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uHeapLmmm.cc -- Lean Mean Malloc Machine - a runtime configurable replacement
 //                 for malloc.
@@ -8,8 +8,8 @@
 // Author           : Peter A. Buhr
 // Created On       : Sat Nov 11 16:07:20 1988
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Jul 15 19:38:35 2006
-// Update Count     : 704
+// Last Modified On : Tue Sep 11 08:27:56 2007
+// Update Count     : 709
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -101,7 +101,7 @@ void uHeapManager::noMemory() {
 } // uHeapManager::noMemory
 
 
-inline void uHeapManager::headers( char *name, void *addr, uStorage *&block, uFreeHeader *&freeElem, size_t &alignment ) {
+inline void uHeapManager::headers( const char *name, void *addr, uStorage *&block, uFreeHeader *&freeElem, size_t &alignment ) {
 #ifdef __U_DEBUG__
     if ( addr < heapBegin || heapEnd <= addr ) {
 	uAbort( "Attempt to %s storage 0x%p outside the current heap range:0x%p to 0x%p.\n"
@@ -344,12 +344,7 @@ void uHeapManager::boot() {
     uHeapBoot = true;
 #endif // __U_DEBUG__
 
-    // SKULLDUGGERY: This ensures that calls to uThisCoroutine work before the
-    // kernel is initialized.
-
-    ((uBaseTask *)&uKernelModule::bootTaskStorage)->currCoroutine = (uBaseTask *)&uKernelModule::bootTaskStorage;
-    ((uBaseTask *)&uKernelModule::bootTaskStorage)->inheritTask = (uBaseTask *)&uKernelModule::bootTaskStorage;
-    uHeapManager::heapManagerInstance = new((void *)&uHeapStorage) uHeapManager;
+    uHeapManager::heapManagerInstance = new( &uHeapStorage ) uHeapManager;
 } // uHeapManager::boot
 
 
@@ -507,7 +502,6 @@ void free( void *addr ) __THROW {
 
 } // extern "C"
 
-
 // Local Variables: //
 // compile-command: "gmake install" //
 // End: //
