@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uMachContext.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Fri Feb 25 15:46:42 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Sep 23 23:19:38 2006
-// Update Count     : 561
+// Last Modified On : Sat Sep 22 14:18:08 2007
+// Update Count     : 641
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -50,7 +50,13 @@ extern "C" void uInvokeStub( uMachContext * );
 #endif // __sparc__
 
 
-extern "C" void _pthread_deletespecific( void * );	// see pthread simulation
+using namespace UPP;
+
+
+extern "C" void pthread_deletespecific_( void * );	// see pthread simulation
+
+
+#define uMinStackSize 1000				// minimum feasible stack size in bytes
 
 
 void uMachContext::invokeCoroutine( uBaseCoroutine &This ) { // magically invoke the "main" of the most derived class
@@ -63,6 +69,10 @@ void uMachContext::invokeCoroutine( uBaseCoroutine &This ) { // magically invoke
     if ( uThisTask().profileActive && uProfiler::uProfiler_postallocateMetricMemory ) {
 	(*uProfiler::uProfiler_postallocateMetricMemory)( uProfiler::profilerInstance, uThisTask() );
     } // if
+    // also appears in uBaseCoroutine::uContextSw2
+    if ( ! THREAD_GETMEM( disableInt ) && uThisTask().profileActive && uProfiler::uProfiler_registerCoroutineUnblock ) {
+	(*uProfiler::uProfiler_registerCoroutineUnblock)( uProfiler::profilerInstance, uThisTask() );
+    } // if
 
     // At this point, execution is on the stack of the new coroutine or task
     // that has just been switched to by the kernel.  Therefore, interrupts can
@@ -75,17 +85,16 @@ void uMachContext::invokeCoroutine( uBaseCoroutine &This ) { // magically invoke
     } catch ( uBaseCoroutine::UnwindStack &u ) {
 	u.exec_dtor = false;				// defuse the bomb or otherwise unwinding will continue
 	This.notHalted = false;				// terminate coroutine
-    } catch( uBaseCoroutine::UnHandledException &ex ) {
-	ex.multiple = true;				// set multiple exceptions
-	_Resume ex _At This.resumer();                    
-	This.notHalted = false;				// terminate coroutine
-    } catch( ... ) {					// unhandled exception ?
-	char msg[uEHMMaxMsg], name[uEHMMaxName + sizeof("...")]; // room for "...\0"
-	strcat( strcpy( msg, "an unhandled exception of type " ), uEHM::getCurrentEventName( uEHM::uThrowF, name, uEHMMaxName ) );
-	_Resume uBaseCoroutine::UnHandledException( msg ) _At This.resumer();
-	This.notHalted = false;				// terminate coroutine
+    } catch( uBaseCoroutine::UnhandledException &ex ) {
+	This.handleUnhandled( &ex );
+    } catch ( uBaseEvent &ex ) {
+	This.handleUnhandled( &ex );
+    } catch( ... ) {					// unknown exception ?
+	This.handleUnhandled();
     } // try
-    if ( ! This.notHalted ) {				// exceptional ending ? check outside handler so exception is freed before suspending
+
+    // check outside handler so exception is freed before suspending
+    if ( ! This.notHalted ) {				// exceptional ending ?
 	This.suspend();					// restart last resumer, which should immediately propagate the nonlocal exception
     } // if
     This.corFinish();
@@ -113,36 +122,48 @@ void uMachContext::invokeTask( uBaseTask &This ) {	// magically invoke the "main
     // that has just been switched to by the kernel.  Therefore, interrupts can
     // legitimately occur now.
 
-    try {
-	uEHM::poll();					// cancellation checkpoint
-	This.main();					// start task's "main" routine
-    } catch( uBaseCoroutine::UnwindStack &evt) {
-	evt.exec_dtor = false;				// defuse the unwinder	
-    } catch( uEHM::uDualClass &evt ) {
-	evt.defaultTerminate();
-	cleanup( This );				// preserve current exception
-    } catch( uEHM::uThrowClass &evt ) {
-	evt.defaultTerminate();
-	cleanup( This );				// preserve current exception
-    } catch( ... ) {
-	cleanup( This );				// preserve current exception
-    } // try
+    uPthreadable *pthreadable = dynamic_cast< uPthreadable * > (&This);
 
-    This.notHalted = false;
-    This.setState( uBaseTask::Terminate );
+    try {
+	try {
+	    uEHM::poll();				// cancellation checkpoint
+	    This.main();				// start task's "main" routine
+	} catch( uBaseCoroutine::UnwindStack &evt ) {
+	    evt.exec_dtor = false;			// defuse the unwinder	
+	} catch( uBaseEvent &ex ) {
+	    ex.defaultTerminate();
+	    cleanup( This );				// preserve current exception
+	} catch( ... ) {
+	    if ( ! This.cancelInProgress() ) {
+		cleanup( This );			// preserve current exception
+		// CONTROL NEVER REACHES HERE!
+	    } // if
+	    if ( pthreadable ) {
+		pthreadable->stop_unwinding = true;	// prevent continuation of unwinding
+	    } // if
+#if defined (__irix__)					// remove if appropriate
+	    uPthreadable::unwind_lock.release();	// release lock acquired in Pthreadable::do_unwind()
+#endif // __irix__
+	} // try
+    } catch (...) {
+	uEHM::terminate();				// if defaultTerminate or std::terminate throws exception
+    } // try
+    // NOTE: this code needs further protection as soon as asynchronous cancellation is supported
 
     // Clean up storage associated with the task for pthread thread-specific
     // data, e.g., exception handling associates thread-specific data with any
     // task.
 
     if ( This.pthreadData != NULL ) {
-	_pthread_deletespecific( This.pthreadData );
+	pthread_deletespecific_( This.pthreadData );
     } // if
+
+    This.notHalted = false;
+    This.setState( uBaseTask::Terminate );
+
     This.getSerial().leave2();
     // CONTROL NEVER REACHES HERE!
-#ifdef __U_DEBUG__
     assert( false );
-#endif // __U_DEBUG__
 } // uMachContext::invokeTask
 
 
@@ -153,41 +174,31 @@ void uMachContext::cleanup( uBaseTask &This ) {
     } // try
 
     if ( This.pthreadData != NULL ) {			// see above for explanation
-	_pthread_deletespecific( This.pthreadData );
+	pthread_deletespecific_( This.pthreadData );
     } // if
 
     uEHM::terminate();					// call abort terminate routine
 } // uMachContext::cleanup
 
 
-void *uMachContext::rtnAdr( void (*rtn)() ) {
-#if defined( __linux__ ) && defined( __ia64__ )
-    if ( ! rtn ) return NULL;
+void uMachContext::extraSave() {
+    // Don't need to test extras bit, it is sufficent to check context list
 
-    struct TOC {
-	void *rtn;
-	void *toc;
-    };
-
-    return ((TOC *)rtn)->rtn;
-#else
-    return (void *)rtn;
-#endif
-} // uMachContext::rtnAdr
+    uContext *context;
+    for ( uSeqIter<uContext> iter(additionalContexts); iter >> context; ) {
+	context->save();
+    } // for
+} // uMachContext::extraSave
 
 
-#if defined( __linux__ ) && defined( __ia64__ )
-void *uMachContext::gpAdr( void (*rtn)() ) {
-    if ( ! rtn ) return NULL;
+void uMachContext::extraRestore() {
+    // Don't need to test extras bit, it is sufficent to check context list
 
-    struct TOC {
-	void *rtn;
-	void *toc;
-    };
-
-    return ((TOC *)rtn)->toc;
-} // uMachContext::gpAdr
-#endif
+    uContext *context;
+    for ( uSeqIter<uContext> iter(additionalContexts); iter >> context; ) {
+	context->restore();
+    } // for
+} // uMachContext::extraRestore
 
 
 unsigned int uMachContext::magic() {
@@ -196,8 +207,12 @@ unsigned int uMachContext::magic() {
 
 
 void uMachContext::startHere( void (*uInvoke)( uMachContext & ) ) {
-
 /*******************************************************
+  ,-----------------.
+  |                 |
+  | __U_CONTEXT_T__ |
+  |                 |
+  `-----------------'   <--- context
   magic number (16 bytes)
   ,-----------------. \ <--- base (stack grows down)
   |                 | |
@@ -205,50 +220,43 @@ void uMachContext::startHere( void (*uInvoke)( uMachContext & ) ) {
   |                 | |
   `-----------------' / <--- limit
   magic number (16 bytes)
-  ,-----------------.
-  |                 |
-  | __U_CONTEXT_T__ |
-  |                 |
-0 `-----------------' <--- storage
+0                       <--- storage
 *******************************************************/
 
 #if defined( __i386__ )
 
     // set base and limits of stack
 
-    limit = (char *)storage + uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + 16;
+    limit = (char *)storage + 16;
     base = (char *)limit + size;
+    context = (char *)limit + size + 16;
 
 #if ! defined( __U_SWAPCONTEXT__ )
     struct uFakeStack {
 	void *uFixedRegisters[3];			// fixed registers ebx, edi, esi
-	void *uReturn;
+	void *uReturn;					// where to go on return from uSwitch
 	void *uDummyReturn;
 	void *uArgument;
     };
 
-    ((uContext_t *)storage)->SP = (char *)base - sizeof( uFakeStack );
-    ((uContext_t *)storage)->FP = NULL;		// terminate stack with NULL fp
+    ((uContext_t *)context)->SP = (char *)base - sizeof( uFakeStack );
+    ((uContext_t *)context)->FP = NULL;			// terminate stack with NULL fp
 
-    ((uFakeStack *)(((uContext_t *)storage)->SP))->uArgument = this; // argument to uInvoke
-    ((uFakeStack *)(((uContext_t *)storage)->SP))->uReturn = rtnAdr( (void (*)())uInvoke );
+    ((uFakeStack *)(((uContext_t *)context)->SP))->uDummyReturn = NULL;
+    ((uFakeStack *)(((uContext_t *)context)->SP))->uArgument = this; // argument to uInvoke
+    ((uFakeStack *)(((uContext_t *)context)->SP))->uReturn = rtnAdr( (void (*)())uInvoke );
 #else
-    // set base and limits of stack
-
-    limit = (char *)storage + sizeof(ucontext_t) + 16;
-    base = (char *)limit + size;
-
-    if ( ::getcontext( (ucontext *)storage ) == -1 ) {	// initialize ucontext area
+    if ( ::getcontext( (ucontext *)context ) == -1 ) {	// initialize ucontext area
 	uAbort( "internal error, getcontext failed" );
     } // if
-    ((ucontext *)storage)->uc_stack.ss_sp = (char *)limit;
-    ((ucontext *)storage)->uc_stack.ss_size = size; 
-    ((ucontext *)storage)->uc_stack.ss_flags = 0;
-    ::makecontext( (ucontext *)storage, (void (*)())uInvoke, 2, this );
+    ((ucontext *)context)->uc_stack.ss_sp = (char *)limit;
+    ((ucontext *)context)->uc_stack.ss_size = size; 
+    ((ucontext *)context)->uc_stack.ss_flags = 0;
+    ::makecontext( (ucontext *)context, (void (*)())uInvoke, 2, this );
     // TEMPORARY: stack is incorrectly initialized to allow stack walking
-    ((ucontext *)storage)->uc_mcontext.gregs[ REG_EBP ] = 0; // terminate stack with NULL fp
+    ((ucontext *)context)->uc_mcontext.gregs[ REG_EBP ] = 0; // terminate stack with NULL fp
 #if defined( __U_MULTI__ ) && defined( __U_ONETIMER__ )
-    sigaddset( (sigset_t*)&((ucontext *)storage)->uc_sigmask, SIGALRM );
+    sigaddset( (sigset_t*)&((ucontext *)context)->uc_sigmask, SIGALRM );
 #endif // __U_MULTI__ && __U_ONETIMER__
 #endif
 
@@ -256,21 +264,24 @@ void uMachContext::startHere( void (*uInvoke)( uMachContext & ) ) {
 
     // set base and limits of stack
 
-    limit = (char *)storage + uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + 16;
+    limit = (char *)storage + 16;
     base = (char *)limit + size;
+    context = (char *)limit + size + 16;
 
 #if ! defined( __U_SWAPCONTEXT__ )
     struct uFakeStack {
 	void *uFixedRegisters[5];			// fixed registers rbx, r12, r13, r14, r15
-	void *uReturn;
+	void *uReturn;					// where to go on return from uSwitch
+	void *uDummyReturn;				// NULL return address to provide proper alignment
     };
 
-    ((uContext_t *)storage)->SP = (char *)base - sizeof( uFakeStack );
-    ((uContext_t *)storage)->FP = NULL;		// terminate stack with NULL fp
+    ((uContext_t *)context)->SP = (char *)base - sizeof( uFakeStack );
+    ((uContext_t *)context)->FP = NULL;			// terminate stack with NULL fp
 
-    ((uFakeStack *)(((uContext_t *)storage)->SP))->uReturn = rtnAdr( (void (*)())uInvokeStub );
-    ((uFakeStack *)(((uContext_t *)storage)->SP))->uFixedRegisters[0] = this;
-    ((uFakeStack *)(((uContext_t *)storage)->SP))->uFixedRegisters[1] = rtnAdr( (void (*)())uInvoke );
+    ((uFakeStack *)(((uContext_t *)context)->SP))->uDummyReturn = NULL;
+    ((uFakeStack *)(((uContext_t *)context)->SP))->uReturn = rtnAdr( (void (*)())uInvokeStub );
+    ((uFakeStack *)(((uContext_t *)context)->SP))->uFixedRegisters[0] = this;
+    ((uFakeStack *)(((uContext_t *)context)->SP))->uFixedRegisters[1] = rtnAdr( (void (*)())uInvoke );
 #else
     // makecontext is difficult to support.  See http://sources.redhat.com/bugzilla/show_bug.cgi?id=404
     #error uC++ : internal error, swapcontext cannot be used on the x86_64 architecture
@@ -278,12 +289,13 @@ void uMachContext::startHere( void (*uInvoke)( uMachContext & ) ) {
 
 #elif defined( __ia64__ )
 
-#if ! defined( __U_SWAPCONTEXT__ )
-
     // set base and limits of stack
 
-    limit = (char *)storage + uCeiling( sizeof(__U_CONTEXT_T__), 16 );
+    limit = (char *)storage + 16;
     base = (char *)limit + size;
+    context = (char *)limit + size + 16;
+
+#if ! defined( __U_SWAPCONTEXT__ )
 
     struct uFakeStack {
 	void *scratch1[2];				// abi-mandated scratch area
@@ -310,43 +322,38 @@ void uMachContext::startHere( void (*uInvoke)( uMachContext & ) ) {
 	void *scratch2[2];				// abi-mandated scratch area
     };
 
-    ((uContext_t *)storage)->SP = (char *)base - sizeof( uFakeStack );
-    ((uContext_t *)storage)->BSP = (char*)limit + 16;
-    sigemptyset( &((uContext_t *)storage)->sigMask );
+    ((uContext_t *)context)->SP = (char *)base - sizeof( uFakeStack );
+    ((uContext_t *)context)->BSP = (char*)limit + 16;
+    sigemptyset( &((uContext_t *)context)->sigMask );
 #ifdef __U_MULTI__
-    sigaddset( &((uContext_t *)storage)->sigMask, SIGALRM );
+    sigaddset( &((uContext_t *)context)->sigMask, SIGALRM );
 #endif // __U_MULTI__
-    memset( ((uContext_t *)storage)->SP, 0, sizeof( uFakeStack ) );
-    ((uFakeStack *)(((uContext_t *)storage)->SP))->preserved.b0 = rtnAdr( (void (*)())uInvokeStub );
-    ((uFakeStack *)(((uContext_t *)storage)->SP))->preserved.r1 = gpAdr( (void (*)())uInvokeStub );
+    memset( ((uContext_t *)context)->SP, 0, sizeof( uFakeStack ) );
+    ((uFakeStack *)(((uContext_t *)context)->SP))->preserved.b0 = rtnAdr( (void (*)())uInvokeStub );
+    ((uFakeStack *)(((uContext_t *)context)->SP))->preserved.r1 = gpAdr( (void (*)())uInvokeStub );
 #if defined( __INTEL_COMPILER )
-    ((uFakeStack *)(((uContext_t *)storage)->SP))->preserved.fpsr = (void*)__getReg( _IA64_REG_AR_FPSR );
+    ((uFakeStack *)(((uContext_t *)context)->SP))->preserved.fpsr = (void*)__getReg( _IA64_REG_AR_FPSR );
 #else
-    asm ( "mov.m %0 = ar.fpsr" : "=r" (((uFakeStack *)(((uContext_t *)storage)->SP))->preserved.fpsr) );
+    asm ( "mov.m %0 = ar.fpsr" : "=r" (((uFakeStack *)(((uContext_t *)context)->SP))->preserved.fpsr) );
 #endif // __INTEL_COMPILER
-    ((uFakeStack *)(((uContext_t *)storage)->SP))->preserved.r4 = this;
-    ((uFakeStack *)(((uContext_t *)storage)->SP))->preserved.b1 = rtnAdr( (void (*)())uInvoke );
-    ((uFakeStack *)(((uContext_t *)storage)->SP))->preserved.b2 = NULL; // null terminate for stack walking
+    ((uFakeStack *)(((uContext_t *)context)->SP))->preserved.r4 = this;
+    ((uFakeStack *)(((uContext_t *)context)->SP))->preserved.b1 = rtnAdr( (void (*)())uInvoke );
+    ((uFakeStack *)(((uContext_t *)context)->SP))->preserved.b2 = NULL; // null terminate for stack walking
 #else
-    // set base and limits of stack
-
-    limit = (char *)storage + sizeof(ucontext_t) + 16;
-    base = (char *)limit + size;
-
-    if ( ::getcontext( (ucontext *)storage ) == -1 ) {	// initialize ucontext area
+    if ( ::getcontext( (ucontext *)context ) == -1 ) {	// initialize ucontext area
 	uAbort( "internal error, getcontext failed" );
     } // if
-    ((ucontext *)storage)->uc_stack.ss_sp = (char *)limit;
-    ((ucontext *)storage)->uc_stack.ss_size = size;
-    ((ucontext *)storage)->uc_stack.ss_flags = 0;
-    ::makecontext( (ucontext *)storage, (void (*)())uInvoke, 2, this );
+    ((ucontext *)context)->uc_stack.ss_sp = (char *)limit;
+    ((ucontext *)context)->uc_stack.ss_size = size;
+    ((ucontext *)context)->uc_stack.ss_flags = 0;
+    ::makecontext( (ucontext *)context, (void (*)())uInvoke, 2, this );
 
     // TEMPORARY: getcontext doesn't get the signal mask properly
-    if ( sigprocmask( SIG_BLOCK, NULL, (sigset_t*)&(((ucontext *)storage)->uc_sigmask) ) == -1 ) {
+    if ( sigprocmask( SIG_BLOCK, NULL, (sigset_t*)&(((ucontext *)context)->uc_sigmask) ) == -1 ) {
         uAbort( "internal error, sigprocmask" );
     } // if
 #if defined( __U_MULTI__ ) && defined( __U_ONETIMER__ )
-    sigaddset( (sigset_t*)&((ucontext *)storage)->uc_sigmask, SIGALRM );
+    sigaddset( (sigset_t*)&((ucontext *)context)->uc_sigmask, SIGALRM );
 #endif // __U_MULTI__ && __U_ONETIMER__
 #endif
 
@@ -354,8 +361,9 @@ void uMachContext::startHere( void (*uInvoke)( uMachContext & ) ) {
 
     // set base and limits of stack
 
-    limit = (char *)storage + uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + 16;
+    limit = (char *)storage + 16;
     base = (char *)limit + size;
+    context = (char *)limit + size + 16;
 
 #if ! defined( __U_SWAPCONTEXT__ )
     struct uFakeStack {
@@ -367,25 +375,25 @@ void uMachContext::startHere( void (*uInvoke)( uMachContext & ) ) {
 	void *uCalleeRegArgs[6];
     };
 
-    ((uContext_t *)storage)->FP = (char *)(SA( (unsigned long)base - STACK_ALIGN + 1 ) - SA( MINFRAME ) - STACK_BIAS );
-    ((uContext_t *)storage)->SP = (char *)((uContext_t *)storage)->FP - SA( MINFRAME );
-    ((uContext_t *)storage)->PC = (char *)rtnAdr( (void (*)())uInvokeStub ) - 8;
+    ((uContext_t *)context)->FP = (char *)(SA( (unsigned long)base - STACK_ALIGN + 1 ) - SA( MINFRAME ) - STACK_BIAS );
+    ((uContext_t *)context)->SP = (char *)((uContext_t *)context)->FP - SA( MINFRAME );
+    ((uContext_t *)context)->PC = (char *)rtnAdr( (void (*)())uInvokeStub ) - 8;
 
-    ((uFakeStack *)((char *)((uContext_t *)storage)->FP + STACK_BIAS))->uInRegs[0] = this; // argument to uInvoke
-    ((uFakeStack *)((char *)((uContext_t *)storage)->FP + STACK_BIAS))->uInRegs[1] = (void *)uInvoke; // uInvoke routine
-    ((uFakeStack *)((char *)((uContext_t *)storage)->FP + STACK_BIAS))->uInRegs[6] = NULL; // terminate stack with NULL fp
+    ((uFakeStack *)((char *)((uContext_t *)context)->FP + STACK_BIAS))->uInRegs[0] = this; // argument to uInvoke
+    ((uFakeStack *)((char *)((uContext_t *)context)->FP + STACK_BIAS))->uInRegs[1] = (void *)uInvoke; // uInvoke routine
+    ((uFakeStack *)((char *)((uContext_t *)context)->FP + STACK_BIAS))->uInRegs[6] = NULL; // terminate stack with NULL fp
 #else
-    if ( ::getcontext( (ucontext *)storage ) == -1 ) {	// initialize ucontext area
+    if ( ::getcontext( (ucontext *)context ) == -1 ) {	// initialize ucontext area
 	uAbort( " : internal error, getcontext failed" );
     } // if
-    ((ucontext *)storage)->uc_stack.ss_sp = (char *)base - 8;	// TEMPORARY: -8 for bug in Solaris (fixed in Solaris 4.10)
-    ((ucontext *)storage)->uc_stack.ss_size = size; 
-    ((ucontext *)storage)->uc_stack.ss_flags = 0;
-    ::makecontext( (ucontext *)storage, (void (*)(...))uInvoke, 2, this );
+    ((ucontext *)context)->uc_stack.ss_sp = (char *)base - 8;	// TEMPORARY: -8 for bug in Solaris (fixed in Solaris 4.10)
+    ((ucontext *)context)->uc_stack.ss_size = size; 
+    ((ucontext *)context)->uc_stack.ss_flags = 0;
+    ::makecontext( (ucontext *)context, (void (*)(...))uInvoke, 2, this );
     // TEMPORARY: stack is incorrectly initialized to allow stack walking
     *((int *)base - 8) = 0;				// terminate stack with NULL fp
 #if defined( __U_MULTI__ ) && defined( __U_ONETIMER__ )
-    sigaddset( (sigset_t*)&((ucontext *)storage)->uc_sigmask, SIGALRM );
+    sigaddset( (sigset_t*)&((ucontext *)context)->uc_sigmask, SIGALRM );
 #endif // __U_MULTI__ && __U_ONETIMER__
 #endif
 
@@ -397,31 +405,27 @@ void uMachContext::startHere( void (*uInvoke)( uMachContext & ) ) {
 	void *uDummyAlign[1];				// make multiple of 16
     };
 
-    limit = (char *)storage + uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + 16;
-    base = (char *)storage + size;
+    limit = (char *)storage + 16;
+    base = (char *)limit + size;
+    context = (char *)limit + size + 16;
 
-    ((uContext_t *)storage)->SP = (char *)base - sizeof( uFakeStack );
+    ((uContext_t *)context)->SP = (char *)base - sizeof( uFakeStack );
 
-    ((uFakeStack *)((uContext_t *)storage)->SP)->uFixedRegisters[0] = reinterpret_cast<unsigned long long>( this ); // argument to uInvoke (r16)
-    ((uFakeStack *)((uContext_t *)storage)->SP)->uFixedRegisters[1] = reinterpret_cast<unsigned long long>( rtnAdr( (void (*)())uInvoke ) );	// uInvoke routine (r17)
-    ((uFakeStack *)((uContext_t *)storage)->SP)->uFixedRegisters[8] = 0; // terminate stack with NULL fp (r30)
-    ((uFakeStack *)((uContext_t *)storage)->SP)->uFixedRegisters[9] = reinterpret_cast<unsigned long long>( rtnAdr( (void (*)())uInvokeStub ) ); // (r31)
+    ((uFakeStack *)((uContext_t *)context)->SP)->uFixedRegisters[0] = reinterpret_cast<unsigned long long>( this ); // argument to uInvoke (r16)
+    ((uFakeStack *)((uContext_t *)context)->SP)->uFixedRegisters[1] = reinterpret_cast<unsigned long long>( rtnAdr( (void (*)())uInvoke ) );	// uInvoke routine (r17)
+    ((uFakeStack *)((uContext_t *)context)->SP)->uFixedRegisters[8] = 0; // terminate stack with NULL fp (r30)
+    ((uFakeStack *)((uContext_t *)context)->SP)->uFixedRegisters[9] = reinterpret_cast<unsigned long long>( rtnAdr( (void (*)())uInvokeStub ) ); // (r31)
 
 #else
-    // set base and limits of stack
-
-    limit = (char *)storage + sizeof(ucontext_t) + 16;
-    base = (char *)limit + size;
-
-    if ( ::getcontext( (ucontext *)storage ) == -1 ) {	// initialize ucontext area
+    if ( ::getcontext( (ucontext *)context ) == -1 ) {	// initialize ucontext area
 	uAbort( "internal error, getcontext failed" );
     } // if
-    ((ucontext *)storage)->uc_stack.ss_sp = (char *)base - 8;	// TEMPORARY: -8 for bug in Solaris (fixed in Solaris 4.10)
-    ((ucontext *)storage)->uc_stack.ss_size = size; 
-    ((ucontext *)storage)->uc_stack.ss_flags = 0;
-    ::makecontext( (ucontext *)storage, (void (*)())uInvoke, 2, this );
+    ((ucontext *)context)->uc_stack.ss_sp = (char *)base - 8;	// TEMPORARY: -8 for bug in Solaris (fixed in Solaris 4.10)
+    ((ucontext *)context)->uc_stack.ss_size = size; 
+    ((ucontext *)context)->uc_stack.ss_flags = 0;
+    ::makecontext( (ucontext *)context, (void (*)())uInvoke, 2, this );
 #if defined( __U_MULTI__ ) && defined( __U_ONETIMER__ )
-    sigaddset( (sigset_t*)&((ucontext *)storage)->uc_sigmask, SIGALRM );
+    sigaddset( (sigset_t*)&((ucontext *)context)->uc_sigmask, SIGALRM );
 #endif // __U_MULTI__ && __U_ONETIMER__
 #endif
 
@@ -431,34 +435,40 @@ void uMachContext::startHere( void (*uInvoke)( uMachContext & ) ) {
 
     // set magic words on stack
 
+#ifdef __U_DEBUG__
     *(unsigned int *)((char *)limit - 16) = magic();
+#endif // __U_DEBUG__
     *(unsigned int *)base = magic();
 } // uMachContext::startHere
 
 
-void uMachContext::createContext( unsigned int stacksize ) { // used by all constructors
-    size = uCeiling( stacksize, 16 );
-    limit = base = NULL;
-    uErrno = 0;
+void uMachContext::createContext( void *storage_, unsigned int storageSize ) { // used by all constructors
+    if ( storage_ != NULL ) {
+#ifdef __U_DEBUG__
+	if ( ((size_t)storage_ & (uAlign() - 1)) != 0 ) { // multiple of uAlign ?
+	    uAbort( "Stack storage 0x%p for task/coroutine must be aligned on %d byte boundary.", storage_, (int)uAlign() );
+	} // if
+#endif // __U_DEBUG__
+	userStack = true;
+	storage = storage_;
+    } else {
+	userStack = false;
+	// use malloc because "new" handles the overflow
+	storage = malloc( uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + storageSize + 32 );
+	if ( storage == NULL ) {			// allocate stack from heap
+	    uAbort( "Attempt to allocate %d bytes of storage for coroutine or task execution-state but insufficient memory available.", storageSize );
+	} // if
+    } // if
+#ifdef __U_DEBUG__
+    if ( storageSize < uMinStackSize ) {		// below minimum stack size ?
+	uAbort( "Stack size %d provides less than minimum of %d bytes for a stack.", storageSize, uMinStackSize );
+    } // if
+#endif // __U_DEBUG__
+    size = storageSize;
     extras.allExtras = 0;
 } // uMachContext::createContext
 
 
-uMachContext::uMachContext( unsigned int stacksize ) {
-    createContext( stacksize );
-    // use malloc because "new" handles the overflow
-    storage = malloc( uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + size + 32 );
-    if ( storage == NULL ) {				// allocate stack from heap
-	uAbort( "Attempt to allocate %d bytes of storage for coroutine or task execution-state but insufficient memory available.", stacksize );
-    } // if
-} // uMachContext::uMachContext
-
-
-uMachContext::~uMachContext() {
-    free( storage );
-} // uMachContext::~uMachContext
-
-
 void *uMachContext::stackPointer() const {
     if ( &uThisCoroutine() == this ) {			// accessing myself ?
 	void *sp;					// use my current stack value
@@ -489,7 +499,7 @@ void *uMachContext::stackPointer() const {
 	return sp;
     } else {						// accessing another coroutine
 #if defined( __U_SWAPCONTEXT__ )
-	return (void *)(((ucontext_t *)storage)->uc_mcontext.
+	return (void *)(((ucontext_t *)context)->uc_mcontext.
 #if defined( __i386__ )
 #if defined( __linux__ )
 	    gregs[REG_ESP]);
@@ -511,9 +521,9 @@ void *uMachContext::stackPointer() const {
 #endif
 #else
 #if defined( __sparc__ )
-	return (void*)((char*)((uContext_t *)storage)->SP + STACK_BIAS);
+	return (void*)((char*)((uContext_t *)context)->SP + STACK_BIAS);
 #else
-	return ((uContext_t *)storage)->SP;
+	return ((uContext_t *)context)->SP;
 #endif // __sparc__
 #endif
     } // if
@@ -532,20 +542,15 @@ void *uMachContext::registerStackPointer() const {
 	return bsp;
 #endif // __INTEL_COMPILER
     } else {						// accessing another coroutine
-	return (void *)(((ucontext_t *)storage)->uc_mcontext.sc_ar_bsp);
+	return (void *)(((ucontext_t *)context)->uc_mcontext.sc_ar_bsp);
     } // if
 #else
-    return ((uContext_t *)storage)->BSP;
+    return ((uContext_t *)context)->BSP;
 #endif
 } // uMachContext::registerStackPointer
 #endif // __ia64__
 
 
-unsigned int uMachContext::stackSize() const {
-    return size;
-} // uMachContext::stackSize
-
-
 ptrdiff_t uMachContext::stackFree() const {
     return (char *)stackPointer() - (char *)limit;
 } // uMachContext::stackFree
@@ -572,7 +577,11 @@ void uMachContext::verify() {
     } else if ( stackPointer() > base ) {
 	uAbort( "Stack underflow detected.\n"
 		"Possible cause is corrupted stack frame via overwriting memory." );
-    } else if ( ( *(unsigned int *)base != magic() ) || ( *(unsigned int *)((char *)limit - 16) != magic() ) ) {
+    } else if ( ( *(unsigned int *)base != magic() )
+#ifdef __U_DEBUG__
+		|| ( *(unsigned int *)((char *)limit - 16) != magic() )
+#endif // __U_DEBUG__
+	       ) {
 	uAbort( "Stack corruption detected.\n"
 		"Possible cause is corrupted stack frame via overwriting memory." );
 #if defined( __ia64__ )
@@ -586,24 +595,34 @@ void uMachContext::verify() {
 } // uMachContext::verify
 
 
-void uMachContext::extraSave() {
-    // Don't need to test extras bit, it is sufficent to check context list
+void *uMachContext::rtnAdr( void (*rtn)() ) {
+#if defined( __linux__ ) && defined( __ia64__ )
+    if ( ! rtn ) return NULL;
 
-    uContext *context;
-    for ( uSeqIter<uContext> iter(additionalContexts); iter >> context; ) {
-	context->save();
-    } // for
-} // uMachContext::extraSave
+    struct TOC {
+	void *rtn;
+	void *toc;
+    };
+
+    return ((TOC *)rtn)->rtn;
+#else
+    return (void *)rtn;
+#endif
+} // uMachContext::rtnAdr
 
 
-void uMachContext::extraRestore() {
-    // Don't need to test extras bit, it is sufficent to check context list
+#if defined( __linux__ ) && defined( __ia64__ )
+void *uMachContext::gpAdr( void (*rtn)() ) {
+    if ( ! rtn ) return NULL;
 
-    uContext *context;
-    for ( uSeqIter<uContext> iter(additionalContexts); iter >> context; ) {
-	context->restore();
-    } // for
-} // uMachContext::extraRestore
+    struct TOC {
+	void *rtn;
+	void *toc;
+    };
+
+    return ((TOC *)rtn)->toc;
+} // uMachContext::gpAdr
+#endif
 
 
 // Local Variables: //
