@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uProcessor.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Mar 14 17:39:15 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Sep 13 21:48:34 2006
-// Update Count     : 1777
+// Last Modified On : Thu Sep  6 09:45:20 2007
+// Update Count     : 1809
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -38,7 +38,6 @@
 #include <cstdio>					// fprintf
 #include <cerrno>
 #include <unistd.h>					// getpid
-#include <inttypes.h>					// uintptr_t
 
 #if defined( __solaris__ )
 #if defined( __U_PTHREAD__ )
@@ -77,6 +76,10 @@ extern "C" int __clone2( int (*__fn) (void *__arg), void *__child_stack_base, si
 #include <machine/sysarch.h>				// i386_set_ldt
 #endif // __freebsd__ && __U_MULTI__
 
+
+using namespace UPP;
+
+
 #if ! defined( __U_MULTI__ ) || defined( __U_ONETIMER__ )
 uEventList *uProcessor::events = NULL;
 #endif // ! __U_MULTI__ || __U_ONETIMER__
@@ -142,13 +145,13 @@ void uProcessorTask::main() {
 	    uDebugPrt( "(uProcessorTask &)0x%p.main, ~uProcessorTask\n", this );
 #endif // __U_DEBUG_H__
 	    break;
-	} else _Accept( setPreemption ) {
+	} or _Accept( setPreemption ) {
 #ifdef __U_DEBUG_H__
 	    uDebugPrt( "(uProcessorTask &)0x%p.main, setPreemption( %d )\n", this, preemption );
 #endif // __U_DEBUG_H__
 	    processor.setContextSwitchEvent( preemption ); // use it to set the alarm for this processor
 	    processor.preemption = preemption;
-	} else _Accept( setCluster ) {
+	} or _Accept( setCluster ) {
 #ifdef __U_DEBUG_H__
 	    uDebugPrt( "(uProcessorTask &)0x%p.main, setCluster\n", this );
 #endif // __U_DEBUG_H__
@@ -184,7 +187,7 @@ void uProcessorTask::main() {
 	    result.signalBlock();
 #if defined( __U_MULTI__ )
 #if defined( __irix__ ) || defined( __freebsd__ )
-	} else _Accept( procCreate ) {
+	} or _Accept( procCreate ) {
 	    assert( &processor == uKernelModule::systemProcessor );
 #ifdef __U_DEBUG_H__
 	    uDebugPrt( "(uProcessorTask &)0x%p.main, procCreate pid:%d\n", this, pid );
@@ -200,7 +203,7 @@ void uProcessorTask::main() {
 	    result.signalBlock();
 #endif
 #if defined( __irix__ ) || defined( __linux__ ) || defined( __freebsd__ )
-	} else _Accept( procWait ) {
+	} or _Accept( procWait ) {
 	    assert( &processor == uKernelModule::systemProcessor );
 	    int code, status = 0;
 
@@ -225,7 +228,7 @@ void uProcessorTask::main() {
 	    } // if
 	    result.signalBlock();
 #endif
-	} else _Accept( procExit ) {
+	} or _Accept( procExit ) {
 	    exit( retCode );
 #endif // __U_MULTI__
 	} // _Accept
@@ -281,9 +284,7 @@ void uProcessorTask::procExit( int retcode ) {
     uProcessorTask::retCode = retcode;			// copy arguments
     result.wait();					// wait for result
     // CONTROL NEVER REACHES HERE!
-#ifdef __U_DEBUG__
     assert( false );
-#endif // __U_DEBUG__
 } // uProcessorTask::procExit
 #endif // __U_MULTI__
 
@@ -484,7 +485,7 @@ inline void uProcessorKernel::taskIsBlocking() {
 } // uProcessorKernel::taskIsBlocking
 
 
-void uProcessorKernel::schedule() {
+void uProcessorKernel::scheduleInternal() {
     assert( ! uThisTask().readyRef.listed() );
     assert( ! THREAD_GETMEM( disableIntSpin ) );
 
@@ -492,10 +493,10 @@ void uProcessorKernel::schedule() {
 
     kind = 0;
     contextSw();					// not resume because entering kernel
-} // uProcessorKernel::schedule
+} // uProcessorKernel::scheduleInternal
 
 
-void uProcessorKernel::schedule( uSpinLock *lock ) {
+void uProcessorKernel::scheduleInternal( uSpinLock *lock ) {
     assert( ! uThisTask().readyRef.listed() );
     assert( THREAD_GETMEM( disableIntSpinCnt ) == 1 );
 
@@ -504,10 +505,10 @@ void uProcessorKernel::schedule( uSpinLock *lock ) {
     kind = 1;
     prevLock = lock;
     contextSw();					// not resume because entering kernel
-} // uProcessorKernel::schedule
+} // uProcessorKernel::scheduleInternal
 
 
-void uProcessorKernel::schedule( uBaseTask *task ) {
+void uProcessorKernel::scheduleInternal( uBaseTask *task ) {
     // SKULLDUGGERY: uBootTask is on ready queue for first entry into the kernel.
     assert( &uThisTask() != (uBaseTask *)uKernelModule::bootTask ? ! uThisTask().readyRef.listed() : true );
     assert( ! THREAD_GETMEM( disableIntSpin ) );
@@ -519,10 +520,10 @@ void uProcessorKernel::schedule( uBaseTask *task ) {
     kind = 2;
     nextTask = task;
     contextSw();					// not resume because entering kernel
-} // uProcessorKernel::schedule
+} // uProcessorKernel::scheduleInternal
 
 
-void uProcessorKernel::schedule( uSpinLock *lock, uBaseTask *task ) {
+void uProcessorKernel::scheduleInternal( uSpinLock *lock, uBaseTask *task ) {
     assert( ! uThisTask().readyRef.listed() );
     assert( THREAD_GETMEM( disableIntSpinCnt ) == 1 );
 
@@ -532,6 +533,35 @@ void uProcessorKernel::schedule( uSpinLock *lock, uBaseTask *task ) {
     prevLock = lock;
     nextTask = task;
     contextSw();					// not resume because entering kernel
+} // uProcessorKernel::scheduleInternal
+
+
+#define SCHEDULE_BODY(parm...) \
+    THREAD_GETMEM( This )->disableInterrupts(); \
+    activeProcessorKernel->scheduleInternal( parm ); \
+    THREAD_GETMEM( This )->enableInterrupts(); \
+    /* Are uC++ kernel memory allocation hooks active? */ \
+    if ( uThisTask().profileActive && uProfiler::uProfiler_postallocateMetricMemory ) { \
+	(*uProfiler::uProfiler_postallocateMetricMemory)( uProfiler::profilerInstance, uThisTask() ); \
+    }
+
+void uProcessorKernel::schedule() {
+    SCHEDULE_BODY();
+} // uProcessorKernel::schedule
+
+
+void uProcessorKernel::schedule( uSpinLock *lock ) {
+    SCHEDULE_BODY( lock );
+} // uProcessorKernel::schedule
+
+
+void uProcessorKernel::schedule( uBaseTask *task ) {
+    SCHEDULE_BODY( task );
+} // uProcessorKernel::schedule
+
+
+void uProcessorKernel::schedule( uSpinLock *lock, uBaseTask *task ) {
+    SCHEDULE_BODY( lock, task );
 } // uProcessorKernel::schedule
 
 
@@ -603,8 +633,8 @@ void uProcessorKernel::setTimer( uTime time ) {
 } // uProcessorKernel::setTimer
 
 
-#ifndef __U_MULTI__
-void uProcessorKernel::nextProcessor( uProcessorDL *&currProc ) {
+#if ! defined( __U_MULTI__ )
+void uProcessorKernel::nextProcessor( uProcessorDL *&currProc, uProcessorDL *cycleStart ) {
     // Get next processor to execute.
 
     unsigned int uPrevPreemption = uThisProcessor().getPreemption(); // remember previous preemption value
@@ -612,13 +642,19 @@ void uProcessorKernel::nextProcessor( uProcessorDL *&currProc ) {
     uDebugPrt( "(uProcessorKernel &)0x%p.nextProcessor, from processor 0x%p on cluster %.256s (0x%p) with time slice %d\n",
 	       this, &uThisProcessor(), uThisProcessor().currCluster->getName(), uThisProcessor().currCluster, uThisProcessor().getPreemption() );
 #endif // __U_DEBUG_H__
-    uProcessorDL *original = currProc;
     do {						// ignore deleted processors
 	currProc = uKernelModule::globalProcessors->succ( currProc );
 	if ( currProc == NULL ) {			// make list appear circular
 	    currProc = uKernelModule::globalProcessors->head(); // restart at beginning of list
 	} // if
-    } while ( currProc != original && currProc->processor().terminated );
+    } while ( currProc != cycleStart &&			// stop searching if all processors in the cycle have been checked
+	      // ignore a processor if it is terminated or has no tasks to execute on either of its ready queues
+	      ( currProc->processor().terminated || ( currProc->processor().external.empty() && currProc->processor().currCluster->readyTasksEmpty() ) ) );
+
+    if ( currProc->processor().terminated ) {
+	currProc = &(uKernelModule::systemProcessor->globalRef);
+    } // if
+
     THREAD_SETMEM( activeProcessor, &(currProc->processor() ) );
     uCluster *currCluster = THREAD_GETMEM( activeProcessor )->currCluster;
     THREAD_SETMEM( activeCluster, currCluster );
@@ -633,7 +669,7 @@ void uProcessorKernel::nextProcessor( uProcessorDL *&currProc ) {
 	uThisProcessor().setContextSwitchEvent( uThisProcessor().getPreemption() );
     } // if
 } // nextProcessor
-#endif // __U_MULTI__
+#endif // ! __U_MULTI__
 
 
 void uProcessorKernel::main() {
@@ -651,6 +687,7 @@ void uProcessorKernel::main() {
     bool &okToSelect = uCluster::NBIO->okToSelect;
     uBaseTask *&IOPoller = uCluster::NBIO->IOPoller;
 #endif // ! __U_MULTI__
+    uBaseTask *uReadyTask;
 
     for ( unsigned int spin = 0;; ) {
 	// Advance the spin counter now to detect if a task is executed.
@@ -688,29 +725,32 @@ void uProcessorKernel::main() {
 
 #if defined( __U_MULTI__ ) && defined( __U_SWAPCONTEXT__ )
 #if defined( __i386__ ) && ! defined( __U_PTHREAD__ )
-	    ((ucontext_t *)(uThisProcessor().currTask->currCoroutine->storage))->uc_mcontext.gregs[REG_GS] = THREAD_GETMEM( ldtValue );    
+	    ((ucontext_t *)(uThisProcessor().currTask->currCoroutine->context))->uc_mcontext.gregs[REG_GS] = THREAD_GETMEM( ldtValue );    
 #elif defined( __ia64__ )
-	    ((ucontext_t *)(uThisProcessor().currTask->currCoroutine->storage))->uc_mcontext.sc_gr[13] = (unsigned long)THREAD_GETMEM( threadPointer );
+	    ((ucontext_t *)(uThisProcessor().currTask->currCoroutine->context))->uc_mcontext.sc_gr[13] = (unsigned long)THREAD_GETMEM( threadPointer );
 #elif defined( __sparc__ )
-	    ((ucontext_t *)(uThisProcessor().currTask->currCoroutine->storage))->uc_mcontext.gregs[REG_G7] = (int)(THREAD_GETMEM( This ) ); 
+	    ((ucontext_t *)(uThisProcessor().currTask->currCoroutine->context))->uc_mcontext.gregs[REG_G7] = (int)(THREAD_GETMEM( This ) ); 
 #endif
 #ifdef __U_ONETIMER__
 	    if ( &uThisProcessor() == uKernelModule::systemProcessor ) {
-		sigdelset( (sigset_t *)&(((ucontext_t *)(uThisProcessor().currTask->currCoroutine->storage))->uc_sigmask), SIGALRM );
+		sigdelset( (sigset_t *)&(((ucontext_t *)(uThisProcessor().currTask->currCoroutine->context))->uc_sigmask), SIGALRM );
 	    } else {
-		sigaddset( (sigset_t *)&(((ucontext_t *)(uThisProcessor().currTask->currCoroutine->storage))->uc_sigmask), SIGALRM );
+		sigaddset( (sigset_t *)&(((ucontext_t *)(uThisProcessor().currTask->currCoroutine->context))->uc_sigmask), SIGALRM );
 	    } // if
 #endif // __U_ONETIMER__
 #endif // __U_MULTI__ && __U_SWAPCONTEXT__
 #if defined( __U_MULTI__ ) && defined( __U_ONETIMER__ ) && defined( __ia64__ )
 	    if ( &uThisProcessor() == uKernelModule::systemProcessor ) {
-		sigdelset( &((uContext_t *)(uThisProcessor().currTask->currCoroutine->storage))->sigMask, SIGALRM );
+		sigdelset( &((uContext_t *)(uThisProcessor().currTask->currCoroutine->context))->sigMask, SIGALRM );
 	    } else {
-		sigaddset( &((uContext_t *)(uThisProcessor().currTask->currCoroutine->storage))->sigMask, SIGALRM );
+		sigaddset( &((uContext_t *)(uThisProcessor().currTask->currCoroutine->context))->sigMask, SIGALRM );
 	    } // if
 #endif // __U_MULTI__ && __U_ONETIMER__ && __ia64__
 
-	    uSwitch( storage, uThisProcessor().currTask->currCoroutine->storage );
+#ifdef KNOT
+	    context_switches += 1;
+#endif // KNOT
+	    uSwitch( context, uThisProcessor().currTask->currCoroutine->context );
 	    THREAD_GETMEM( This )->enableInterrupts();
 	    assert( THREAD_GETMEM( disableInt ) && THREAD_GETMEM( disableIntCnt ) > 0 );
 
@@ -749,13 +789,14 @@ void uProcessorKernel::main() {
 		    // Get next processor to execute because the current one
 		    // just terminated.
 
-		    nextProcessor( currProc );
+		    nextProcessor( currProc, cycleStart );
 		} // if
 #endif // __U_MULTI__
 	    } // if
 	} // if
 
-	uBaseTask *uReadyTask = &(uThisProcessor().currCluster->readyTaskTryRemove());
+	uReadyTask = &(uThisProcessor().currCluster->readyTaskTryRemove());
+
 	if ( uReadyTask != NULL ) {			// ready queue not empty, schedule that task
 	    assert( ! uReadyTask->readyRef.listed() );
 	    THREAD_SETMEM( activeTask, uThisProcessor().currTask = uReadyTask );
@@ -777,29 +818,32 @@ void uProcessorKernel::main() {
 
 #if defined( __U_MULTI__ ) && defined( __U_SWAPCONTEXT__ )
 #if defined( __i386__ ) && ! defined( __U_PTHREAD__ )
-	    ((ucontext_t *)(uReadyTask->currCoroutine->storage))->uc_mcontext.gregs[REG_GS] = THREAD_GETMEM( ldtValue );    
+	    ((ucontext_t *)(uReadyTask->currCoroutine->context))->uc_mcontext.gregs[REG_GS] = THREAD_GETMEM( ldtValue );    
 #elif defined( __ia64__ )
-	    ((ucontext_t *)(uReadyTask->currCoroutine->storage))->uc_mcontext.sc_gr[13] = THREAD_GETMEM( threadPointer );
+	    ((ucontext_t *)(uReadyTask->currCoroutine->context))->uc_mcontext.sc_gr[13] = THREAD_GETMEM( threadPointer );
 #elif defined( __sparc__ )
-	    ((ucontext_t *)(uReadyTask->currCoroutine->storage))->uc_mcontext.gregs[REG_G7] = (int)(THREAD_GETMEM( This ) ); 
+	    ((ucontext_t *)(uReadyTask->currCoroutine->context))->uc_mcontext.gregs[REG_G7] = (int)(THREAD_GETMEM( This ) ); 
 #endif
 #ifdef __U_ONETIMER__
 	    if ( &uThisProcessor() == uKernelModule::systemProcessor ) {
-		sigdelset( (sigset_t *)&(((ucontext_t *)(uReadyTask->currCoroutine->storage))->uc_sigmask), SIGALRM );
+		sigdelset( (sigset_t *)&(((ucontext_t *)(uReadyTask->currCoroutine->context))->uc_sigmask), SIGALRM );
 	    } else {
-		sigaddset( (sigset_t *)&(((ucontext_t *)(uReadyTask->currCoroutine->storage))->uc_sigmask), SIGALRM );
+		sigaddset( (sigset_t *)&(((ucontext_t *)(uReadyTask->currCoroutine->context))->uc_sigmask), SIGALRM );
 	    } // if
 #endif // __U_ONETIMER__
 #endif // __U_MULTI__ && __U_SWAPCONTEXT__
 #if defined( __U_MULTI__ ) && defined( __U_ONETIMER__ ) && defined( __ia64__ )
 	    if ( &uThisProcessor() == uKernelModule::systemProcessor ) {
-		sigdelset( &((uContext_t *)(uReadyTask->currCoroutine->storage))->sigMask, SIGALRM );
+		sigdelset( &((uContext_t *)(uReadyTask->currCoroutine->context))->sigMask, SIGALRM );
 	    } else {
-		sigaddset( &((uContext_t *)(uReadyTask->currCoroutine->storage))->sigMask, SIGALRM );
+		sigaddset( &((uContext_t *)(uReadyTask->currCoroutine->context))->sigMask, SIGALRM );
 	    } // if
 #endif // __U_MULTI__ && __U_ONETIMER__ && __ia64__
 
-	    uSwitch( storage, uReadyTask->currCoroutine->storage );
+#ifdef KNOT
+	    context_switches += 1;
+#endif // KNOT
+	    uSwitch( context, uReadyTask->currCoroutine->context );
 	    assert( THREAD_GETMEM( disableInt ) && THREAD_GETMEM( disableIntCnt ) > 0 );
 
 	    // SKULLDUGGERY: During spinning, the activeTask should not point
@@ -919,7 +963,7 @@ void uProcessorKernel::main() {
 
 	// Get next processor to execute.
 
-	nextProcessor( currProc );
+	nextProcessor( currProc, cycleStart );
 #endif // __U_MULTI__
     } // for
 
@@ -967,27 +1011,9 @@ uProcessorKernel::~uProcessorKernel() {
 } // uProcessorKernel::~uProcessorKernel
 
 
-void *uProcessorKernel::operator new( size_t, void *storage ) {
-    return storage;
-} // uProcessorKernel::operator new
-
-void *uProcessorKernel::operator new( size_t size ) {
-    return ::operator new( size );
-} // uProcessorKernel::operator new
-
-
 //######################### uProcessor #########################
 
 
-void *uProcessor::operator new( size_t, void *storage ) {
-    return storage;
-} // uProcessor::operator new
-
-void *uProcessor::operator new( size_t size ) {
-    return ::operator new( size );
-} // uProcessor::operator new
-
-
 void uProcessor::createProcessor( uCluster &cluster, bool detached, int ms, int spin ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uProcessor &)0x%p.createProcessor, on cluster %.256s (0x%p)\n", this, cluster.getName(), &cluster );
@@ -1020,6 +1046,7 @@ void uProcessor::createProcessor( uCluster &cluster, bool detached, int ms, int
 #endif // __U_ONETIMER__
     contextSwitchHandler = new uCxtSwtchHndlr;
     contextEvent = new uEventNode( *contextSwitchHandler, this );
+    profileProcessorSamplerInstance = NULL;
 #endif // __U_MULTI__
     terminated = false;
     currCluster->processorAdd( *this );
@@ -1148,6 +1175,10 @@ void uProcessor::fork( uProcessor *processor ) {
     sigset_t mask, old_mask;
     sigemptyset( &mask );
     sigaddset( &mask, SIGALRM );
+    sigaddset( &mask, SIGVTALRM );
+#if defined( __U_HW_OVFL_SIG__ )
+    sigaddset( &mask, __U_HW_OVFL_SIG__ );
+#endif // __U_HW_OVFL_SIG__
     sigprocmask( SIG_BLOCK, &mask, &old_mask );
     assert( &uThisProcessor() == uKernelModule::systemProcessor || sigismember( &old_mask, SIGALRM ) );
 
@@ -1192,7 +1223,7 @@ void uProcessor::fork( uProcessor *processor ) {
 #elif defined( __solaris__ )
     ucontext *ucp;
 #if defined( __U_SWAPCONTEXT__ )
-    ucp = (ucontext *)(processor->processorKer.storage);
+    ucp = (ucontext *)(processor->processorKer.context);
     // _lwp_makecontext overwrites the existing context except for the signal mask
     // so the signal mask obtained from getcontext during startHere is used
 #else
