@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1998
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1998
 // 
 // uSystemTask.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Jun 22 15:25:53 1998
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Aug 10 17:07:38 2006
-// Update Count     : 106
+// Last Modified On : Tue Jun 26 23:48:42 2007
+// Update Count     : 107
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -43,11 +43,11 @@ void uSystemTask::main() {
     for ( ;; ) {
 	_Accept( ~uSystemTask ) {
 	    break;
-	} else _Accept( reaper ) {
+	} or _Accept( reaper ) {
 	    delete victim;
-	} else _Accept( pthreadDetachEnd ) {
+	} or _Accept( pthreadDetachEnd ) {
 	    delete victim;
-	} else uTimeout( uDuration( 1 ) ) {		// 1 second
+	} or _Timeout( uDuration( 1 ) ) {		// 1 second
 	} // _Accept
 
 #if __U_LOCALDEBUGGER_H__
