@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1998
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1998
 // 
 // uSystemTask.h -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Jun 22 15:23:25 1998
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Aug 10 17:08:41 2006
-// Update Count     : 19
+// Last Modified On : Sat Jul 21 10:22:40 2007
+// Update Count     : 20
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -30,7 +30,7 @@
 
 
 _Task uSystemTask {
-    friend _Task Pthread;				// access: pthreadDetachEnd
+    friend _Task UPP::Pthread;				// access: pthreadDetachEnd
 
     uBaseTask *victim;					// communication
 
