@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 2002
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 2002
 // 
 // Unix.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Dec  2 22:46:18 2002
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Sep  1 15:46:16 2006
-// Update Count     : 20
+// Last Modified On : Fri Sep 14 09:02:08 2007
+// Update Count     : 21
 // 
 
 #define __U_KERNEL__
@@ -17,9 +17,6 @@
 
 
 extern "C" unsigned int sleep( unsigned int sec ) {
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "sleep ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ\n" );
-#endif // __U_DEBUG_H__
     _Timeout( uDuration( sec, 0 ) );
     return 0;
 } // sleep
