@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uFile.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Tue Mar 29 16:42:36 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jan 24 18:17:55 2006
-// Update Count     : 305
+// Last Modified On : Thu Sep  6 11:33:52 2007
+// Update Count     : 316
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -39,28 +39,6 @@
 //######################### uFile #########################
 
 
-void uFile::access() {
-    accessCnt += 1;
-} // uFile::access
-
-
-void uFile::unaccess() {
-    accessCnt -= 1;
-} // uFile::unaccess
-
-
-void uFile::uCreateFile( const char *name ) {
-    uFile::name = new char[strlen( name ) + 1];
-    strcpy( uFile::name, name );
-    accessCnt = 0;
-} // uFile::uCreateFile
-
-
-uFile::uFile( const char *name ) {
-    uCreateFile( name );
-} // uFile::uFile
-
-
 uFile::~uFile() {
     TerminateFailure temp( *this, accessCnt, "terminating access with outstanding accessor(s)" );
     if ( name != 0 ) delete name;			// safe to delete name as the name is copied in the exception object
@@ -80,14 +58,13 @@ const char *uFile::getName() const {
 
 
 void uFile::status( struct stat &buf ) {
-    int code;
+    int retcode;
 
     for ( ;; ) {
-	code = ::stat( name, &buf );
-      if ( code != -1 ) break;
-      if ( errno != EINTR ) break;			// timer interrupt ?
+	retcode = ::stat( name, &buf );
+      if ( retcode != -1 || errno != EINTR ) break;	// timer interrupt ?
     } // for
-    if ( code == -1 ) {
+    if ( retcode == -1 ) {
 	_Resume uFile::StatusFailure( *this, buf, "could not obtain statistical information for file" );
     } // if
 } // uFile::status
@@ -96,97 +73,38 @@ void uFile::status( struct stat &buf ) {
 //######################### uFileIO #########################
 
 
-uFileIO::uFileIO( uIOaccess &acc ) : access( acc ) {
-} // uFileIO::uFileIO
-
-
-uFileIO::~uFileIO() {
-} // uFileIO::~uFileIO
-
-
-int uFileIO::_read( char *buf, int len ) {
-    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.setPollFlag( access.fd );
-    int rlen = ::read( access.fd, buf, len );
-    int terrno = errno;					// preserve errno across calls
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "(uFileIO &)0x%p._read attempting read to fd:%d, rlen:%d, errno:%d\n", this, access.fd, rlen, errno );
-#endif // __U_DEBUG_H__
-    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.clearPollFlag( access.fd );
-    errno = terrno;
-    return rlen;
-} // uFileIO::_read
-
-
-int uFileIO::_readv( const struct iovec *iov, int iovcnt ) {
-    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.setPollFlag( access.fd );
-    int rlen = ::readv( access.fd, iov, iovcnt );
-    int terrno = errno;					// preserve errno across calls
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "(uFileIO &)0x%p._readv attempting readv to fd:%d, rlen:%d, errno:%d\n", this, access.fd, rlen, errno );
-#endif // __U_DEBUG_H__
-    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.clearPollFlag( access.fd );
-    errno = terrno;
-    return rlen;
-} // uFileIO::_readv
-
-
-int uFileIO::_write( char *buf, int len ) {
-    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.setPollFlag( access.fd );
-    int wlen = ::write( access.fd, buf, len );
-    int terrno = errno;					// preserve errno across calls
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "(uFileIO &)0x%p._write attempting write to fd:%d, wlen:%d, errno:%d\n", this, access.fd, wlen, errno );
-#endif // __U_DEBUG_H__
-    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.clearPollFlag( access.fd );
-    errno = terrno;
-    return wlen;
-} // uFileIO::_write
-
-
-int uFileIO::_writev( const struct iovec *iov, int iovcnt ) {
-    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.setPollFlag( access.fd );
-    int wlen = ::writev( access.fd, iov, iovcnt );
-    int terrno = errno;					// preserve errno across calls
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "(uFileIO &)0x%p._writev attempting writev to fd:%d, wlen:%d, errno:%d\n", this, access.fd, wlen, errno );
-#endif // __U_DEBUG_H__
-    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.clearPollFlag( access.fd );
-    errno = terrno;
-    return wlen;
-} // uFileIO::_writev
-
-
 int uFileIO::read( char *buf, int len, uDuration *timeout ) {
     int rlen;
 
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "(uFileIO &)0x%p.read attempting read to fd:%d\n", this, access.fd );
-#endif // __U_DEBUG_H__
+    struct Read : public uIOClosure {
+	char *buf;
+	int len;
 
-    for ( ;; ) {
-	rlen = _read( buf, len );
-      if ( rlen != -1 ) break;
-      if ( ! ( errno == EINTR || errno == U_EWOULDBLOCK ) ) break;
-	if ( errno == U_EWOULDBLOCK ) {
-	    int mask = uCluster::readSelect;
-	    if ( timeout == NULL ) {
-		uThisCluster().select( access.fd, mask );
-	    } else {
-		timeval t = *timeout;			// convert to timeval for select
-		if ( uThisCluster().select( access.fd, mask, &t ) == 0 ) { // timeout ?
-		    readTimeout( buf, len, timeout, "read" );
-		} // if
+	int action( int rwe ) {
+#ifdef KNOT
+	    read_syscalls += 1;
+#endif // KNOT
+	    return ::read( access.fd, buf, len );
+	}
+	Read( uIOaccess &access, int &rlen, char *buf, int len ) : uIOClosure( access, rlen ), buf( buf ), len( len ) {}
+    } readClosure( access, rlen, buf, len );
+
+    readClosure.wrapper( 0 );
+    if ( rlen == -1 ) {
+	if ( errno != U_EWOULDBLOCK ) {
+	    readFailure( buf, len, timeout, "read" );
+	} // if
+	int mask = uCluster::readSelect;
+	if ( timeout == NULL ) {
+	    uThisCluster().select( readClosure, mask );
+	} else {
+	    timeval t = *timeout;			// convert to timeval for select
+	    if ( uThisCluster().select( readClosure, mask, &t ) == 0 ) { // timeout ?
+		readTimeout( buf, len, timeout, "read" );
 	    } // if
 	} // if
-    } // for    
-
-    if ( rlen == -1 ) {
-	readFailure( buf, len, timeout, "read" );
     } // if
 
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "(uFileIO &)0x%p.read completed read to fd:%d, read:%d bytes\n", this, access.fd, rlen );
-#endif // __U_DEBUG_H__
     return rlen;
 } // uFileIO::read
 
@@ -194,77 +112,76 @@ int uFileIO::read( char *buf, int len, uDuration *timeout ) {
 int uFileIO::readv( const struct iovec *iov, int iovcnt, uDuration *timeout ) {
     int rlen;
 
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "(uFileIO &)0x%p.readv attempting read to fd:%d\n", this, access.fd );
-#endif // __U_DEBUG_H__
+    struct Readv : public uIOClosure {
+	const struct iovec *iov;
+	int iovcnt;
 
-    for ( ;; ) {
-	rlen = _readv( iov, iovcnt );
-      if ( rlen != -1 ) break;
-      if ( ! ( errno == EINTR || errno == U_EWOULDBLOCK ) ) break;
-	if ( errno == U_EWOULDBLOCK ) {
-	    int mask = uCluster::readSelect;
-	    if ( timeout == NULL ) {
-		uThisCluster().select( access.fd, mask );
-	    } else {
-		timeval t = *timeout;			// convert to timeval for select
-		if ( uThisCluster().select( access.fd, mask, &t ) == 0 ) { // timeout ?
-		    readTimeout( (const char *)iov, iovcnt, timeout, "readv" );
-		} // if
+	int action( int rwe ) { return ::readv( access.fd, iov, iovcnt ); }
+	Readv( uIOaccess &access, int &rlen, const struct iovec *iov, int iovcnt ) : uIOClosure( access, rlen ), iov( iov ), iovcnt( iovcnt ) {}
+    } readvClosure( access, rlen, iov, iovcnt );
+
+    readvClosure.wrapper( 0 );
+    if ( rlen == -1 ) {
+	if ( errno != U_EWOULDBLOCK ) {
+	    readFailure( (const char *)iov, iovcnt, timeout, "readv" );
+	} // if
+	int mask = uCluster::readSelect;
+	if ( timeout == NULL ) {
+	    uThisCluster().select( readvClosure, mask );
+	} else {
+	    timeval t = *timeout;			// convert to timeval for select
+	    if ( uThisCluster().select( readvClosure, mask, &t ) == 0 ) { // timeout ?
+		readTimeout( (const char *)iov, iovcnt, timeout, "readv" );
 	    } // if
 	} // if
-    } // for    
-    if ( rlen == -1 ) {
-	readFailure( (const char *)iov, iovcnt, timeout, "readv" );
     } // if
 
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "(uFileIO &)0x%p.readv completed read to fd:%d, read:%d bytes\n", this, access.fd, rlen );
-#endif // __U_DEBUG_H__
     return rlen;
 } // uFileIO::readv
 
 
-int uFileIO::write( char *buf, int len, uDuration *timeout ) {
+int uFileIO::write( const char *buf, int len, uDuration *timeout ) {
     int count, wlen;
 
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "(uFileIO &)0x%p.write attempting write to fd:%d\n", this, access.fd );
-#endif // __U_DEBUG_H__
+    struct Write : public uIOClosure {
+	const char *buf;
+	int len;
+
+	int action( int rwe ) {
+#ifdef KNOT
+	    write_syscalls += 1;
+#endif // KNOT
+	    return ::write( access.fd, buf, len );
+	}
+	Write( uIOaccess &access, int &wlen ) : uIOClosure( access, wlen ) {}
+    } writeClosure( access, wlen );
 
     for ( count = 0; count < len; count += wlen ) {	// ensure all data is written
-	for ( ;; ) {
-	    wlen = _write( buf + count, len - count );
-	  if ( wlen != -1 ) break;
-	  if ( ! ( errno == EINTR || errno == U_EWOULDBLOCK ) ) break;
-	    if ( errno == U_EWOULDBLOCK ) {
-		int mask = uCluster::writeSelect;
-		if ( timeout == NULL ) {
-		    uThisCluster().select( access.fd, mask );
-		} else {
-		    timeval t = *timeout;		// convert to timeval for select
-		    if ( uThisCluster().select( access.fd, mask, &t ) == 0 ) { // timeout ?
-			writeTimeout( buf, len, timeout, "write" );
-		    } // if
+	writeClosure.buf = buf + count;
+	writeClosure.len = len - count;
+	writeClosure.wrapper( 0 );
+	if ( wlen == -1 ) {
+	    if ( errno != U_EWOULDBLOCK ) {
+		// EIO means the write is to stdout but the shell has terminated (I
+		// think). Normally, people want this to work as if stdout is
+		// magically redirected to /dev/null, instead of aborting the
+		// program.
+      if ( errno == EIO ) goto fini;
+		writeFailure( buf, len, timeout, "write" );
+	    } // if
+	    int mask = uCluster::writeSelect;
+	    if ( timeout == NULL ) {
+		uThisCluster().select( writeClosure, mask );
+	    } else {
+		timeval t = *timeout;			// convert to timeval for select
+		if ( uThisCluster().select( writeClosure, mask, &t ) == 0 ) { // timeout ?
+		    writeTimeout( buf, len, timeout, "write" );
 		} // if
 	    } // if
-	} // for
-
-	if ( wlen == -1 ) {
-	    // EIO means the write is to stdout but the shell has terminated (I
-	    // think). Normally, people want this to work as if stdout is
-	    // magically redirected to /dev/null, instead of aborting the
-	    // program.
-
-      if ( errno == EIO ) break;
-
-      	    writeFailure( buf, len, timeout, "write" );
 	} // if
     } // for
+  fini:
 
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "(uFileIO &)0x%p.write completed write to fd:%d, wrote:%d bytes\n", this, access.fd, len );
-#endif // __U_DEBUG_H__
     return len;						// always return the specified length
 } // uFileIO::write
 
@@ -272,47 +189,39 @@ int uFileIO::write( char *buf, int len, uDuration *timeout ) {
 int uFileIO::writev( const struct iovec *iov, int iovcnt, uDuration *timeout ) {
     int wlen;
 
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "(uFileIO &)0x%p.writev attempting write to fd:%d\n", this, access.fd );
-#endif // __U_DEBUG_H__
+    struct Writev : public uIOClosure {
+	const struct iovec *iov;
+	int iovcnt;
 
-    for ( ;; ) {
-	wlen = _writev( iov, iovcnt );
-      if ( wlen != -1 ) break;
-      if ( ! ( errno == EINTR || errno == U_EWOULDBLOCK ) ) break;
-	if ( errno == U_EWOULDBLOCK ) {
-	    int mask = uCluster::writeSelect;
-	    if ( timeout == NULL ) {
-		uThisCluster().select( access.fd, mask );
-	    } else {
-		timeval t = *timeout;		// convert to timeval for select
-		if ( uThisCluster().select( access.fd, mask, &t ) == 0 ) { // timeout ?
-		    writeTimeout( (const char *)iov, iovcnt, timeout, "writev" );
-		} // if
+	int action( int rwe ) { return ::writev( access.fd, iov, iovcnt ); }
+	Writev( uIOaccess &access, int &wlen, const struct iovec *iov, int iovcnt ) : uIOClosure( access, wlen ), iov( iov ), iovcnt( iovcnt ) {}
+    } writevClosure( access, wlen, iov, iovcnt );
+
+    writevClosure.wrapper( 0 );
+    if ( wlen == -1 ) {
+	if ( errno != U_EWOULDBLOCK ) {
+	    // EIO means the write is to stdout but the shell has terminated (I
+	    // think). Normally, people want this to work as if stdout is magically
+	    // redirected to /dev/null, instead of aborting the program.
+      if ( errno == EIO ) goto fini;
+	    writeFailure( (const char *)iov, iovcnt, timeout, "writev" );
+	} // if
+	int mask = uCluster::writeSelect;
+	if ( timeout == NULL ) {
+	    uThisCluster().select( writevClosure, mask );
+	} else {
+	    timeval t = *timeout;			// convert to timeval for select
+	    if ( uThisCluster().select( writevClosure, mask, &t ) == 0 ) { // timeout ?
+		writeTimeout( (const char *)iov, iovcnt, timeout, "writev" );
 	    } // if
 	} // if
-    } // for
-
-    // EIO means the write is to stdout but the shell has terminated (I
-    // think). Normally, people want this to work as if stdout is magically
-    // redirected to /dev/null, instead of aborting the program.
-
-    if ( wlen == -1 && errno != EIO ) {
-	writeFailure( (const char *)iov, iovcnt, timeout, "writev" );
     } // if
+  fini:
 
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "(uFileIO &)0x%p.writev completed write to fd:%d, wrote:%d bytes\n", this, access.fd, wlen );
-#endif // __U_DEBUG_H__
     return wlen;
 } // uFileIO::writev
 
 
-int uFileIO::fd() {
-    return access.fd;
-} // uFileIO::fd
-
-
 //######################### uFileAccess #########################
 
 
@@ -344,18 +253,10 @@ void uFileAccess::writeTimeout( const char *buf, const int len, const uDuration
 } // uFileAccess::writeTimeout
 
 
-uFileAccess::uFileAccess( int fd, uFile &f ) : uFileIO( access ), ufile( f ) {
-    access.fd = fd;
-    access.poll.setStatus( uPoll::PollOnDemand );
-    ufile.access();
-} // uFileAccess::uFileAccess
-
-
 uFileAccess::uFileAccess( uFile &f, int flags, int mode ) : uFileIO( access ), ufile( f ) {
     for ( ;; ) {
 	access.fd = ::open( ufile.name, flags, mode );
-      if ( access.fd != -1 ) break;
-      if ( errno != EINTR ) break;			// timer interrupt ?
+      if ( access.fd != -1 || errno != EINTR ) break;	// timer interrupt ?
     } // for
     if ( access.fd == -1 ) {
         _Throw uFileAccess::OpenFailure( *this, flags, mode, "unable to access file" );
@@ -370,15 +271,14 @@ uFileAccess::~uFileAccess() {
     ufile.unaccess();
     if ( access.poll.getStatus() == uPoll::AlwaysPoll ) access.poll.clearPollFlag( access.fd );
     if ( access.fd >= 3 ) {				// don't close the standard file descriptors
-	int code;
+	int retcode;
 
 	uThisCluster().closeFD( access.fd );
 	for ( ;; ) {
-	    code = ::close( access.fd );
-	  if ( code != -1 ) break;
-	  if ( errno != EINTR ) break;			// timer interrupt ?
+	    retcode = ::close( access.fd );
+	  if ( retcode != -1 || errno != EINTR ) break;	// timer interrupt ?
 	} // for
-	if ( code == -1 ) {
+	if ( retcode == -1 ) {
 	    if ( ! std::uncaught_exception() ) _Resume uFileAccess::CloseFailure( *this, "unable to terminate access to file" );
 	} // if
     } // if
@@ -386,32 +286,30 @@ uFileAccess::~uFileAccess() {
 
 
 off_t uFileAccess::lseek( off_t offset, int whence ) {
-    off_t code;
+    off_t retcode;
 
     for ( ;; ) {
-	code = ::lseek( access.fd, offset, whence );
-      if ( code != -1 ) break;
-      if ( errno != EINTR ) break;			// timer interrupt ?
+	retcode = ::lseek( access.fd, offset, whence );
+      if ( retcode != -1 || errno != EINTR ) break;	// timer interrupt ?
     } // for
-    if ( code == -1 ) {
+    if ( retcode == -1 ) {
         _Throw uFileAccess::SeekFailure( *this, offset, whence, "could not seek file" );
     } // if
-    return code;
+    return retcode;
 } // uFileAccess::lseek
 
 
 int uFileAccess::fsync() {
-    int code;
+    int retcode;
 
     for ( ;; ) {
-	code = ::fsync( access.fd );
-      if ( code != -1 ) break;
-      if ( errno != EINTR ) break;			// timer interrupt ?
+	retcode = ::fsync( access.fd );
+      if ( retcode != -1 || errno != EINTR ) break;	// timer interrupt ?
     } // for
-    if ( code == -1 ) {
+    if ( retcode == -1 ) {
         _Throw uFileAccess::SyncFailure( *this, "could not fsync file" );
     } // if
-    return code;
+    return retcode;
 } // uFileAccess::fsync
 
 
@@ -423,8 +321,6 @@ uFile::Failure::Failure( const uFile &f, const char *const msg ) : uIOFailure( m
     uEHM::strncpy( name, f.getName(), uEHMMaxName );
 } // uFile::Failure::Failure
 
-uFile::Failure::~Failure() {}
-
 const uFile &uFile::Failure::file() const { return f; }
 
 const char *uFile::Failure::getName() const { return name; }
