@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1998
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1998
 // 
 // uIOcntl.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Wed Jun 10 16:11:30 1998
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Jul 11 21:02:32 2003
-// Update Count     : 20
+// Last Modified On : Thu Sep  6 11:36:46 2007
+// Update Count     : 21
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -31,6 +31,19 @@
 #include <uIOcntl.h>
 
 
+int uIOClosure::wrapper( int rwe ) {
+    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.setPollFlag( access.fd );
+    for ( ;; ) {
+	retcode = action( rwe );
+      if ( retcode != -1 || errno != EINTR ) break;	// timer interrupt ?
+    } // for
+    int terrno = errno;					// preserve errno across calls
+    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.clearPollFlag( access.fd );
+    errno = terrno;
+
+    return retcode;
+} // uIOClosure::wrapper
+
 
 // Local Variables: //
 // compile-command: "gmake install" //
