@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uIOcntl.h -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Tue Mar 29 16:49:48 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jul 15 12:04:49 2003
-// Update Count     : 55
+// Last Modified On : Thu Sep  6 11:37:21 2007
+// Update Count     : 56
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -42,6 +42,18 @@ struct uIOaccess {
 }; // uIOaccess
 
 
+struct uIOClosure {
+    uIOaccess &access;
+    int &retcode;
+
+    uIOClosure( uIOaccess &access, int &retcode ) : access( access ), retcode( retcode ) {}
+    virtual ~uIOClosure() {}
+
+    int wrapper( int rwe );
+    virtual int action( int rwe ) = 0;
+}; // uIOClosure
+
+
 #pragma __U_USER_CODE__
 
 #endif // __U_IOCNTL_H__
