@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uSemaphore.h -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Tue Mar 29 13:42:33 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Aug 16 09:26:36 2006
-// Update Count     : 65
+// Last Modified On : Wed Jul 11 15:37:37 2007
+// Update Count     : 75
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -32,29 +32,7 @@
 
 #ifndef __U_SEMAPHORE_MONITOR__
 
-class uSemaphore {
-    // These data fields must be initialized to zero. Therefore, this lock can
-    // be used in the same storage area as a sem_t, if sizeof(sem_t) >=
-    // sizeof(uSemaphore).
-
-    uSpinLock spin;
-    int count;
-    uQueue<uBaseTaskDL> waiting;
-
-    uSemaphore( uSemaphore & );				// no copy
-    uSemaphore &operator=( uSemaphore & );		// no assignment
-  public:
-    uSemaphore( unsigned int count = 1 );
-    void P();						// wait on a semaphore
-    void P( uSemaphore &s );				// wait on a semaphore and release another
-    bool TryP();					// conditionally wait on a semaphore
-    void V( unsigned int times = 1 );			// signal a semaphore
-    int counter() const;				// semaphore counter
-    bool empty() const;					// no tasks waiting on semaphore ?
-
-    void *operator new( size_t, void *storage );
-    void *operator new( size_t size );
-}; // uSemaphore
+using UPP::uSemaphore;
 
 #else
 
