@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Robert Denda 1997
+// uC++ Version 5.5.0, Copyright (C) Robert Denda 1997
 // 
 // uProfiler.cc -- 
 // 
 // Author           : Robert Denda
 // Created On       : Tue Jul 16 16:45:16 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Aug 15 08:47:09 2006
-// Update Count     : 699
+// Last Modified On : Thu Jul 12 16:30:02 2007
+// Update Count     : 702
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -106,10 +106,8 @@ _Task uProfiler {
     friend class uHeapManager;				// access: profilerInstance
     friend void *malloc( size_t size ) __THROW;		// access: profilerInstance
     friend void *memalign( size_t alignment, size_t size ) __THROW; // access: profilerInstance
-    friend class uCondLock;                             // access: profilerInstance
-    friend class uOwnerLock;                            // access: profilerInstance
     friend class uCondition;				// access: profilerInstance                    
-    friend class uEventList;                            // access: profilerInstance
+    friend class UPP::uProcessorKernel;			// access: profilerInstance
 
     // profiling
     friend class uProfilerBoot;
@@ -155,7 +153,6 @@ _Task uProfiler {
     void		 *currentFunction;
     void		 *callingFunction;
     void		 *firstArg;
-    uTime                 contextSwTime;		// used to reduced the number of calls to getTime(), which is expensive
     void                 *memAddress;
     size_t                memSizeRequested, memSizeAllocated;
     
@@ -223,6 +220,8 @@ _Task uProfiler {
     mutable uSequence<uExecutionMonitorNode> &registerMemoryDeallocateMonitorList;
     mutable uSequence<uExecutionMonitorNode> &pollDecentrList;                // list of monitors to be periodically polled
     mutable uSequence<uExecutionMonitorNode> &pollMonitorList;                
+    mutable uSequence<uExecutionMonitorNode> &profileInactivateDecentrList;
+    mutable uSequence<uExecutionMonitorNode> &profileInactivateMonitorList;        
 	 
     // built in monitoring modules 
     mutable uSequence<uExecutionMonitorNode> &builtinRegisterTaskBlockDecentrList; // list of monitors to be informed upon task block
@@ -280,7 +279,8 @@ _Task uProfiler {
     _Mutex void registerSetNameMutex( const uBaseCoroutine &coroutine, const char *name );
     _Mutex void registerMemoryAllocateMutex( void *address, size_t sizeRequested, size_t sizeAllocated, const uBaseTask &task );
     _Mutex void registerMemoryDeallocateMutex( void *address, size_t requestedSize, const uBaseTask &task );
-     
+    _Mutex void profileInactivateMutex( const uBaseTask &task );
+
     _Mutex void Finish();
   public:
     uProfiler();
@@ -323,6 +323,7 @@ _Task uProfiler {
     _Nomutex MMInfoEntry *registerMemoryAllocate( void *address, size_t sizeRequested, size_t sizeAllocated );
     _Nomutex void registerMemoryDeallocate( void *address, size_t requestedSize, MMInfoEntry *entry );
     _Nomutex void poll();
+    _Nomutex void profileInactivate( const uBaseTask &task );
 
     // built-in modules (do not have corresponding mutex members => cannot be used by user metrics)
     _Nomutex void builtinRegisterTaskBlock( const uBaseTask &task ); // not allowed to block ( hook inside context switch routine )
@@ -367,7 +368,8 @@ _Task uProfiler {
     static void (* uProfiler_registerSetName)(uProfiler *, const uBaseCoroutine &, const char * );
     static MMInfoEntry *(* uProfiler_registerMemoryAllocate)(uProfiler *, void *, size_t, size_t );
     static void (* uProfiler_registerMemoryDeallocate)(uProfiler *, void *, size_t, MMInfoEntry * );
-    
+    static void (* uProfiler_profileInactivate)(uProfiler *, const uBaseTask & );
+
     // hooks for built in metrics (cannot be used by user metrics because they do not notify execution monitors)
 
     static void (* uProfiler_builtinRegisterTaskBlock)(uProfiler *, const uBaseTask & );
