@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1999
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1999
 // 
 // uRealTime.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Feb  1 15:06:12 1999
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Sep 12 08:12:00 2006
-// Update Count     : 72
+// Last Modified On : Wed Oct  4 17:28:53 2006
+// Update Count     : 73
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -119,33 +119,33 @@ void uPrioritySeq::onRelease( uBaseTask &owner ) {
 
 uRealTimeBaseTask::uRealTimeBaseTask( uCluster &cluster ) : uBaseTask( cluster ) {};
 
-uRealTimeBaseTask::uRealTimeBaseTask( uTime _firstActivateTask, uTime _endTime, uDuration _deadline, uCluster &cluster ) : uBaseTask( cluster ) {
-    if ( _deadline < 0 ) {
+uRealTimeBaseTask::uRealTimeBaseTask( uTime firstActivateTask_, uTime endTime_, uDuration deadline_, uCluster &cluster ) : uBaseTask( cluster ) {
+    if ( deadline_ < 0 ) {
 	uAbort( "Attempt to create real time task with deadline less than 0." );
     } // if
-    firstActivateTime = _firstActivateTask;
-    endTime = _endTime;
-    deadline = _deadline;
+    firstActivateTime = firstActivateTask_;
+    endTime = endTime_;
+    deadline = deadline_;
 } // uRealTimeBaseTask::uRealTimeBaseTask
 
-uRealTimeBaseTask::uRealTimeBaseTask( uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster ) : uBaseTask( cluster ) {
-    if ( _deadline < 0 ) {
+uRealTimeBaseTask::uRealTimeBaseTask( uEvent firstActivateEvent_, uTime endTime_, uDuration deadline_, uCluster &cluster ) : uBaseTask( cluster ) {
+    if ( deadline_ < 0 ) {
 	uAbort( "Attempt to create real time task with deadline less than 0." );
     } // if
-    firstActivateEvent = _firstActivateEvent;
+    firstActivateEvent = firstActivateEvent_;
     firstActivateTime = 0;
-    endTime = _endTime;
-    deadline = _deadline;
+    endTime = endTime_;
+    deadline = deadline_;
 } // uRealTimeBaseTask::uRealTimeBaseTask
 
-uRealTimeBaseTask::uRealTimeBaseTask( uTime _firstActivateTask, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster ) : uBaseTask( cluster ) {
-    if ( _deadline < 0 ) {
+uRealTimeBaseTask::uRealTimeBaseTask( uTime firstActivateTask_, uEvent firstActivateEvent_, uTime endTime_, uDuration deadline_, uCluster &cluster ) : uBaseTask( cluster ) {
+    if ( deadline_ < 0 ) {
 	uAbort( "Attempt to create real time task with deadline less than 0." );
     } // if
-    firstActivateTime = _firstActivateTask;
-    firstActivateEvent = _firstActivateEvent;
-    endTime = _endTime;
-    deadline = _deadline;
+    firstActivateTime = firstActivateTask_;
+    firstActivateEvent = firstActivateEvent_;
+    endTime = endTime_;
+    deadline = deadline_;
 } // uRealTimeBaseTask::uRealTimeBaseTask
 
 uRealTimeBaseTask::~uRealTimeBaseTask() {
@@ -158,7 +158,7 @@ uDuration uRealTimeBaseTask::getDeadline() const {
     return deadline;
 } // uRealTimeBaseTask::getDeadline
 
-uDuration uRealTimeBaseTask::setDeadline( uDuration _deadline ) {
+uDuration uRealTimeBaseTask::setDeadline( uDuration deadline_ ) {
 #ifdef __U_DEBUG__
     if ( this != &uThisTask() ) {
 	uAbort( "Attempt to change the deadline of task %.256s (0x%p).\n"
@@ -170,10 +170,10 @@ uDuration uRealTimeBaseTask::setDeadline( uDuration _deadline ) {
     // A simple optimization: changing the deadline of a task to its existing
     // value does not require a recalculation of priorities.
 	
-  if ( _deadline == deadline ) return deadline;
+  if ( deadline_ == deadline ) return deadline;
 
     uDuration temp = deadline;
-    deadline = _deadline;
+    deadline = deadline_;
     uThisCluster().taskReschedule( *this );
     yield();
     return temp;
@@ -219,27 +219,27 @@ int uRealTimeBaseTask::setVersion( uCluster &cluster, int version ) {
 //######################### uPeriodicBaseTask #########################
 
 
-uPeriodicBaseTask::uPeriodicBaseTask( uDuration _period, uCluster &cluster ) : uRealTimeBaseTask( uTime(0), uTime(0), uDuration(0), cluster ) {
-    period = _period;
+uPeriodicBaseTask::uPeriodicBaseTask( uDuration period_, uCluster &cluster ) : uRealTimeBaseTask( uTime(0), uTime(0), uDuration(0), cluster ) {
+    period = period_;
 } // uPeriodicBaseTask::uPeriodicBaseTask
 
-uPeriodicBaseTask::uPeriodicBaseTask( uDuration _period, uTime _firstActivateTask, uTime _endTime, uDuration _deadline, uCluster &cluster ) : uRealTimeBaseTask( _firstActivateTask, _endTime, _deadline, cluster ) {
-    period = _period;
+uPeriodicBaseTask::uPeriodicBaseTask( uDuration period_, uTime firstActivateTask_, uTime endTime_, uDuration deadline_, uCluster &cluster ) : uRealTimeBaseTask( firstActivateTask_, endTime_, deadline_, cluster ) {
+    period = period_;
 } // uPeriodicBaseTask::uPeriodicBaseTask
 
-uPeriodicBaseTask::uPeriodicBaseTask( uDuration _period, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster ) : uRealTimeBaseTask( _firstActivateEvent, _endTime, _deadline, cluster ) {
-    period = _period;
+uPeriodicBaseTask::uPeriodicBaseTask( uDuration period_, uEvent firstActivateEvent_, uTime endTime_, uDuration deadline_, uCluster &cluster ) : uRealTimeBaseTask( firstActivateEvent_, endTime_, deadline_, cluster ) {
+    period = period_;
 } // uPeriodicBaseTask::uPeriodicBaseTask
 
-uPeriodicBaseTask::uPeriodicBaseTask( uDuration _period, uTime _firstActivateTask, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster ) : uRealTimeBaseTask( _firstActivateTask, _firstActivateEvent, _endTime, _deadline, cluster ) {
-    period = _period;
+uPeriodicBaseTask::uPeriodicBaseTask( uDuration period_, uTime firstActivateTask_, uEvent firstActivateEvent_, uTime endTime_, uDuration deadline_, uCluster &cluster ) : uRealTimeBaseTask( firstActivateTask_, firstActivateEvent_, endTime_, deadline_, cluster ) {
+    period = period_;
 } // uPeriodicBaseTask::uPeriodicBaseTask
 
 uDuration uPeriodicBaseTask::getPeriod() const {
     return period;
 } // uPeriodicBaseTask::getPeriod
 
-uDuration uPeriodicBaseTask::setPeriod( uDuration _period ) {
+uDuration uPeriodicBaseTask::setPeriod( uDuration period_ ) {
 #ifdef __U_DEBUG__
     if ( this != &uThisTask() ) {
 	uAbort( "Attempt to change the period of task %.256s (0x%p).\n"
@@ -251,10 +251,10 @@ uDuration uPeriodicBaseTask::setPeriod( uDuration _period ) {
     // A simple optimization: changing the period of a task to its existing
     // value does not require a recalculation of priorities.
 	
-  if ( _period == period ) return period;
+  if ( period_ == period ) return period;
 
     uDuration temp = period;
-    period = _period;
+    period = period_;
     uThisCluster().taskReschedule( *this );
     yield();
     return temp;
@@ -264,27 +264,27 @@ uDuration uPeriodicBaseTask::setPeriod( uDuration _period ) {
 //######################### uSporadicBaseTask #########################
 
 
-uSporadicBaseTask::uSporadicBaseTask( uDuration _frame, uCluster &cluster ) : uRealTimeBaseTask( uTime(0), uTime(0), uDuration(0), cluster ) {
-    frame = _frame;
+uSporadicBaseTask::uSporadicBaseTask( uDuration frame_, uCluster &cluster ) : uRealTimeBaseTask( uTime(0), uTime(0), uDuration(0), cluster ) {
+    frame = frame_;
 } // uSporadicBaseTask::uSporadicBaseTask
 
-uSporadicBaseTask::uSporadicBaseTask( uDuration _frame, uTime _firstActivateTask, uTime _endTime, uDuration _deadline, uCluster &cluster ) : uRealTimeBaseTask( _firstActivateTask, _endTime, _deadline, cluster ) {
-    frame = _frame;
+uSporadicBaseTask::uSporadicBaseTask( uDuration frame_, uTime firstActivateTask_, uTime endTime_, uDuration deadline_, uCluster &cluster ) : uRealTimeBaseTask( firstActivateTask_, endTime_, deadline_, cluster ) {
+    frame = frame_;
 } // uSporadicBaseTask::uSporadicBaseTask
 
-uSporadicBaseTask::uSporadicBaseTask( uDuration _frame, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster ) : uRealTimeBaseTask( _firstActivateEvent, _endTime, _deadline, cluster ) {
-    frame = _frame;
+uSporadicBaseTask::uSporadicBaseTask( uDuration frame_, uEvent firstActivateEvent_, uTime endTime_, uDuration deadline_, uCluster &cluster ) : uRealTimeBaseTask( firstActivateEvent_, endTime_, deadline_, cluster ) {
+    frame = frame_;
 } // uSporadicBaseTask::uSporadicBaseTask
 
-uSporadicBaseTask::uSporadicBaseTask( uDuration _frame, uTime _firstActivateTask, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster ) : uRealTimeBaseTask( _firstActivateTask, _firstActivateEvent, _endTime, _deadline, cluster ) {
-    frame = _frame;
+uSporadicBaseTask::uSporadicBaseTask( uDuration frame_, uTime firstActivateTask_, uEvent firstActivateEvent_, uTime endTime_, uDuration deadline_, uCluster &cluster ) : uRealTimeBaseTask( firstActivateTask_, firstActivateEvent_, endTime_, deadline_, cluster ) {
+    frame = frame_;
 } // uSporadicBaseTask::uSporadicBaseTask
 
 uDuration uSporadicBaseTask::getFrame() const {
     return frame;
 } // uSporadicBaseTask::getFrame
 
-uDuration uSporadicBaseTask::setFrame( uDuration _frame ) {
+uDuration uSporadicBaseTask::setFrame( uDuration frame_ ) {
 #ifdef __U_DEBUG__
     if ( this != &uThisTask() ) {
 	uAbort( "Attempt to change the frame of task %.256s (0x%p).\n"
@@ -296,10 +296,10 @@ uDuration uSporadicBaseTask::setFrame( uDuration _frame ) {
     // A simple optimization: changing the frame of a task to its existing
     // value does not require a recalculation of priorities.
 	
-  if ( _frame == frame ) return frame;
+  if ( frame_ == frame ) return frame;
 
     uDuration temp = frame;
-    frame = _frame;
+    frame = frame_;
     uThisCluster().taskReschedule( *this );
     yield();
     return temp;
