@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Philipp E. Lim 1996
+// uC++ Version 5.5.0, Copyright (C) Philipp E. Lim 1996
 // 
 // uRealTime.h -- 
 // 
 // Author           : Philipp E. Lim
 // Created On       : Fri Jul 19 16:34:59 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Sep 12 08:12:08 2006
-// Update Count     : 113
+// Last Modified On : Wed Oct  4 17:30:28 2006
+// Update Count     : 114
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -189,12 +189,12 @@ class uRealTimeBaseTask : public uBaseTask {
     uTime endTime;
   public:
     uRealTimeBaseTask( uCluster &cluster = uThisCluster() );
-    uRealTimeBaseTask( uTime _firstActivateTask, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
-    uRealTimeBaseTask( uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
-    uRealTimeBaseTask( uTime _firstActivateTask, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
+    uRealTimeBaseTask( uTime firstActivateTask_, uTime endTime_, uDuration deadline_, uCluster &cluster = uThisCluster() );
+    uRealTimeBaseTask( uEvent firstActivateEvent_, uTime endTime_, uDuration deadline_, uCluster &cluster = uThisCluster() );
+    uRealTimeBaseTask( uTime firstActivateTask_, uEvent firstActivateEvent_, uTime endTime_, uDuration deadline_, uCluster &cluster = uThisCluster() );
     ~uRealTimeBaseTask();
     virtual uDuration getDeadline() const;
-    virtual uDuration setDeadline( uDuration _deadline );
+    virtual uDuration setDeadline( uDuration deadline_ );
 
     // These members should be private but cannot be because they are
     // referenced from user code.
@@ -211,12 +211,12 @@ class uPeriodicBaseTask : public uRealTimeBaseTask {
   protected:
     uDuration period;
   public:
-    uPeriodicBaseTask( uDuration _period, uCluster &cluster = uThisCluster() );
-    uPeriodicBaseTask( uDuration _period, uTime _firstActivateTask, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
-    uPeriodicBaseTask( uDuration _period, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
-    uPeriodicBaseTask( uDuration _period, uTime _firstActivateTask, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
+    uPeriodicBaseTask( uDuration period_, uCluster &cluster = uThisCluster() );
+    uPeriodicBaseTask( uDuration period_, uTime firstActivateTask_, uTime endTime_, uDuration deadline_, uCluster &cluster = uThisCluster() );
+    uPeriodicBaseTask( uDuration period_, uEvent firstActivateEvent_, uTime endTime_, uDuration deadline_, uCluster &cluster = uThisCluster() );
+    uPeriodicBaseTask( uDuration period_, uTime firstActivateTask_, uEvent firstActivateEvent_, uTime endTime_, uDuration deadline_, uCluster &cluster = uThisCluster() );
     uDuration getPeriod() const;
-    uDuration setPeriod( uDuration _period );
+    uDuration setPeriod( uDuration period_ );
 }; // uPeriodicBaseTask
 
 
@@ -227,12 +227,12 @@ class uSporadicBaseTask : public uRealTimeBaseTask {
   protected:
     uDuration frame;
   public:
-    uSporadicBaseTask( uDuration _frame, uCluster &cluster = uThisCluster() );
-    uSporadicBaseTask( uDuration _frame, uTime _firstActivateTask, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
-    uSporadicBaseTask( uDuration _frame, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
-    uSporadicBaseTask( uDuration _frame, uTime _firstActivateTask, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
+    uSporadicBaseTask( uDuration frame_, uCluster &cluster = uThisCluster() );
+    uSporadicBaseTask( uDuration frame_, uTime firstActivateTask_, uTime endTime_, uDuration deadline_, uCluster &cluster = uThisCluster() );
+    uSporadicBaseTask( uDuration frame_, uEvent firstActivateEvent_, uTime endTime_, uDuration deadline_, uCluster &cluster = uThisCluster() );
+    uSporadicBaseTask( uDuration frame_, uTime firstActivateTask_, uEvent firstActivateEvent_, uTime endTime_, uDuration deadline_, uCluster &cluster = uThisCluster() );
     uDuration getFrame() const;
-    uDuration setFrame( uDuration _frame );
+    uDuration setFrame( uDuration frame_ );
 }; // uSporadicBaseTask
 
 
