@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
 // 
 // attribute.h -- 
 // 
 // Author           : Richard A. Stroobosscher
 // Created On       : Tue Apr 28 16:02:53 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jun 21 18:08:08 2005
-// Update Count     : 40
+// Last Modified On : Sat Feb 10 10:37:36 2007
+// Update Count     : 41
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -48,12 +48,14 @@ union declqualifier {
 	bool STATIC : 1;
 	bool EXTERN : 1;
 	bool MUTABLE : 1;
+	bool THREAD : 1;
 	bool EXTENSION : 1;
 	bool INLINE : 1;
 	bool VIRTUAL : 1;
 	bool EXPLICIT : 1;
 	bool CONST : 1;
 	bool VOLATILE : 1;
+	bool RESTRICT : 1;
     } qual;
 };
 
