@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 2003
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 2003
 // 
 // cc1plus.cc -- 
 // 
 // Author           : Peter A Buhr
 // Created On       : Tue Feb 25 09:04:44 2003
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Jan 25 17:35:34 2006
-// Update Count     : 118
+// Last Modified On : Fri Jun 22 17:39:48 2007
+// Update Count     : 119
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -28,6 +28,8 @@
 #include <string>
 using std::string;
 #include <cstdio>
+#include <cstdlib>					// getenv, exit
+#include <cstring>					// strcmp, strlen
 #include <unistd.h>					// execvp, fork, unlink
 #include <sys/wait.h>					// wait
 
