@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
 // 
 // gen.c -- 
 // 
 // Author           : Richard A. Stroobosscher
 // Created On       : Tue Apr 28 15:00:53 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Jan 27 07:49:07 2006
-// Update Count     : 807
+// Last Modified On : Fri Jul 20 17:54:52 2007
+// Update Count     : 877
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -32,6 +32,7 @@
 #include "table.h"
 #include "input.h"
 #include "gen.h"
+#include <cstring>					// strlen, strcpy, strcat
 
 
 void gen_code( token_t *before, const char text ) {
@@ -75,8 +76,7 @@ void gen_class( token_t *before ) {
 void gen_base_clause( token_t *before, symbol_t *symbol ) {
     uassert( symbol != NULL );
 
-    if ( ( symbol->data->key == COROUTINE || symbol->data->key == TASK ||
-	   symbol->data->key == DUALEVENT || symbol->data->key == RESUMEEVENT || symbol->data->key == THROWEVENT ) &&
+    if ( ( symbol->data->key == COROUTINE || symbol->data->key == TASK || symbol->data->key == EVENT ) &&
 	 ( symbol->data->base == NULL ||
 	   ( symbol->data->base->data->attribute.Mutex && ( symbol->data->base->data->key == STRUCT || symbol->data->base->data->key == CLASS ) ) ) ) {
 	uassert( before != NULL );
@@ -108,12 +108,8 @@ void gen_base_clause( token_t *before, symbol_t *symbol ) {
 	    } else {
 		gen_code( next, "public uBaseTask" );
 	    } // if
-	} else if ( symbol->data->key == DUALEVENT ) {
-	    gen_code( next, "public uEHM :: uDualClass" );
-	} else if ( symbol->data->key == RESUMEEVENT ) {
-	    gen_code( next, "public uEHM :: uResumeClass" );
-	} else if ( symbol->data->key == THROWEVENT ) {
-	    gen_code( next, "public uEHM :: uThrowClass" );
+	} else if ( symbol->data->key == EVENT ) {
+	    gen_code( next, "public uBaseEvent" );
 	} // if
 
 	// insert a comma if the base specifier list is already started
@@ -417,7 +413,7 @@ void gen_base_specifier_name( token_t *before, symbol_t *symbol ) {
 // consistent check for user and generated source when checking for exisitng
 // initializers.
 
-void gen_initializer( token_t *before, symbol_t *symbol, char prefix ) {
+void gen_initializer( token_t *before, symbol_t *symbol, char prefix, bool after ) {
     uassert( symbol != NULL );
 
     if ( symbol->data->key == COROUTINE || symbol->data->attribute.Mutex ) {
@@ -425,9 +421,14 @@ void gen_initializer( token_t *before, symbol_t *symbol, char prefix ) {
 	// If base->table is NULL, the type is incomplete; let g++ deal with it.
 	if ( base != NULL && base->data->table != NULL && base->data->table->hasdefault ) {
 	    if ( base->data->key == COROUTINE || base->data->attribute.Mutex ) {
-		gen_code( before, prefix );		// not entered as CODE
+		if ( ! after ) {
+		    gen_code( before, prefix );		// not entered as CODE
+		} // if
 		gen_base_specifier_name( before, symbol );
 		gen_code( before, "( uNo )" );
+		if ( after ) {
+		    gen_code( before, prefix );		// not entered as CODE
+		} // if
 	    } // if
 	} // if
     } // if
@@ -436,7 +437,6 @@ void gen_initializer( token_t *before, symbol_t *symbol, char prefix ) {
 
 void gen_serial_initializer( token_t *rp, token_t *end, token_t *before, symbol_t *symbol ) {
     uassert( symbol != NULL );
-
     if ( symbol->data->attribute.Mutex && ( symbol->data->base == NULL || ! symbol->data->base->data->attribute.Mutex ) ) {
 	// check if there is already a base specifier for this type
 
@@ -457,11 +457,6 @@ void gen_serial_initializer( token_t *rp, token_t *end, token_t *before, symbol_
 } // gen_serial_initializer
 
 
-void gen_event_kind( token_t *before, symbol_t *symbol ) {
-    gen_code( before, symbol->data->key == DUALEVENT ? "uEHM :: uDualClass" : symbol->data->key == RESUMEEVENT ? "uEHM :: uResumeClass" : "uEHM :: uThrowClass" );
-} // gen_event_kind
-
-
 void gen_constructor( token_t *before, symbol_t *symbol ) {
     table_t *table;
 
@@ -471,8 +466,7 @@ void gen_constructor( token_t *before, symbol_t *symbol ) {
 
     // if necessary, generate a default constructor
     
-    if ( symbol->data->key == COROUTINE || symbol->data->attribute.Mutex ||
-	 symbol->data->key == DUALEVENT || symbol->data->key == RESUMEEVENT || symbol->data->key == THROWEVENT ) {
+    if ( symbol->data->key == COROUTINE || symbol->data->attribute.Mutex || symbol->data->key == EVENT ) {
 
 	symbol->data->table->hasdefault = true;
 	gen_hash( table->public_area, symbol->hash );
@@ -481,7 +475,7 @@ void gen_constructor( token_t *before, symbol_t *symbol ) {
 	if ( symbol->data->key == COROUTINE || symbol->data->attribute.Mutex ) {
 	    gen_code( table->public_area, "( uAction uConstruct = uYes )" );
 	    rp = table->public_area->prev_parse_token();
-	    gen_initializer( table->public_area, symbol, ':' );
+	    gen_initializer( table->public_area, symbol, ':', false );
 	} else {
 	    gen_code( table->public_area, "( )" );
 	    rp = table->public_area->prev_parse_token();
@@ -576,9 +570,7 @@ void gen_class_prefix( token_t *before, symbol_t *symbol ) {
       case CLASS:
       case COROUTINE:
       case TASK:
-      case DUALEVENT:
-      case RESUMEEVENT:
-      case THROWEVENT:
+      case EVENT:
 	gen_code( before, "private :" );
 	break;
       default:
@@ -616,22 +608,36 @@ void gen_class_suffix( token_t *before, symbol_t *symbol ) {
     table = symbol->data->table;
     uassert( table != NULL );
 
-    if ( symbol->data->key == DUALEVENT || symbol->data->key == RESUMEEVENT || symbol->data->key == THROWEVENT ) {
-	gen_code( table->protected_area, "virtual uDualClass * duplicate ( ) const { return new" );
+    if ( symbol->data->key == EVENT ) {
+	gen_code( table->protected_area, "virtual" );
+	gen_hash( table->protected_area, symbol->hash );
+	gen_code( table->protected_area, "* duplicate ( ) const { return new" );
 	gen_hash( table->protected_area, symbol->hash );
 	gen_code( table->protected_area, "( * this ) ; }" );
-
-	if ( symbol->data->key == DUALEVENT || symbol->data->key == THROWEVENT ) {
-	    gen_code( table->protected_area, "virtual void stackThrow ( ) const { throw * this ; }" );
-	} // if
+	gen_code( table->protected_area, "virtual void stackThrow ( ) const { throw * this ; }" );
     } // if
 
     // declare uSerialInstance *after* the mutex queues (uMutexList) because
     // ~uSerial accesses these queues to check if there are outstanding tasks
     // awaiting entry.
 
-    if ( symbol->data->attribute.Mutex && ( symbol->data->base == NULL || ! symbol->data->base->data->attribute.Mutex ) ) {
-	gen_code( table->protected_area, "uSerial uSerialInstance ;" );
+    if ( symbol->data->attribute.Mutex ) {
+	 if ( symbol->data->base == NULL || ! symbol->data->base->data->attribute.Mutex ) {
+	     gen_code( table->protected_area, "uSerial uSerialInstance ;" );
+	 } else {
+	     // for a derived monitor that is a template or lexically contained
+	     // in a template, it is necessary to create a local typedef to
+	     // reference the mutex-queue type in its parent
+	     for ( symbol_t *ptr = symbol;; ptr = ptr->data->found->symbol ) {
+	       if ( ptr->data->attribute.plate != NULL ) {
+		     gen_code( table->private_area, "typedef typename" );
+		     gen_base_specifier_name( table->private_area, symbol );
+		     gen_code( table->private_area, ":: uMutexList uMutexList ;" );
+		     break;
+		 } // if
+	       if ( ptr->data->found == root ) break;	// => not contained in template type
+	     } // for
+	 } // if
     } // if
 
     // classes (not mutex), structs, unions may not have mutex arguments
@@ -673,8 +679,16 @@ void gen_class_suffix( token_t *before, symbol_t *symbol ) {
 	    structor_t *structor = table->constructor.remove_structor();
 
 	    gen_constructor_parameter( structor->rp, symbol, true );
-	    
+
 	    if ( structor->prefix != NULL ) {
+		if ( structor->separator != '\0' ) {
+		    if ( structor->start != NULL && structor->separator == ',' ) {
+			gen_initializer( structor->start, symbol, structor->separator, true );
+		    } else {
+			gen_initializer( structor->prefix, symbol, structor->separator, false );
+		    } // if
+		} // if
+		gen_serial_initializer( structor->rp, structor->prefix, structor->start, symbol );
 		gen_constructor_prefix( structor->prefix, symbol );
 		gen_constructor_suffix( structor->suffix, symbol );
 	    } // if
@@ -691,57 +705,21 @@ void gen_class_suffix( token_t *before, symbol_t *symbol ) {
 } // gen_class_suffix
 
 
-void gen_wait_prefix( token_t *before, token_t *after ) { // deprecated
+void gen_wait_prefix( token_t *before, token_t *after ) {
     gen_code( before, "(" );
     gen_code( after, ") . wait (" );
 } // gen_wait_prefix
 
-void gen_with( token_t *before, token_t *after ) {	// deprecated
+void gen_with( token_t *before, token_t *after ) {
     gen_code( before, "(" );
     gen_code( after, ")" );
 } // gen_with
 
-void gen_wait_suffix( token_t *before ) {		// deprecated
+void gen_wait_suffix( token_t *before ) {
     gen_code( before, ")" );
 } // gen_wait_suffix
 
 
-void gen_signal_prefix( token_t *before ) {		// deprecated
-    gen_code( before, "(" );
-} // gen_signal_prefix
-
-void gen_signal_suffix( token_t *before ) {		// deprecated
-    gen_code( before, ") . signal ( )" );
-} // gen_signal_suffix
-
-
-void gen_signalblock_prefix( token_t *before ) {	// deprecated
-    gen_code( before, "(" );
-} // gen_signalblock_prefix
-
-void gen_signalblock_suffix( token_t *before ) {	// deprecated
-    gen_code( before, ") . signalBlock ( )" );
-} // gen_signalblock_suffix
-
-
-void gen_suspend_prefix( token_t *before, symbol_t *symbol ) { // deprecated
-    gen_code( before, "{ suspend ( )" );
-} // gen_suspend_prefix
-
-void gen_suspend_suffix( token_t *before, symbol_t *symbol ) { // deprecated
-    gen_code( before, "}" );
-} // gen_suspend_suffix
-
-
-void gen_resume_prefix( token_t *before, symbol_t *symbol ) { // deprecated
-    gen_code( before, "{ resume ( )" );
-} // gen_resume
-
-void gen_resume_suffix( token_t *before, symbol_t *symbol ) { // deprecated
-    gen_code( before, "}" );
-} // gen_resume
-
-
 void gen_verify( token_t *before ) {
     gen_code( before, "uThisCoroutine ( ) . verify ( ) ;" );
 } // gen_verify
@@ -752,24 +730,6 @@ void gen_yield( token_t *before ) {
 } // gen_yield
 
 
-void gen_uthrow_prefix( token_t *before, token_t *after ) {
-    gen_code( before, "uEHM :: Throw (" );
-} // gen_uthrow_prefix
-
-void gen_uthrow_suffix( token_t *before ) {
-    gen_code( before, ")" );
-} // gen_uthrow_suffix
-
-
-void gen_raise_prefix( token_t *before, token_t *after ) {
-    gen_code( before, "uEHM :: Resume (" );
-} // gen_raise_prefix
-
-void gen_raise_suffix( token_t *before ) {
-    gen_code( before, ")" );
-} // gen_raise_suffix
-
-
 // Local Variables: //
 // compile-command: "gmake install" //
 // End: //
