@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
 // 
 // input.c -- 
 // 
 // Author           : Richard A. Stroobosscher
 // Created On       : Tue Apr 28 15:05:28 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sun Aug  8 07:32:54 2004
-// Update Count     : 55
+// Last Modified On : Fri Jul 13 18:08:57 2007
+// Update Count     : 57
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -30,6 +30,7 @@
 #include "input.h"
 
 #include <iostream>
+#include <cstdlib>					// exit
 
 using std::cerr;
 using std::endl;
@@ -718,7 +719,7 @@ token_t *getinput() {
 void read_all_input() {
     for ( ;; ) {
 	token_t *token = getinput();
-	list->add_to_tail( *token );
+	token_list->add_to_tail( *token );
       if ( token->value == EOF ) break;
     } // for
 } // read_all_input
