@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
 // 
 // scan.c -- 
 // 
 // Author           : Richard A. Stroobosscher
 // Created On       : Tue Apr 28 15:11:49 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sun Aug  8 07:15:40 2004
-// Update Count     : 49
+// Last Modified On : Fri Jun 22 17:45:09 2007
+// Update Count     : 52
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -30,6 +30,17 @@
 #include "input.h"
 #include "scan.h"
 
+#include <cstdio>					// EOF
+
+//#define __U_DEBUG_H__
+
+#ifdef __U_DEBUG_H__
+#include <iostream>
+
+using std::cerr;
+using std::endl;
+#endif // __U_DEBUG_H__
+
 
 void scan() {
     ahead = ahead->next_parse_token();
@@ -49,15 +60,34 @@ void scan() {
 	// use the symbol to determine whether the identifier is a type or a
 	// variable.
 	
+#ifdef __U_DEBUG_H__
+	cerr << "scan: token " << ahead << " (" << ahead->hash->text << ") focus " << focus << endl;
+#endif // __U_DEBUG_H__
 	if ( focus != NULL ) {			// scanning mode
 	    ahead->symbol = focus->search_table( ahead->hash );
 	    if ( ahead->symbol != NULL ) {
+#ifdef __U_DEBUG_H__
+		cerr << "scan: setting token " << ahead << " (" << ahead->hash->text << ") to value " << ahead->symbol->value << endl;
+#endif // __U_DEBUG_H__
 		ahead->value = ahead->symbol->value;
 	    } // if
 	} // if
     } // if
 } // scan
 
+
+void unscan( token_t *back ) {
+    for ( token_t *t = back->next_parse_token(); t != ahead->next_parse_token(); t = t->next_parse_token() ) {
+#ifdef __U_DEBUG_H__
+	if ( t->value == TYPE || t->symbol != NULL ) cerr << "unscan: clearing token " << ahead << " (" << ahead->hash->text << ")" << endl;
+#endif // __U_DEBUG_H__
+	if ( t->value == TYPE ) t->value = IDENTIFIER;
+	t->symbol = NULL;
+    } // for
+    ahead = back;
+} // unscan
+
+
 // Local Variables: //
 // compile-command: "gmake install" //
 // End: //
