@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
 // 
 // scan.h -- 
 // 
 // Author           : Richard A. Stroobosscher
 // Created On       : Tue Apr 28 15:43:34 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jun 28 16:46:21 2001
-// Update Count     : 10
+// Last Modified On : Sat Feb 10 10:54:49 2007
+// Update Count     : 11
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -28,6 +28,7 @@
 #define __SCAN_H__
 
 void scan();
+void unscan( token_t *back );
 
 #endif // __SCAN_H__
 
