@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
 // 
 // structor.h -- 
 // 
 // Author           : Richard A. Stroobosscher
 // Created On       : Tue Apr 28 15:46:34 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Aug  2 12:33:12 2004
-// Update Count     : 27
+// Last Modified On : Mon Dec 18 17:14:07 2006
+// Update Count     : 29
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -34,6 +34,8 @@ class token_t;
 
 class structor_t {
   public:
+    char separator;					// separator cahracter before base-class initializer
+    token_t *start;					// first token of non-base class initializer
     token_t *prefix;					// '{' of constructor/destructor
     token_t *suffix;					// '}' of constructor/destructor
     token_t *rp;					// ')' of constructor parameter list
