@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr and Nikita Borisov 1995
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr and Nikita Borisov 1995
 // 
 // u++.cc -- 
 // 
 // Author           : Nikita Borisov
 // Created On       : Tue Apr 28 15:26:27 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Sep 15 20:54:49 2006
-// Update Count     : 797
+// Last Modified On : Tue Sep 11 08:31:18 2007
+// Update Count     : 815
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -29,6 +29,7 @@
 #include <fstream>					// ifstream
 #include <cstdio>					// perror
 #include <cstdlib>					// getenv, putenv
+#include <cstring>					// strcmp, strlen
 #include <string>					// STL version
 #include <unistd.h>					// execvp
 
@@ -104,6 +105,7 @@ int main( int argc, char *argv[] ) {
     bool Yield = false;					// -yield flag (name "yield" already taken)
     bool verify = false;				// -verify flag
     bool profile = false;				// -profile flag
+    bool exact = true;					// profile type: exact | statistical
     bool debugging = false;				// -g flag
     bool openmp = false;				// -openmp flag
 
@@ -128,8 +130,9 @@ int main( int argc, char *argv[] ) {
     string uxlibdir;
     string mvdincdir;
     string mvdlibdir;
-    string perfctrincdir;
-    string perfctrlibdir;
+    string useperfmonstr;
+    string perfmonincdir;
+    string perfmonlibdir;
     string token;
 
 #ifdef __U_DEBUG_H__
@@ -157,6 +160,7 @@ int main( int argc, char *argv[] ) {
 		args[nargs] = argv[i];			// pass the argument along
 		nargs += 1;
 		i += 1;
+		if ( i == argc ) continue;		// next argument available ?
 		args[nargs] = argv[i];			// pass the argument along
 		nargs += 1;
 
@@ -189,11 +193,20 @@ int main( int argc, char *argv[] ) {
 		verify = false;				// strip the noverify flag
 	    } else if ( arg == "-profile" ) {
                 profile = true;                         // strip the profile flag
+		if ( i + 1 < argc ) {			// check next argument, if available
+		    if ( strcmp( argv[i + 1], "exact" ) == 0 ) { // default ?
+			i += 1;				// skip argument
+		    } else if ( strcmp( argv[i + 1], "statistical" ) == 0 ) {
+			exact = false;
+			i += 1;				// skip argument
+		    } // if
+		} // if
             } else if ( arg == "-noprofile" ) {
                 profile = false;                        // strip the noprofile flag
 	    } else if ( arg == "-compiler" ) {
 		// use the user specified compiler
 		i += 1;
+		if ( i == argc ) continue;		// next argument available ?
 		compiler_path = argv[i];
 #if __GNUC__==3 && __GNUC_MINOR__==2
 		args[nargs] = ( *new string( string("-D__U_COMPILER__=") + compiler_path ) ).c_str();
@@ -222,6 +235,7 @@ int main( int argc, char *argv[] ) {
 	    } else if ( prefix( arg, "-b" ) ) {
 		if ( arg.length() == 2 ) {		// separate argument ?
 		    i += 1;
+		    if ( i == argc ) continue;		// next argument available ?
 		    arg += argv[i];			// concatenate argument
 		} // if
 #if __GNUC__==3 && __GNUC_MINOR__==2
@@ -229,6 +243,7 @@ int main( int argc, char *argv[] ) {
 		nargs += 1;
 		args[nargs] = ( *new string( string("-D__U_GCC_MACHINE__=") + arg ) ).c_str();
 #else
+		// later versions of gcc require the -b option to appear at the start of the command line
 		shuffle( args, sargs, nargs, 1 );	// make room at front of argument list
 		args[sargs] = ( *new string( arg ) ).c_str(); // pass the argument along
 		if ( putenv( (char *)( *new string( string( "__U_GCC_MACHINE__=" ) + arg ) ).c_str() ) != 0 ) {
@@ -241,6 +256,7 @@ int main( int argc, char *argv[] ) {
 	    } else if ( prefix( arg, "-V" ) && ! prefix( compiler_name, "icpc" ) ) {
 		if ( arg.length() == 2 ) {		// separate argument ?
 		    i += 1;
+		    if ( i == argc ) continue;		// next argument available ?
 		    arg += argv[i];			// concatenate argument
 		} // if
 #if __GNUC__==3 && __GNUC_MINOR__==2
@@ -248,6 +264,7 @@ int main( int argc, char *argv[] ) {
 		nargs += 1;
 		args[nargs] = ( *new string( string("-D__U_GCC_VERSION__=") + arg ) ).c_str();
 #else
+		// later versions of gcc require the -V option to appear at the start of the command line
 		shuffle( args, sargs, nargs, 1 );	// make room at front of argument list
 		args[sargs] = ( *new string( arg ) ).c_str(); // pass the argument along
 		if ( putenv( (char *)( *new string( string( "__U_GCC_VERSION__=" ) + arg ) ).c_str() ) != 0 ) {
@@ -339,9 +356,9 @@ int main( int argc, char *argv[] ) {
 		cerr << argv[0] << ": Warning could not open file \"" << configFilename << "\". Profiling disabled." << endl;
 		profile = false;
 	    } else {
-		const int dirnum = 8;
+		const int dirnum = 9;
 		struct {
-		    char *dirkind;
+		    const char *dirkind;
 		    int used;
 		    string *dirname;
 		} dirs[dirnum] = {
@@ -350,8 +367,9 @@ int main( int argc, char *argv[] ) {
 		    { "BFDINCLUDEDIR", 1, &bfdincdir },
 		    { "MOTIFINCLUDEDIR", 1, &motifincdir },
 		    { "MOTIFLIBDIR", 1, &motiflibdir },
-		    { "PERFCTRINCLUDEDIR", 1, &perfctrincdir },
-		    { "PERFCTRLIBDIR", 1, &perfctrlibdir },
+		    { "PERFMON", 1, &useperfmonstr },
+		    { "PFMINCLUDEDIR", 1, &perfmonincdir },
+		    { "PFMLIBDIR", 1, &perfmonlibdir },
 		    { "TMPDIR", 1, &tmppath },
 		};
 		string dirkind, equal, dirname;
@@ -394,8 +412,7 @@ int main( int argc, char *argv[] ) {
 
 	int pargs = 0;
 	if ( profile ) {
-	    pargs += 9;					// N profiler arguments added at beginning
-	    if ( ! debugging ) pargs += 1;		// no -g flag ? make room for one
+	    pargs += 7;					// N profiler arguments added at beginning
 	} // if
 	shuffle( args, sargs, nargs, pargs );
 	nargs += pargs;
@@ -404,10 +421,6 @@ int main( int argc, char *argv[] ) {
 	    // link the profiling library before the user code
 	    args[sargs] = "-u";
 	    sargs += 1;
-	    args[sargs] = "__cyg_profile_func_enter";	// force profiler library to be loaded
-	    sargs += 1;
-	    args[sargs] = "-u";
-	    sargs += 1;
 	    args[sargs] = "U_SMEXACTMENUWD";		// force profiler start-up widgets to be loaded
 	    sargs += 1;
 	    args[sargs] = "-u";
@@ -418,11 +431,19 @@ int main( int argc, char *argv[] ) {
 	    sargs += 1;
 	    args[sargs] = "U_SMOTHERMENUWD";		// force profiler start-up widgets to be loaded
 	    sargs += 1;
+	    // SKULLDUGGERY: Put the profiler library before the user code to
+	    // force the linker to include the no-profiled versions of compiled
+	    // inlined routines from uC++.h.
 	    args[sargs] = ( *new string( mvdlibdir + "/uProfile"  + m + d + ".a" ) ).c_str();
 	    sargs += 1;
+	    // SKULLDUGGERY: Put the profiler library after the user code to
+	    // force the linker to include the -finstrument-functions, if there
+	    // is any reference to them in the user code.
+	    args[nargs] = ( *new string( mvdlibdir + "/uProfile"  + m + d + ".a" ) ).c_str();
+	    nargs += 1;
 	    if ( ! debugging ) {			// add -g if not specified
-		args[sargs] = "-g";
-		sargs += 1;
+		args[nargs] = "-g";
+		nargs += 1;
 	    } // if
 	} // if    
 
@@ -466,18 +487,6 @@ int main( int argc, char *argv[] ) {
 
 	args[nargs] = ( *new string( installlibdir + "/uProfilerFunctionPointers" + ".o" ) ).c_str();
 	nargs += 1;
-#if 0
-	if ( tvendor == "ibm" ) {
-	    // Prevent linker from reordering code in memory.  This is
-	    // necessary for the correct implementation of time slicing and
-	    // shared memory management.
-
-	    args[nargs] = "-Xlinker";			// g++ trick to pass through next flag to linker
-	    nargs += 1;
-	    args[nargs] = "-bnoobjreorder";
-	    nargs += 1;
-	} // if
-#endif // 0
 
 	// any machine specific libraries
 
@@ -528,21 +537,25 @@ int main( int argc, char *argv[] ) {
                 libs[nlibs] = "-lcpc";
                 nlibs += 1;
 	    } // if
-	    if ( tos == "linux" && tcpu == "i386" ) {	// link in performance counter
-		if ( perfctrlibdir.length() != 0 ) {
-		    args[nargs] = ( *new string( string( "-L" ) + perfctrlibdir ) ).c_str();
-		    nargs += 1;
-		    args[nargs] = ( *new string( string("-Wl,-R,") + perfctrlibdir ) ).c_str();
-		    nargs += 1;
-		} // if 
+	    if ( perfmonlibdir.length() != 0 ) {
+		args[nargs] = ( *new string( string( "-L" ) + perfmonlibdir ) ).c_str();
+		nargs += 1;
+		args[nargs] = ( *new string( string("-Wl,-R,") + perfmonlibdir ) ).c_str();
+		nargs += 1;
+	    } // if
+	    if ( useperfmonstr == "PERFMON" ) {		// link in performance counter
+                libs[nlibs] = "-lpfm";
+                nlibs += 1;
+	    } else if ( useperfmonstr == "PERFMON3" ) {
+                libs[nlibs] = "-lpfm3";
+                nlibs += 1;
+	    } else if ( useperfmonstr == "PERFCTR" ) {
                 libs[nlibs] = "-lperfctr";
                 nlibs += 1;
 	    } // if
 	    if ( tos == "linux" && tcpu == "ia64" ) {
                 libs[nlibs] = "-lunwind";		// link in libunwind for backtraces
                 nlibs += 1;
-                libs[nlibs] = "-lpfm3";			// link in performance counter
-                nlibs += 1;
 	    } // if
 	} // if
 
@@ -641,8 +654,10 @@ int main( int argc, char *argv[] ) {
 
     if ( profile ) {
         heading += " (profile)";
-	args[nargs] = ( *new string( "-finstrument-functions" ) ).c_str();
-	nargs += 1;
+	if ( exact ) {
+	    args[nargs] = ( *new string( "-finstrument-functions" ) ).c_str();
+	    nargs += 1;
+	} // if
         args[nargs] = "-D__U_PROFILE__";
         nargs += 1;
     } else {
@@ -675,6 +690,12 @@ int main( int argc, char *argv[] ) {
 	nargs += 1;
     } // if
 
+    if ( tcpu == "sparc" && tos == "solaris" ) {
+	// tell assembler it's ok to use cas
+	args[nargs] = "-Wa,-xarch=v8plusa";
+	nargs += 1;
+    } // if
+
     // execute the compilation command
 
     args[0] = compiler_path.c_str();			// set compiler command for exec
