@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
 // 
 // assert.h -- 
 // 
 // Author           : Richard A. Stroobosscher
 // Created On       : Tue Apr 28 16:01:41 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Nov 20 10:07:51 2002
-// Update Count     : 34
+// Last Modified On : Fri Jun 22 17:46:53 2007
+// Update Count     : 35
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -36,6 +36,7 @@
 #else
 
 #include <iostream>
+#include <cstdlib>					// exit
 
 using std::cerr;
 using std::endl;
